(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    195062,       5062]*)
(*NotebookOutlinePosition[    236600,       6551]*)
(*  CellTagsIndexPosition[    236273,       6537]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[ValueBox["FileName"]], "Title",
  CounterAssignments->{{"Title", 0}, {"SubTitle", 0}, {"SubSubTitle", 0}, {
      "Section", 0}, {"SubSection", 0}, {"SubSubSection", 0}, {
      "NumberedEquation", 0}, {"NumberedFigure", 0}, {"NumberedTable", 0}}],

Cell["\<\
Fragesteller:\t  24.  6.2002\tGerd Baumann
Bearbeitung:\t    4.  9.2002 - 27.  2.2003\tNorbert S\[UDoubleDot]dland
Letzte Berechnung:\t27.  2.2003\tNorbert S\[UDoubleDot]dland\
\>", "Subsubtitle",
  TextAlignment->Left],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ". Frage"
}], "Section"],

Cell["\<\
F\[UDoubleDot]r astronomische Berechnungen ist die genaue Kenntnis der \
Zeitdifferenz notwendig. Wie kann bei bekanntem Kalendersystem auf diese \
Differenz geschlossen werden? Wie kann aus der Zeitdifferenz auf ein \
entsprechendes Kalenderdatum geschlossen werden? Wie lassen sich verschiedene \
Kalendersysteme ineinander umrechnen?\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ". Antwort"
}], "Section"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Motivation"
}], "Subsection"],

Cell[TextData[{
  "Derartige Fragestellungen ergeben sich, wenn der ",
  StyleBox["Scientific Astronomer",
    FontSlant->"Italic"],
  " zum Programmpaket ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " geladen wird. Bislang fehlt n\[ADoubleDot]mlich eine derartige M\
\[ODoubleDot]glichkeit, wodurch das Nachvollziehen historischer Sternl\
\[ADoubleDot]ufe unn\[ODoubleDot]tig erschwert ist."
}], "Text"],

Cell[TextData[{
  "Erfreulich am ",
  StyleBox["Scientific Astronomer",
    FontSlant->"Italic"],
  " ist, da\[SZ] der Sternlauf f\[UDoubleDot]r jeden geographischen Punkt auf \
der Erde konkret ber\[UDoubleDot]cksichtigt werden kann."
}], "Text"],

Cell[TextData[{
  "Das Besondere an ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ist, da\[SZ] mit beliebig gro\[SZ]en Zahlen umgegangen werden kann, \
wodurch auch extreme Extrapolationen der vorhandenen mathematischen Modelle \
durchgef\[UDoubleDot]hrt werden k\[ODoubleDot]nnen \[Dash] freilich auch, um \
die Grenzen der Extrapolation zu beleuchten."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Programme zur Errechnung einer Zeitdifferenz"
}], "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Einheitlicher Bezugspunkt"
}], "Subsubsection"],

Cell["\<\
Zeitdifferenzen k\[ODoubleDot]nnen nur miteinander verglichen werden, wenn \
sie jeweils denselben einheitlichen Bezugspunkt besitzen.\
\>", "Text"],

Cell["\<\
Bei physikalischen Versuchsaufbauten ist stets die Differenz ab Startzeit zu \
bilden. Bei historischen Datierungen mu\[SZ] ein einheitlicher und eventuell \
unumstrittener Zeitpunkt gew\[ADoubleDot]hlt werden.\
\>", "Text"],

Cell["\<\
Bei der Wahl des Bezugspunktes ist prinzipiell jedes beliebige Datum m\
\[ODoubleDot]glich. Um dies zu unterstreichen, wird hier Freitag, der 14. \
5.1948, als Tag der Wiedergr\[UDoubleDot]ndung Israels zum Bezugspunkt der \
Zeitdifferenz gemacht. Dieser Termin stellt in keinem Kalendersystem eine \
besonders einfache Position dar, wodurch alle Probleme der Umrechnung erfa\
\[SZ]t werden.\
\>", "Text"],

Cell[TextData[{
  "Da die Woche die \[ADoubleDot]lteste Zeitperiode ist, die zur \
Zeiteinteilung durchgehalten wurde, bekommt dieser Tag die Ordnungszahl ",
  Cell[BoxData[
      \(6\)]],
  " f\[UDoubleDot]r Freitag, den sechsten Tag der Woche."
}], "Text"],

Cell[TextData[{
  "In Knaurs Lexikon (",
  ButtonBox["[Knau1951]",
    ButtonData:>"[Knau1951]",
    ButtonStyle->"Hyperlink"],
  ", Stichwort \"Israel\", Seite 722) wird der 15. 5.1948 als Tag der \
Proklamation Israels angegeben. Da ein Samstag rechentechnisch die \
Ordnungszahl ",
  Cell[BoxData[
      \(TraditionalForm\`7\)]],
  " besitzt und auf die Tagesdifferenz ",
  Cell[BoxData[
      \(TraditionalForm\`0\)]],
  " gebracht werden kann, w\[ADoubleDot]re die Verwendung dieses Datums eine \
Vereinfachung des Algorithmus und somit nicht v\[ODoubleDot]llig allgemein."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Tagesl\[ADoubleDot]nge bei Monaten im Sonnenjahr"
}], "Subsubsection"],

Cell[TextData[{
  "Im Sonnenjahr sind konstant ",
  Cell[BoxData[
      \(12\)]],
  " Monate pro Jahr vorhanden, wobei jeder Monat eine andere \
L\[ADoubleDot]nge besitzt. Die hier verwendete Monatsl\[ADoubleDot]nge \
richtet sich nach dem Julianischen Kalender ohne Ber\[UDoubleDot]cksichtigung \
der Schalttage:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Protect[\ MonthlyDaySum\ ]\ ; \n
    \(Function[\n\tClear[\ MonthlyDaySum\ ]\ ; \n\t\n\t
        MonthlyDaySum::usage\  = \n\t
          "\<MonthlyDaySum[month] gives the sum of days\>"\ <>\n\t\t
            "\< according to a given `month`.\>"\ ; \n\t\n\t
         (**********************************) \n\t\t
        MonthlyDaySum[month_Integer\ ]\  := \n\t
           (*\(******\)*\(********************\)******) \n\t
          \(# - #\[LeftDoubleBracket]\ 
                  Mod[\ month\  - \ 1\ \ , \ 12\ ]\  + \ 1\ 
                  \[RightDoubleBracket]&\)@\n\t\t
            \((\(Plus@@
                    Take[{0, 31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30}, #]&
                  \)/@\n\t\tRange[12])\)\ ; \n\t\n\tProtect[#]\n]\)[\ 
      Unprotect[\ MonthlyDaySum\ ]\ ]\)], "Input"],

Cell[BoxData[
    \({"MonthlyDaySum"}\)], "Output"]
}, Open  ]],

Cell["\<\
Daraus ergibt sich eine Matrix mit den Tagessummen f\[UDoubleDot]r jeden \
Monat des Jahres:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(MonthlyDaySum[#]&\)/@Range[12] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
           
             {"0", "31", "59", "90", "120", "151", "181", "212", "243", "273",
               "304", "334"},
           
             {\(-31\), "0", "28", "59", "89", "120", "150", "181", "212", 
              "242", "273", "303"},
           
             {\(-59\), \(-28\), "0", "31", "61", "92", "122", "153", "184", 
              "214", "245", "275"},
           
             {\(-90\), \(-59\), \(-31\), "0", "30", "61", "91", "122", "153", 
              "183", "214", "244"},
           
             {\(-120\), \(-89\), \(-61\), \(-30\), "0", "31", "61", "92", 
              "123", "153", "184", "214"},
           
             {\(-151\), \(-120\), \(-92\), \(-61\), \(-31\), "0", "30", "61", 
              "92", "122", "153", "183"},
           
             {\(-181\), \(-150\), \(-122\), \(-91\), \(-61\), \(-30\), "0", 
              "31", "62", "92", "123", "153"},
           
             {\(-212\), \(-181\), \(-153\), \(-122\), \(-92\), \(-61\), 
              \(-31\), "0", "31", "61", "92", "122"},
           
             {\(-243\), \(-212\), \(-184\), \(-153\), \(-123\), \(-92\), 
              \(-62\), \(-31\), "0", "30", "61", "91"},
           
             {\(-273\), \(-242\), \(-214\), \(-183\), \(-153\), \(-122\), 
              \(-92\), \(-61\), \(-30\), "0", "31", "61"},
           
             {\(-304\), \(-273\), \(-245\), \(-214\), \(-184\), \(-153\), 
              \(-123\), \(-92\), \(-61\), \(-31\), "0", "30"},
           
             {\(-334\), \(-303\), \(-275\), \(-244\), \(-214\), \(-183\), 
              \(-153\), \(-122\), \(-91\), \(-61\), \(-30\), "0"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". \[CapitalADoubleDot]gyptisches Sonnenjahr"
}], "Subsubsection"],

Cell[TextData[{
  "Das \[ADoubleDot]gyptische Sonnenjahr hatte ",
  Cell[BoxData[
      \(365\)]],
  " Tage und besa\[SZ] bis zum 28. 2.45 v.Chr. G\[UDoubleDot]ltigkeit, als \
Caius Julius Caesar am folgenden Tag in Rom den Julianischen Kalender einf\
\[UDoubleDot]hrte. (",
  ButtonBox["[Zem1987]",
    ButtonData:>"[Zem1987]",
    ButtonStyle->"Hyperlink"],
  ", Abschnitte 2.61 und 2.64, Seite 26 und 27)"
}], "Text"],

Cell[TextData[{
  "Bis zum 14. 5.1948 wurden wegen der Gregorianischen Kalenderreform ",
  Cell[BoxData[
      \(13\)]],
  " der ",
  Cell[BoxData[
      \(499\)]],
  " Schalttage weggelassen. Das Jahr 45 v.Chr. selbst ist ein Schaltjahr, w\
\[ADoubleDot]hrend das Jahr Null nicht existiert. Eine Datierung in \
\[ADoubleDot]gyptischen Sonnenjahren gibt also als Tag der Wiedergr\
\[UDoubleDot]ndung Israels den 12. 9.1949 an. Dieser Tag erh\[ADoubleDot]lt \
die Nummer ",
  Cell[BoxData[
      \(6\)]],
  ", da es sich um einen Freitag handelt."
}], "Text"],

Cell[TextData[{
  "Das Sonnenjahr besitzt immer ",
  Cell[BoxData[
      \(12\)]],
  " Monate im Jahr, wodurch Bereichsverletzungen die Jahreszahl entsprechend \
ver\[ADoubleDot]ndern."
}], "Text"],

Cell["\<\
Es resultiert folgendes Programm, um aus einem \[ADoubleDot]gyptischen Datum \
(mit r\[ODoubleDot]mischer Monatsl\[ADoubleDot]nge!) eine Zeitdifferenz in \
Tagen zu bestimmen:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Protect[\ EgyptianSolarYearDay\ ]\ ; \n
    \(Function[\n\tClear[\ EgyptianSolarYearDay\ ]\ ; \n\t\n\t
        EgyptianSolarYearDay::usage = \n\t
          "\<EgyptianSolarYearDay[{year, month, day, ..}] gives the number of \
days\>"\ <>\n\t\t"\< since Friday, May 14th, 1948 (Gregorianic system)\>"\ <>
            \n\t\t"\< which is Friday, Sept 12th, 1949 in the Egyptian system\
\>"\ <>\n\t\t"\< where Friday is number six.\>"\ ; \n\t\n\t
         (************************************************************) \n\t\t
        EgyptianSolarYearDay[
            \ {\ year_Integer\ , month_Integer\ , day_Integer\ , \n
              \t\t\t___Integer\ }\ ] := \n\t
           (************************************************************) \n\t
          Block[\ {\ yearnew\ , \ \ 
               (*\ the\ year\ `0`\ does\ not\ \(exist!\)\ *) \n\t\t\tmonthnew
              \ , \n\t\t\tresult = 6\ \ \  (*\ Friday\ *) \n\t\t}\ , \n\t\n
            \t\t (*\ Preparation : \ *) \n\t\t
             (*\(--\(--\(--\(---\)\)\)\)*) \n\t\t
            yearnew\  = \ 
              year\  + \ Floor[\ \((month\  - \ 1)\)\ /\ 12\ ] + \ 
                \((1 - Sign[2  year + 1])\)/2; \n\t\t
            monthnew\  = \ Mod[\ month\  - 1\ , \ 12\ ] + 1\ ; \n\t\t\n\t\t
             (*\ Orientation\ to\ Sept\ 12  th, \ \(1949 : \)\ *) \n\t\t
             (*\(--\(--
                  \(--\(--\(--\(--\(--\(--\(--\(---\)\)\)\)\)\)\)\)\)\)*) \n
            \t\tresult\  += \ 
              day\  - \ 12\  + \ 
                \(MonthlyDaySum[\ 9\ ]\)\[LeftDoubleBracket]\ monthnew\ 
                  \[RightDoubleBracket]\ ; \n\t\t
            result\  += \((yearnew - 1949)\)*365\ ; \n\t\t\n\t\t
             (*\ Result : \ *) \n\t\t (*\(--\(---\)\)*) \n\t\tresult\n\t]\ ; 
        \n\t\n\tProtect[\ #\ ]\n]\)[\ Unprotect[\ EgyptianSolarYearDay\ ]\ ]
      \)], "Input"],

Cell[BoxData[
    \({"EgyptianSolarYearDay"}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Julianisches Sonnenjahr"
}], "Subsubsection"],

Cell["Das Julianische Sonnenjahr hatte", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(1461\/4 // N[#, 16]&\)], "Input"],

Cell[BoxData[
    StyleBox["365.249999999999985`",
      StyleBoxAutoDelete->True,
      PrintPrecision->16]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Tage (",
  ButtonBox["[Zem1987]",
    ButtonData:>"[Zem1987]",
    ButtonStyle->"Hyperlink"],
  ", Abschnitt 2.64, Seite 27) und besa\[SZ] zwischen dem 29. 2.45 v.Chr. und \
dem 4.10.1582 n.Chr. G\[UDoubleDot]ltigkeit, als Papst Gregor XIII. am \
folgenden Tag in Rom den Gregorianischen Kalender einf\[UDoubleDot]hrte. (",
  ButtonBox["[Zem1987]",
    ButtonData:>"[Zem1987]",
    ButtonStyle->"Hyperlink"],
  ", Einleitung, Seite 11)"
}], "Text"],

Cell[TextData[{
  "Bis zum 14. 5.1948 wurden wegen der Gregorianischen Kalenderreform ",
  Cell[BoxData[
      \(13\)]],
  " der sonst bis zu ",
  Cell[BoxData[
      \(499\)]],
  " Schalttage weggelassen. Eine Datierung in Julianischen Sonnenjahren gibt \
also als Tag der Wiedergr\[UDoubleDot]ndung Israels den 1. 5.1948 an. Dieser \
Tag erh\[ADoubleDot]lt die Nummer ",
  Cell[BoxData[
      \(6\)]],
  ", da es sich um einen Freitag handelt."
}], "Text"],

Cell[TextData[{
  "Das Sonnenjahr besitzt immer ",
  Cell[BoxData[
      \(12\)]],
  " Monate im Jahr, wodurch Bereichsverletzungen die Jahreszahl entsprechend \
ver\[ADoubleDot]ndern."
}], "Text"],

Cell["\<\
Es resultiert folgendes Programm, um aus einem Julianischen Datum eine \
Zeitdifferenz in Tagen zu bestimmen:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Protect[\ JulianSolarYearDay\ ]\ ; \n
    \(Function[\n\tClear[\ JulianSolarYearDay\ ]\ ; \n\t\n\t
        JulianSolarYearDay::usage = \n\t
          "\<JulianSolarYearDay[{year, month, day, ..}] gives the number of \
days\>"\ <>\n\t\t"\< since Friday, May 14th, 1948 (Gregorianic system)\>"\ <>
            \n\t\t"\< which is Friday, May 1st, 1948 in the Julian system\>"\ \
<>\n\t\t"\< where Friday is number six.\>"\ ; \n\t\n\t
         (**********************************************************) \n\t\t
        JulianSolarYearDay[
            \ {\ year_Integer\ , month_Integer\ , day_Integer\ , \n
              \t\t\t\ ___Integer\ }\ ] := \n\t
           (**********************************************************) \n\t
          Block[\ {\ yearnew\ , \ \ 
               (*\ the\ year\ `0`\ does\ not\ \(exist!\)\ *) \n\t\t\tmonthnew
              \ , \n\t\t\tresult = 6\ \ \  (*\ Friday\ *) \n\t\t}\ , \n\t\n
            \t\t (*\ Preparation : \ *) \n\t\t
             (*\(--\(--\(--\(---\)\)\)\)*) \n\t\t
            yearnew\  = \ 
              year\  + \ Floor[\ \((month\  - \ 1)\)\ /\ 12\ ] + \ 
                \((1 - Sign[2  year + 1])\)/2; \n\t\t
            monthnew\  = \ Mod[\ month\  - 1\ , \ 12\ ] + 1\ ; \n\t\t\n\t\t
             (*\ Orientation\ to\ May\ 1  st, \ \(1948 : \)\ *) \n\t\t
             (*\(--\(--\(--\(--\(--\(--\(--\(--\(----\)\)\)\)\)\)\)\)\)*) \n
            \t\tresult\  += \ 
              day\  - \ 1\  + \ 
                \(MonthlyDaySum[\ 5\ ]\)\[LeftDoubleBracket]\ monthnew\ 
                  \[RightDoubleBracket]\ ; \n\t\t
            result\  += \((yearnew - 1948)\)*\ 365\ ; \n\t\t
            result\  += Floor[\((yearnew - 1948)\)/4]\ ; \n\t\n\t\t
             (*\ Before\ Intercalary\ Day\ within\ a\ Leap - \(Year : \)\ *) 
              \n\t\t (*
              \(--\(--\(--
                    \(--\(-\(--
                          \(--\(--
                              \(--\(--
                                  \(--\(--
                                      \(--\(----
                                        \)\)\)\)\)\)\)\)\)\)\)\)\)\)*) \n\t\t
            If[\ Mod[\ yearnew\ , \ 4\ ]\ \  === \ \ 0\ \ \  && \ \ \ 
                monthnew\  < \ 3\ , \n\t\t\t\(result\  -= \ 1\ ; \)\n\t\t]\ ; 
            \n\t\t\t\n\t\t (*\ Result : \ *) \n\t\t (*\(--\(---\)\)*) \n\t\t
            result\n\t]\ ; \n\t\n\tProtect[\ #\ ]\n]\)[\ 
      Unprotect[\ JulianSolarYearDay\ ]\ ]\)], "Input"],

Cell[BoxData[
    \({"JulianSolarYearDay"}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Gregorianische Kalenderreform"
}], "Subsubsection"],

Cell["Das Gregorianische Sonnnenjahr hat", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(146097\/400 // N[#, 16]&\)], "Input"],

Cell[BoxData[
    StyleBox["365.242500000000003`",
      StyleBoxAutoDelete->True,
      PrintPrecision->16]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Tage (",
  ButtonBox["[Zem1987]",
    ButtonData:>"[Zem1987]",
    ButtonStyle->"Hyperlink"],
  ", Abschnitt 2.65, Seite 28-29) und besitzt ab Freitag, dem 15.10.1582 \
n.Chr., G\[UDoubleDot]ltigkeit, den Papst Gregor XIII. in Rom auf Donnerstag, \
den 4.10.1582, folgen lie\[SZ]. (",
  ButtonBox["[Zem1987]",
    ButtonData:>"[Zem1987]",
    ButtonStyle->"Hyperlink"],
  ", Einleitung, Seite 11)"
}], "Text"],

Cell[TextData[{
  "Bis zum 14. 5.1948 hatte sich der Unterschied zum Julianischen Kalender um \
weitere drei Tage auf ",
  Cell[BoxData[
      \(13\)]],
  " erh\[ODoubleDot]ht. Eine Datierung in Gregorianischen Sonnenjahren gibt \
also als Tag der Wiedergr\[UDoubleDot]ndung Israels den 14. 5.1948 an. Dieser \
Tag erh\[ADoubleDot]lt die Nummer ",
  Cell[BoxData[
      \(6\)]],
  ", da es sich um einen Freitag handelt."
}], "Text"],

Cell[TextData[{
  "Das Sonnenjahr besitzt immer ",
  Cell[BoxData[
      \(12\)]],
  " Monate im Jahr, wodurch Bereichsverletzungen die Jahreszahl entsprechend \
ver\[ADoubleDot]ndern."
}], "Text"],

Cell["\<\
Es resultiert folgendes Programm, um aus einem Gregorianischen Datum eine \
Zeitdifferenz in Tagen zu bestimmen:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Protect[\ GregorianSolarYearDay\ ]\ ; \n
    \(Function[\n\tClear[\ GregorianSolarYearDay\ ]\ ; \n\t\n\t
        GregorianSolarYearDay::usage = \n\t
          "\<GregorianSolarYearDay[{year, month, day, ..}] gives the number \
of days\>"\ <>\n\t\t
            "\< since Friday, May 14th, 1948 (Gregorianic system)\>"\ <>\n\t\t
            "\< where Friday is number six.\>"\ ; \n\t\n\t
         (*************************************************************) \n
        \t\tGregorianSolarYearDay[
            \ {\ year_Integer\ , month_Integer\ , day_Integer\ , \n
              \t\t\t\ ___Integer\ }\ ] := \n\t
           (*************************************************************) \n
          \tBlock[\ {\ yearnew\ , \ \ 
               (*\ the\ year\ `0`\ does\ not\ \(exist!\)\ *) \n\t\t\tmonthnew
              \ , \n\t\t\tresult = 6\ \ \  (*\ Friday\ *) \n\t\t}\ , \n\t\n
            \t\t (*\ Preparation : \ *) \n\t\t
             (*\(--\(--\(--\(---\)\)\)\)*) \n\t\t
            yearnew\  = \ 
              year\  + \ Floor[\ \((month\  - \ 1)\)\ /\ 12\ ] + \ 
                \((1 - Sign[2  year + 1])\)/2; \n\t\t
            monthnew\  = \ Mod[\ month\  - 1\ , \ 12\ ] + 1\ ; \n\t\t\n\t\t
             (*\ Orientation\ to\ May\ 14  th, \ \(1948 : \)\ *) \n\t\t
             (*\(--\(--
                  \(--\(--\(--\(--\(--\(--\(--\(---\)\)\)\)\)\)\)\)\)\)*) \n
            \t\tresult\  += \ 
              day\  - \ 14\  + \ 
                \(MonthlyDaySum[\ 5\ ]\)\[LeftDoubleBracket]\ monthnew\ 
                  \[RightDoubleBracket]\ ; \n\t\t
            result\  += \((yearnew - 1948)\)*\ 365\ ; \n\t\t
            result\  += Floor[\((yearnew - 1948)\)/4]\ ; \n\t\t
            result\  -= \ Floor[\((yearnew - 1900)\)/100]\ ; \n\t\t
            result += Floor[\((yearnew - 1600)\)/400]\ ; \n\t\n\t\t
             (*\ Before\ Intercalary\ Day\ within\ a\ Leap - \(Year : \)\ *) 
              \n\t\t (*
              \(--\(--\(--
                    \(--\(-\(--
                          \(--\(--
                              \(--\(--
                                  \(--\(--
                                      \(--\(----
                                        \)\)\)\)\)\)\)\)\)\)\)\)\)\)*) \t\t\n
            \t\tIf[\ Mod[\ yearnew\ , \ 4\ ]\ \  === \ \ 0\ \ \  && \ \ \ 
                monthnew\  < \ 3\ , \n\t\t\tresult\  -= \ 1\ ; \n\t\t\t
              If[\ Mod[\ yearnew\ , \ 100\ ]\ \  === \ \ 0\ \ \  && \ \ \ 
                  Mod[\ yearnew\ , \ 400\ ]\ \  =!= \ \ 0\ , \n\t\t\t\t
                \(result\  += \ 1\ ; \)\n\t\t\t]\ ; \n\t\t]\ ; \n\t\t\n\t\t
             (*\ Result : \ *) \n\t\t (*\(--\(---\)\)*) \n\t\tresult\n\t]\ ; 
        \n\t\n\tProtect[\ #\ ]\n]\)[\ Unprotect[\ GregorianSolarYearDay\ ]\ ]
      \)], "Input"],

Cell[BoxData[
    \({"GregorianSolarYearDay"}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Historische Kombination"
}], "Subsubsection"],

Cell["\<\
Die historische Kombination dieser drei Kalendersysteme ergibt folgendes \
Programm:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Protect[\ HistoricalSolarYearDay\ ]\ ; \n
    \(Function[\n\tClear[\ HistoricalSolarYearDay\ ]\ ; \n\t\n\t
        HistoricalSolarYearDay::usage = \n\t
          "\<HistoricalSolarYearDay[{year, month, day, ..}] gives the number \
of days\>"\ <>\n\t\t
            "\< since Friday, May 14th, 1948 (Gregorianic system) due to \
historical\>"\ <>\n\t\t
            "\< changes of calendar systems where Friday is number six.\>"\ ; 
        \n\t\n\t (************************************************************\
*) \n\t\tHistoricalSolarYearDay[
            \ {\ year_Integer\ , month_Integer\ , day_Integer\ , \n
              \t\t\t\ ___Integer\ }\ ] := \n\t
           (*************************************************************) \n
          \tBlock[\ {\ yearnew\ , \ \ 
               (*\ the\ year\ `0`\ does\ not\ \(exist!\)\ *) \n\t\t\tmonthnew
              \ , \n\t\t\tresult = 6\ \ \  (*\ Friday\ *) \n\t\t}\ , \n\t\n
            \t\t (*\ Preparation : \ *) \n\t\t
             (*\(--\(--\(--\(---\)\)\)\)*) \n\t\t
            yearnew\  = \ 
              year\  + \ Floor[\ \((month\  - \ 1)\)\ /\ 12\ ] + \ 
                \((1 - Sign[2  year + 1])\)/2; \n\t\t
            monthnew\  = \ Mod[\ month\  - 1\ , \ 12\ ] + 1\ ; \n\t\t\n\t\t
             (*\ Orientation\ to\ May\ 14  th, \ \(1948 : \)\ *) \n\t\t
             (*\(--\(--
                  \(--\(--\(--\(--\(--\(--\(--\(---\)\)\)\)\)\)\)\)\)\)*) \n
            \t\tresult\  += \ 
              day\  - \ 14\  + \ 
                \(MonthlyDaySum[\ 5\ ]\)\[LeftDoubleBracket]\ monthnew\ 
                  \[RightDoubleBracket]\ ; \n\t\t
            result\  += \((yearnew - 1948)\)*\ 365\ ; \n\t\t\t\n\t\t
             (*\ Julian\ Calendar\ since\ 45\ b.Chr. : \ *) \n\t\t
             (*\(--\(--
                  \(--\(--
                      \(-\(--\(-
                            \(--\(-\(--\(--\(---\)\)\)\)\)\)\)\)\)\)\)\)*) \n
            \t\tresult\  += Floor[\((Max[\(-45\), yearnew] - 1948)\)/4]\ ; \n
            \t\t\n\t\t
             (*\ Gregorian\ Calendar\ since\ 15.10 \( .1582 : \)\ *) \n\t\t
             (*\(--\(--
                  \(--\(--
                      \(--\(--
                          \(--\(--\(--\(--\(--\(---\)\)\)\)\)\)\)\)\)\)\)\)*) 
              \n\t\tresult\  -= \ 
              Floor[\((Max[1582, yearnew] - 1900)\)/100]\ ; \n\t\t
            result += Floor[\((Max[1582, yearnew] - 1600)\)/400]\ ; \n\t\t\t\n
            \t\t (*\ Historical\ Date\ \(Jump : \)\ *) \n\t\t
             (*\(--\(--\(--\(--\(--\(--\(---\)\)\)\)\)\)\)*) \n\t\t
            If[\ yearnew\  < \ 1582\ \ \  || \n\t\t\t\ \ \ 
                yearnew\ \  === \ \ 1582\ \ \  && \ \ \ 
                  monthnew\ \  < \ \ 10\ \ \  || \n\t\t\t\ \ \ 
                yearnew\ \  === \ \ 1582\ \ \  && \ \ \ 
                  monthnew\ \  === \ \ 10\ \ \  && \ \ \ day\ \  < \ \ 5\ , \n
              \t\t\t\(result\  += \ 10\ ; \)\n\t\t]\ ; \n\t\t\n\t\t
             (*\ Before\ Intercalary\ Day\ within\ a\ Leap - \(Year : \)\ *) 
              \n\t\t (*
              \(--\(--\(--
                    \(--\(-\(--
                          \(--\(--
                              \(--\(--
                                  \(--\(--
                                      \(--\(----
                                        \)\)\)\)\)\)\)\)\)\)\)\)\)\)*) \n\t\t
            If[\ yearnew\ \  > \ \ \(-45\)\ \ \  && \ \ \ 
                Mod[\ yearnew\ , \ 4\ ]\ \  === \ \ 0\ \ \  && \ \ \ 
                monthnew\  < \ 3\ , \n\t\t\tresult\  -= \ 1\ ; \n\t\t\t
              If[\ yearnew\ \  > \ \ 1582\ \ \  && \n\t\t\t\t\ \ \ 
                  Mod[\ yearnew\ , \ 100\ ]\ \  === \ \ 0\ \ \  && \ \ \ 
                  Mod[\ yearnew\ , \ 400\ ]\ \  =!= \ \ 0\ , \n\t\t\t\t
                \(result\  += \ 1\ ; \)\n\t\t\t]\ ; \n\t\t]\ ; \n\t\t\n\t\t
             (*\ Result : \ *) \n\t\t (*\(--\(---\)\)*) \n\t\tresult\n\t]\ ; 
        \n\t\n\tProtect[\ #\ ]\n]\)[\ Unprotect[\ HistoricalSolarYearDay\ ]\ ]
      \)], "Input"],

Cell[BoxData[
    \({"HistoricalSolarYearDay"}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Dieses Programm ist auch in QBASIC (",
  ButtonBox["[SW2003]",
    ButtonData:>"[SW2003]",
    ButtonStyle->"Hyperlink"],
  ", Funktion \"Wochentag\" im Programmteil \"HISTORIK.BAS\") verf\
\[UDoubleDot]gbar."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Vergleich"
}], "Subsubsection"],

Cell["\<\
Mit den vorhandenen Routinen ergeben sich unterschiedliche Tagessummen f\
\[UDoubleDot]r entsprechende Datierungen:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(datierungen = 
      \({HistoricalSolarYearDay[#], GregorianSolarYearDay[#], 
            JulianSolarYearDay[#], EgyptianSolarYearDay[#]}&\)/@{
          Date[\ ], {1949, 9, 12}, {1948, 5, 14}, {1948, 5, 1}, {1582, 10, 
            15}, {1582, 10, 14}, {1582, 10, 4}, {1517, 10, 31}, {955, 8, 
            10}, {30, 4, 9}, {1, 1, 1}, {0, 1, 1}, {\(-1\), 1, 1}, {\(-45\), 
            2, 29}, {\(-45\), 2, 28}, {\(-45\), 1, 1}, {\(-46\), 12, 31}, {
            \(-3761\), 9, 30}}; \n\tdatierungen // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"20018", "20018", "20031", "19519"},
            {"492", "492", "505", "6"},
            {"6", "6", "19", \(-480\)},
            {\(-7\), \(-7\), "6", \(-493\)},
            {\(-133519\), \(-133519\), \(-133509\), \(-133916\)},
            {\(-133520\), \(-133520\), \(-133510\), \(-133917\)},
            {\(-133520\), \(-133530\), \(-133520\), \(-133927\)},
            {\(-157234\), \(-157244\), \(-157234\), \(-157625\)},
            {\(-362587\), \(-362592\), \(-362587\), \(-362837\)},
            {\(-700566\), \(-700564\), \(-700566\), \(-700585\)},
            {\(-711256\), \(-711254\), \(-711256\), \(-711268\)},
            {\(-711622\), \(-711620\), \(-711622\), \(-711633\)},
            {\(-711622\), \(-711620\), \(-711622\), \(-711633\)},
            {\(-727634\), \(-727632\), \(-727634\), \(-727634\)},
            {\(-727635\), \(-727633\), \(-727635\), \(-727635\)},
            {\(-727693\), \(-727691\), \(-727693\), \(-727693\)},
            {\(-727694\), \(-727692\), \(-727694\), \(-727694\)},
            {\(-2083761\), \(-2084659\), \(-2084689\), \(-2083761\)}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell["\<\
Die zugeh\[ODoubleDot]rigen Wochentage (von Sonntag bis Samstag) ergeben sich \
wie folgt:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(Mod[# - 1, 7] + 1&\)/@datierungen // Transpose\) // MatrixForm\)], 
  "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
           
             {"5", "2", "6", "7", "6", "5", "5", "7", "6", "1", "7", "5", "5",
               "2", "1", "6", "5", "6"},
           
             {"5", "2", "6", "7", "6", "5", "2", "4", "1", "3", "2", "7", "7",
               "4", "3", "1", "7", "4"},
           
             {"4", "1", "5", "6", "2", "1", "5", "7", "6", "1", "7", "5", "5",
               "2", "1", "6", "5", "2"},
           
             {"3", "6", "3", "4", "1", "7", "4", "1", "1", "3", "2", "1", "1",
               "2", "1", "6", "5", "6"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell["\<\
Bei dieser Aufstellung ist unber\[UDoubleDot]cksichtigt, da\[SZ] ab dem \
1.1.1977 in Europa der Sonntag als siebter Tag der Woche gilt. Diese \
\[CapitalADoubleDot]nderung ist willk\[UDoubleDot]rlich und kommt dem \
Anliegen der Aufarbeitung anti-israelischer Gebaren in Europa nicht entgegen.\
\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Programme zur Errechnung eines Kalenderdatums"
}], "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Vorgehensweise"
}], "Subsubsection"],

Cell["\<\
Nun ist nach Kenntnis der Tagesdifferenz auch eine Umrechnung in ein zugeh\
\[ODoubleDot]riges Datum erforderlich. Der zugeh\[ODoubleDot]rige Algorithmus \
stellt eine interessante Form der Umkehr-Algebra dar.\
\>", "Text"],

Cell[TextData[{
  "Die Tagesdifferenz mu\[SZ] zu einem einheitlichen Referenzdatum vorliegen, \
wobei auch hier wieder der Tag der Wiedergr\[UDoubleDot]ndungs Israels bei \
Eingabe der Zahl ",
  Cell[BoxData[
      \(6\)]],
  " resultiert."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Zuordnung der Tage"
}], "Subsubsection"],

Cell["\<\
Die Zuordnung der Tage im Jahr erfolgt einheitlich unter \
Ber\[UDoubleDot]cksichtigung von Schaltjahren. Hierzu wird lediglich \
eingeteilt, wo in der folgenden Auflistung\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MonthlyDaySum[1]\)], "Input"],

Cell[BoxData[
    \({0, 31, 59, 90, 120, 151, 181, 212, 243, 273, 304, 334}\)], "Output"]
}, Open  ]],

Cell["die Anzahl der Tage auftritt:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Protect[\ FinishDate\ ]\ ; \n
    \(Function[\n\tClear[\ FinishDate\ ]\ ; \n\n\t
        FinishDate::usage = \n\t
          "\<FinishDate[ year , day , intercalary ] gives a complete date due \
to\>"\ <>\n\t\t"\< the Julian calendar system.\>"\ ; \n\t\n\t
         (********************************************) \n\t\t
        FinishDate[\ year_Integer\ , \ day_Integer?Positive\ , \n\t\t\t\ 
              intercalary_Integer?NonNegative\ ]\  /; \n\t\t
            day\  - \ Sign[\ intercalary\ ]\ \  \[LessEqual] \ 365\  := \n\t
           (********************************************) \n\t
          Block[\ {\n\t\t\tdaylist\ , \n\t\t\tmonth\n\t\t}\ , \n\t\t\n\t\t
             (*\ Attach\ to\ \(Month : \)\ *) \n\t\t
             (*\(--\(--\(--\(--\(----\)\)\)\)\)*) \n\t\t
            daylist\  = \ 
              \(Join@@{Take[#, 2], Take[#, \(-10\)] + Sign[\ intercalary\ ]}&
                  \)@\n\t\t\t\t\t\t\t\tMonthlyDaySum[1]\ ; \n\t\t
            month\  = \ 
              Length[\ DeleteCases[\n\t\t\t\t\t\t\t\t
                  NonPositive/@Sign[\ daylist\  - \ \((day - 1)\)\ ]\ , \ 
                  False\ ]\ ]\ ; \n\t\t\n\t\t
             (*\ Result\ without\ the\ Year\ \(\.b40\.b4 : \)\ *) \n\t\t
             (*\(--\(--\(--\(--\(--\(--\(--\(--\(---\)\)\)\)\)\)\)\)\)*) \n
            \t\t{\ year\  + \ Sign[Sign[\ year\ ] - 1]\ , \ month\ \ , \ 
              day\  - \ 
                daylist\[LeftDoubleBracket]\ month\ \[RightDoubleBracket]}\n
            \t]\ ; \n\t\n\tProtect[\ #\ ]\n]\)[\ Unprotect[\ FinishDate\ ]\ ]
      \)], "Input"],

Cell[BoxData[
    \({"FinishDate"}\)], "Output"]
}, Open  ]],

Cell["\<\
Diese Funktion wird von den einzelnen Kalender-Routinen aufgerufen.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". \[CapitalADoubleDot]gyptisches Sonnenjahr"
}], "Subsubsection"],

Cell["Es ergibt sich folgendes Programm:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Protect[\ EgyptianSolarYearDate\ ]\ ; \n
    \(Function[\n\tClear[\ EgyptianSolarYearDate\ ]\ ; \n\n\t
        EgyptianSolarYearDate::usage = \n\t
          "\<EgyptianSolarYearDate[ day ] gives the inverse function to\>"<>\n
            \t\t"\< EgyptianSolarYearDay[ ].\>"\ ; \n\t\n\t
         (************************************) \n\t\t
        EgyptianSolarYearDate[\ day_Integer\ ]\  := \n\t
           (************************************) \n\t
          \(FinishDate[\ 1948\  + \ Floor[\ #\ ]\ , \ 
                365 \((# - Floor[#])\) + 1\ , \ 0\ ]&\)@\n\t\t
            \((\((day + 498 - 13 + 128)\)/365)\)\ ; \n\n\tProtect[\ #\ ]\n]\)[
      \ Unprotect[\ EgyptianSolarYearDate\ ]\ ]\)], "Input"],

Cell[BoxData[
    \({"EgyptianSolarYearDate"}\)], "Output"]
}, Open  ]],

Cell["Das Referenzdatum lautet:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(EgyptianSolarYearDate[6]\)], "Input"],

Cell[BoxData[
    \({1949, 9, 12}\)], "Output"]
}, Open  ]],

Cell["Einige Proben ergeben:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(# == EgyptianSolarYearDay[EgyptianSolarYearDate[#]]&\)/@
        Range[\(-2000\), 1000] // Union\)], "Input"],

Cell[BoxData[
    \({True}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Julianisches Sonnenjahr"
}], "Subsubsection"],

Cell["Es ergibt sich folgendes Programm:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Protect[\ JulianSolarYearDate\ ]\ ; \n
    \(Function[\n\tClear[\ JulianSolarYearDate\ ]\ ; \n\n\t
        JulianSolarYearDate::usage = \n\t
          "\<JulianSolarYearDate[ day ] gives the inverse function to\>"<>\n
            \t\t"\< JulianSolarYearDay[ ].\>"\ ; \n\t\n\t
         (*********************************) \n\t\t
        JulianSolarYearDate[\ day_Integer\ ]\  := \n\t
           (*\(************\)*\(**************\)*****) \n\t
          Block[\ {\n\t\t\tgroup\ , \n\t\t\toffsetrest\ , \n\t\t\tyear\n\t\t}
              \ , \n\n\t\t (*\ Preparation : \ *) \n\t\t
             (*\(--\(--\(--\(---\)\)\)\)*) \t\n
            \t\t{year, offsetrest} = 
              \({1945 + 4  Min[Floor[#], 3], 1461 \((# - Min[Floor[#], 3])\)}&
                  \)@\n\t\t\t\t\t\t\t\t\t\t\t\t\t
                \((\((day + 1223 - 13)\)/1461)\)\ ; \n\t\t
            group = Min[Floor[offsetrest/365], 3]\ ; \n\t\t
            offsetrest\  -= \ 365  group\ ; \n\t\t\n\t\t (*\ Result : \ *) \n
            \t\t (*\(--\(---\)\)*) \n\t\t
            FinishDate[year + group, offsetrest + 1, Floor[group/3]]\n\t]\ ; 
        \n\n\tProtect[\ #\ ]\n]\)[\ Unprotect[\ JulianSolarYearDate\ ]\ ]\)], 
  "Input"],

Cell[BoxData[
    \({"JulianSolarYearDate"}\)], "Output"]
}, Open  ]],

Cell["Das Referenzdatum lautet:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(JulianSolarYearDate[6]\)], "Input"],

Cell[BoxData[
    \({1948, 5, 1}\)], "Output"]
}, Open  ]],

Cell["Einige Proben ergeben:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(# == JulianSolarYearDay[JulianSolarYearDate[#]]&\)/@
        Range[\(-2000\), 1000] // Union\)], "Input"],

Cell[BoxData[
    \({True}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Gregorianisches Sonnenjahr"
}], "Subsubsection"],

Cell["Es ergibt sich folgendes Programm:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Protect[\ GregorianSolarYearDate\ ]\ ; \n
    \(Function[\n\tClear[\ GregorianSolarYearDate\ ]\ ; \n\n\t
        GregorianSolarYearDate::usage = \n\t
          "\<GregorianSolarYearDate[ day ] gives the inverse function to\>"<>
            \n\t\t"\< GregorianSolarYearDay[ ].\>"\ ; \n\t\n\t
         (************************************) \n\t\t
        GregorianSolarYearDate[\ day_Integer\ ]\  := \n\t
           (************************************) \n\t
          Block[\ {\n\t\t\tgroup\ , \n\t\t\toffsetrest\ , \n\t\t\tyear\ , \n
              \t\t\tintercalary\n\t\t}\ , \n\n\t\t (*\ Preparation : \ *) \n
            \t\t (*\(--\(--\(--\(---\)\)\)\)*) \t\n
            \t\t{year, offsetrest} = 
              \({1601 + 400  Floor[#], 146097 \((# - Floor[#])\)}&\)@\n
                \t\t\t\t\t\t\t\t\t\t\t\t\t\((\((day + 126866)\)/146097)\)\ ; 
            \n\t\t\n\t\t (*\ 400 - Year\ \(Periode : \)\ *) \n\t\t
             (*\(--\(--\(--\(--\(--\(---\)\)\)\)\)\)*) \n\t\t
            group = Min[Floor[offsetrest/36524], 3]\ ; \n\t\t
            offsetrest -= 36524  group\ ; \n\t\tyear += 100  group\ ; \n\t\t
            intercalary = Floor[group/3]\ ; \n\t\t\n\t\t
             (*\ 100 - Year\ \(Periode : \)\ *) \n\t\t
             (*\(--\(--\(--\(--\(--\(---\)\)\)\)\)\)*) \n\t\t
            group = Min[Floor[offsetrest/1461], 24]\ ; \n\t\t
            offsetrest -= 1461  group\ ; \n\t\tyear += 4  group\ ; \n\t\t
            If[\ group\ \  === \ \ 24\ \ \  && \ \ \ offsetrest > 3*365\ , \n
              \t\t\tintercalary -= 1\ , \n\t\t\tintercalary = 0\n\t\t]\ ; \n
            \t\t\n\t\t (*\ 4 - Year\ \(Periode : \)\ *) \n\t\t
             (*\(--\(--\(--\(--\(---\)\)\)\)\)*) \n\t\t
            group = Min[Floor[offsetrest/365], 3]\ ; \n\t\t
            offsetrest\  -= \ 365  group\ ; \n\t\t\n\t\t (*\ Result : \ *) \n
            \t\t (*\(--\(---\)\)*) \n\t\t
            FinishDate[year + group, offsetrest + 1, 
              intercalary + Floor[group/3]]\n\t]\ ; \n\n\tProtect[\ #\ ]\n]\)[
      \ Unprotect[\ GregorianSolarYearDate\ ]\ ]\)], "Input"],

Cell[BoxData[
    \({"GregorianSolarYearDate"}\)], "Output"]
}, Open  ]],

Cell["Das Referenzdatum lautet:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(GregorianSolarYearDate[6]\)], "Input"],

Cell[BoxData[
    \({1948, 5, 14}\)], "Output"]
}, Open  ]],

Cell["Einige Proben ergeben:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(# == GregorianSolarYearDay[GregorianSolarYearDate[#]]&\)/@
        Range[\(-1000\), 1000] // Union\)], "Input"],

Cell[BoxData[
    \({True}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Historisches Sonnenjahr"
}], "Subsubsection"],

Cell["Es ergibt sich folgendes Programm:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Protect[\ HistoricalSolarYearDate\ ]\ ; \n
    \(Function[\n\tClear[\ HistoricalSolarYearDate\ ]\ ; \n\t\n\t
        HistoricalSolarYearDate::usage = \n\t
          "\<HistoricalSolarYearDate[ day ] gives the inverse function to\>"<>
            \n\t\t"\< HistoricalSolarYearDay[ ].\>"\ ; \n\t\t\n\t
         (************************************) \n\t\t
        HistoricalSolarYearDate[\ day_Integer\ ] := \n\t
           (************************************) \n\t
          Which[\ day\  <= \ HistoricalSolarYearDay[{\(-45\), 2, 28}]\ , \n
            \t\tEgyptianSolarYearDate[\ day\ ]\ , \n\t
            HistoricalSolarYearDay[{\(-45\), 2, 29}] \[LessEqual] day 
              \[LessEqual] HistoricalSolarYearDay[{1582, 10, 4}]\ , \n\t\t
            JulianSolarYearDate[\ day\ ]\ , \n\t
            HistoricalSolarYearDay[{1582, 10, 15}] \[LessEqual] day\ , \n\t\t
            GregorianSolarYearDate[\ day\ ]\n\t]\ ; \n\n\tProtect[\ #\ ]\n]\)[
      \ Unprotect[\ HistoricalSolarYearDate\ ]\ ]\)], "Input"],

Cell[BoxData[
    \({"HistoricalSolarYearDate"}\)], "Output"]
}, Open  ]],

Cell["Die Referenzdaten lauten:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(HistoricalSolarYearDay/@{{\(-45\), 2, 28}, {\(-45\), 2, 29}, {1582, 10, 
          4}, {1582, 10, 15}}\), 
    \(HistoricalSolarYearDate/@%\)}], "Input"],

Cell[BoxData[
    \({\(-727635\), \(-727634\), \(-133520\), \(-133519\)}\)], "Output"],

Cell[BoxData[
    \({{\(-45\), 2, 28}, {\(-45\), 2, 29}, {1582, 10, 4}, {1582, 10, 15}}\)], 
  "Output"]
}, Open  ]],

Cell["Einige Proben ergeben:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(# == HistoricalSolarYearDay[HistoricalSolarYearDate[#]]&\)/@
        Range[\(-727000\), \(-726000\)] // Union\)], "Input"],

Cell[BoxData[
    \({True}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(# == HistoricalSolarYearDay[HistoricalSolarYearDate[#]]&\)/@
        Range[\(-134000\), \(-133000\)] // Union\)], "Input"],

Cell[BoxData[
    \({True}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Anwendung"
}], "Subsubsection"],

Cell["\<\
Die jetzt verf\[UDoubleDot]gbaren Funktionen zur Datumsberechnung erm\
\[ODoubleDot]glichen eine individuelle Ber\[UDoubleDot]cksichtigung aller \
Datierungen, die von der r\[ODoubleDot]mischen Auslegung des Gregorianischen \
Kalenders abweichen. Lindau im Bodensee hatte etwa fast zwei Jahrhunderte \
lang zwei verschiedene Kalendersysteme, was auch bei der Diskussion \
historischer Aufzeichungen auf unerwartete Diskrepanzen f\[UDoubleDot]hren \
kann.\
\>", "Text"],

Cell[TextData[{
  "So ist bei Zinzendorf (evangelisch) der 13. 8.1727 (",
  ButtonBox["[M",
    ButtonData:>"[Muel1985]",
    ButtonStyle->"Hyperlink"],
  ButtonBox["\[UDoubleDot]",
    ButtonData:>"[Muel1985]",
    ButtonStyle->"Hyperlink"],
  ButtonBox["l1985]",
    ButtonData:>"[Muel1985]",
    ButtonStyle->"Hyperlink"],
  ", Seite 81) ein Sonntag:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\({JulianSolarYearDay[#], GregorianSolarYearDay[#]}&\)@{1727, 8, 13}\), 
  
    \(\(Mod[# - 1, 7] + 1&\)/@%\)}], "Input"],

Cell[BoxData[
    \({\(-80611\), \(-80622\)}\)], "Output"],

Cell[BoxData[
    \({1, 4}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Die Schlacht auf dem Lechfeld fand am 10. 8.955 von Ulm aus statt. Vor der \
Schlacht fand eine Messe statt. (",
  ButtonBox["[Ple1982]",
    ButtonData:>"[Ple1982]",
    ButtonStyle->"Hyperlink"],
  ", Seite 268-273) War also Sonntag?"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\({JulianSolarYearDay[#], GregorianSolarYearDay[#]}&\)@{955, 8, 10}\), 
    \(\(Mod[# - 1, 7] + 1&\)/@%\)}], "Input"],

Cell[BoxData[
    \({\(-362587\), \(-362592\)}\)], "Output"],

Cell[BoxData[
    \({6, 1}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Durch die Gregorianische Reform wurden auch vereinzelt Datierungen des \
Mittelalters r\[UDoubleDot]ckwirkend umge\[ADoubleDot]ndert, etwa die \
Hinrichtung von Jan Hus in Konstanz, die an einem Sonntag (",
  ButtonBox["[Pub1989]",
    ButtonData:>"[Pub1989]",
    ButtonStyle->"Hyperlink"],
  ", Text zu Abbildung 6) stattgefunden habe, aber auf Samstag (7.Wochentag) \
datiert, n\[ADoubleDot]mlich den 6. Juli 1415 (",
  ButtonBox["[M",
    ButtonData:>"[Muel1985]",
    ButtonStyle->"Hyperlink"],
  ButtonBox["\[UDoubleDot]",
    ButtonData:>"[Muel1985]",
    ButtonStyle->"Hyperlink"],
  ButtonBox["l1985]",
    ButtonData:>"[Muel1985]",
    ButtonStyle->"Hyperlink"],
  ", Seite 61):"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\({#, Mod[# - 1, 7] + 1, GregorianSolarYearDate[#]}&\)@
      JulianSolarYearDay[{1415, 7, 6}]\)], "Input"],

Cell[BoxData[
    \({\(-194607\), 7, {1415, 7, 15}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Der Palmsonntag (24.M\[ADoubleDot]rz 1415) dieses Jahres wird korrekt (",
  ButtonBox["[M",
    ButtonData:>"[Muel1985]",
    ButtonStyle->"Hyperlink"],
  ButtonBox["\[UDoubleDot]",
    ButtonData:>"[Muel1985]",
    ButtonStyle->"Hyperlink"],
  ButtonBox["l1985]",
    ButtonData:>"[Muel1985]",
    ButtonStyle->"Hyperlink"],
  ", Seite 56) angegeben:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\({#, Mod[# - 1, 7] + 1}&\)@HistoricalSolarYearDay[{1415, 3, 24}]\)], 
  "Input"],

Cell[BoxData[
    \({\(-194711\), 1}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Der Gedenkstein in Konstanz erw\[ADoubleDot]hnt auch die Hinrichtung des \
\"Hieron\[YDoubleDot]mus von Prag am 30.Mai (7.Juni) 1416\" (",
  ButtonBox["[Pub1989]",
    ButtonData:>"[Pub1989]",
    ButtonStyle->"Hyperlink"],
  ", Abbildung 9), wobei ein Umrechnungsfehler vorliegt:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\({#, Mod[# - 1, 7] + 1, GregorianSolarYearDate[#]}&\)@
      JulianSolarYearDay[{1416, 5, 30}]\)], "Input"],

Cell[BoxData[
    \({\(-194278\), 7, {1416, 6, 8}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Der zeitliche \[CapitalUDoubleDot]bergang ins Mittelalter ist allerdings \
bei der vorgestellten Rechnung korrekt, da der Reformationstag Luthers (",
  ButtonBox["[Rie1983]",
    ButtonData:>"[Rie1983]",
    ButtonStyle->"Hyperlink"],
  ", Kapitel \"Martin Luther\", Seite 44) gewi\[SZ] auf einen Samstag f\
\[ADoubleDot]llt, weil am n\[ADoubleDot]chsten Tag wegen Allerheiligen und \
Sonntag besonders viele Gottesdienstbesucher zu erwarten waren:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\({JulianSolarYearDay[#], HistoricalSolarYearDay[#]}&\)@{1517, 10, 31}
        \), 
    \(\(Mod[# - 1, 7] + 1&\)/@%\)}], "Input"],

Cell[BoxData[
    \({\(-157234\), \(-157234\)}\)], "Output"],

Cell[BoxData[
    \({7, 7}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Auch die Auferstehung Jesu Christi wird auf Sonntag, den 9. 4.30 datiert \
(",
  ButtonBox["[Rusk1974]",
    ButtonData:>"[Rusk1974]",
    ButtonStyle->"Hyperlink"],
  ", 6. Absatz):"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\({HistoricalSolarYearDay[#], JulianSolarYearDay[#]}&\)@{30, 4, 9}\), 
    \(\(Mod[# - 1, 7] + 1&\)/@%\)}], "Input"],

Cell[BoxData[
    \({\(-700566\), \(-700566\)}\)], "Output"],

Cell[BoxData[
    \({1, 1}\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ". Anwendung"
}], "Section"],

Cell["\<\
Um historische Sternl\[ADoubleDot]ufe korrekt diskutieren zu \
k\[ODoubleDot]nnen, ist die genaue Kenntnis des zugeh\[ODoubleDot]rigen \
Kalendersystems eine zwingende Voraussetzung.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(<< Astronomer`HomeSite`; \)\)], "Input"],

Cell[BoxData[
    \("Astronomer is Copyright (c) 1997 Stellar Software"\)], "Print"]
}, Open  ]],

Cell["Auch f\[UDoubleDot]r die Lage Rom", "Text"],

Cell[BoxData[
    \(\(SetLocation[GeoLongitude\  -> \ 12.5*Degree, \n
      \ \ \ \ \ \ \ \ \ \ \ \ GeoLatitude\ \  -> \ 41.8*Degree, \n
      \ \ \ \ \ \ \ \ \ \ \ \ GeoAltitude\ \  -> \ 0.02*KiloMeter, \n
      \ \ \ \ \ \ \ \ \ \ \ \ TimeZone\ \ \ \ \  -> \ 2]; \)\)], "Input"],

Cell[TextData[{
  "ist beim ",
  StyleBox["Scientific Astronomer",
    FontSlant->"Italic"],
  " vorerst kein Datumssprung um zehn Tage ber\[UDoubleDot]cksichtigt, wie am \
Mondlauf (au\[SZ]en am Rand eingezeichnet) sofort zu erkennen ist:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(SolarSystemPlot[{1582, 10, #}, Distance \[Rule] 2  AU]&\)/@{4, 15}; 
    \)\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.227273 0.5 0.227273 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 .5 m
.5 .5 .45455 0 365.73 arc
F
.47698 .04604 m
.47698 .04604 .01818 0 365.73 arc
F
% Start of gray image
p
.46426 .03331 translate
.02545 .02545 scale
16 string
16 16 8 [16 0 0 16 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00000000193366664C33331900000000
0000001980B3808066664C3319000000
00000080B3664C66804C4C4C33190000
00006699664C4C666633334C4C331900
004C8080664C4C4C80334C3333331919
00808080668080664C4C4C3333333319
008080808099994C6666804C4C4C3319
1980668099998066668080994C4C3333
33996666808080668080808080333333
19B380666680668066808080664C3333
0099B3809966804C4C808066804C4C19
0080B3B380668080808080804C4C3319
0000B3B3B3808080808080664C331900
000019B399808080808080664C330000
00000000808080808080804C33000000
000000000019668080804C0000000000
pop
P
% End of image
gsave
.97727 .5 -69 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
69 11.5 translate
90 rotate
-69 -11.5 translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
69.000000 14.625000 moveto
(h) show
75.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.96101 .62353 -72 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
72 11.5 translate
105 rotate
-72 -11.5 translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Psc) show
81.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.91333 .73864 -69 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
69 11.5 translate
120 rotate
-69 -11.5 translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
69.000000 14.625000 moveto
(h) show
75.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.83748 .83748 -72 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
72 11.5 translate
135 rotate
-72 -11.5 translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Ari) show
81.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.73864 .91333 -69 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
69 11.5 translate
150 rotate
-69 -11.5 translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
69.000000 14.625000 moveto
(h) show
75.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.62353 .96101 -72 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
72 11.5 translate
165 rotate
-72 -11.5 translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Tau) show
81.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.5 .97727 -69 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
69 11.5 translate
180 rotate
-69 -11.5 translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
69.000000 14.625000 moveto
(h) show
75.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.37647 .96101 -72 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
72 11.5 translate
195 rotate
-72 -11.5 translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Gem) show
81.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.26136 .91333 -69 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
69 11.5 translate
210 rotate
-69 -11.5 translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(8) show
69.000000 14.625000 moveto
(h) show
75.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.16252 .83748 -72 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
72 11.5 translate
225 rotate
-72 -11.5 translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Cnc) show
81.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.08667 .73864 -72 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
72 11.5 translate
240 rotate
-72 -11.5 translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
75.000000 14.625000 moveto
(h) show
81.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.03899 .62353 -72 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
72 11.5 translate
255 rotate
-72 -11.5 translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Leo) show
81.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.02273 .5 -72 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
72 11.5 translate
270 rotate
-72 -11.5 translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(12) show
75.000000 14.625000 moveto
(h) show
81.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.03899 .37647 -72 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
72 11.5 translate
285 rotate
-72 -11.5 translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Vir) show
81.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.08667 .26136 -72 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
72 11.5 translate
300 rotate
-72 -11.5 translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(14) show
75.000000 14.625000 moveto
(h) show
81.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.16252 .16252 -72 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
72 11.5 translate
315 rotate
-72 -11.5 translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Lib) show
81.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.26136 .08667 -72 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
72 11.5 translate
330 rotate
-72 -11.5 translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(16) show
75.000000 14.625000 moveto
(h) show
81.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.37647 .03899 -72 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
72 11.5 translate
345 rotate
-72 -11.5 translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Sco) show
81.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.5 .02273 -72 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
72 11.5 translate
360 rotate
-72 -11.5 translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(18) show
75.000000 14.625000 moveto
(h) show
81.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.62353 .03899 -72 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
72 11.5 translate
15 rotate
-72 -11.5 translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Sgr) show
81.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.73864 .08667 -72 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
72 11.5 translate
30 rotate
-72 -11.5 translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
75.000000 14.625000 moveto
(h) show
81.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.83748 .16252 -72 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
72 11.5 translate
45 rotate
-72 -11.5 translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Cap) show
81.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.91333 .26136 -72 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
72 11.5 translate
60 rotate
-72 -11.5 translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(22) show
75.000000 14.625000 moveto
(h) show
81.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.96101 .37647 -72 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
72 11.5 translate
75 rotate
-72 -11.5 translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Aqr) show
81.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
1 1 0 r
1 Mabswid
.5 .5 m
.05269 .41922 L
s
0 1 1 r
.5 .5 m
.41922 .94731 L
s
gsave
.45961 .72365 -87 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 1.000000 1.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 1.000000 1.000000 setrgbcolor
(Morning) show
110.187500 14.625000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 1.000000 1.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Helvetica-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Helvetica-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Helvetica-Bold
grestore
1 0 0 r
.58078 .05269 m
.5 .5 L
s
gsave
.54039 .27635 -86.5 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(Evening) show
109.375000 14.625000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Helvetica-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Helvetica-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Helvetica-Bold
grestore
1 g
gsave
.5 .87727 -94 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 1.000000 1.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 1.000000 1.000000 setrgbcolor
(1582) show
85.000000 14.625000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 1.000000 1.000000 setrgbcolor
(-) show
91.375000 14.625000 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 1.000000 1.000000 setrgbcolor
(Oct) show
106.937500 14.625000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 1.000000 1.000000 setrgbcolor
(-) show
113.312500 14.625000 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 1.000000 1.000000 setrgbcolor
(04) show
124.312500 14.625000 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 1.000000 1.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Helvetica
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Helvetica
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Helvetica
grestore
% Start of colorimage (RGB)
p
.43802 .74675 translate
.02182 .02182 scale
48 string
16 16 8 [16 0 0 16 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000190000001900190000000000000000000000000000\
000000000000000000
0000000000000000001900001900001919193333333366664C4C4C4C4C4C191919000000000000\
000000000000000000
00000000000000001919000033996680808099CC99CCCC66CCCC66CCCC996699664C4C4C000000\
000000000000000000
000000000000000000669999808080CCFF66FFCC66CCCC99CCFF99CCCC66999966808080003333\
000000000000000000
0000000000004C4C4CB3B3B3FFCC66CCCC66808080CCCC66CCCC66996666669966336666666666\
003333000000000000
00000000000066CC99CCCC99CCCC66CCCC99666666666666999966336666666666666666669966\
4C4C4C000000000000
000000191919999999FFCC66FFFF99FFCC66CCCC666699664C4C4C666666666666669933808080\
666666000000000000
000000003333999999CCCC66FFCC99FFFF66FFCC66B3B3B3669933808080808080808080669933\
4C4C4C191919000000
000000191919808080CCCC66FFCC66FFCC99FFCC66CCCC66999966669966CC9933808080666666\
4C4C4C000019000000
000000190000808080CC9966CCCC66CCCC66CC99668080808080809999339999666699334C4C4C\
333333000000000000
000000000000333300808080B3B3B3CC99664C4C4C9999666666338080808080806666664C4C4C\
003333000000000000
0000000000000000194C4C4C6666333366668080806699336666668080804C4C4C4C4C4C191919\
000000000000000000
0000000000000000000019004C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C191919000000\
000000000000000000
000000000000000000000000000000191919191919333333003333191919000019000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
pop
P
% End of image
1 1 0 r
.02 w
.2767 .45967 Mdot
1 1 .8 r
.014 w
.25359 .62135 Mdot
.7 .9 .7 r
.005 w
.22711 .51702 Mdot
.25 .75 1 r
.014 w
.5 .5 Mdot
% Start of colorimage (RGB)
p
1.39636 .48727 translate
.02546 .02546 scale
42 string
14 14 8 [14 0 0 14 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000
000000000000000000000000000000000000190000190000190000001900000000000000000000\
000000
0000000000000000001900001919196666336666336699336666334C4C4C191919000000000000\
000000
000000000000191919996633999966999966B3B3B3999966CCCC669999338080804C4C4C000000\
000000
19000019191966663399996699996699CC99CCCC66CCCC6699CC66CCCC9999CC669999664C4C4C\
000000
000000666666999966B3B3B3CCCC99CCCC99CCFFCCCCCCCCCCFF99CCCC99CCCC9999CC99996666\
001900
191919663300996666999933999933CCCC66CC9966CCCC66CC9933CC996699CC66CC6666669933\
333333
191919996633999966CCCC66CCCC99CCCC66CCFF66CCCC66CCFF99CCCC66CCCC66CCCC66999933\
4C4C4C
330000666633CC9933CCCC66CCCC66CCCC66CCCC66CCCC66CCCC66CCFF66CCCC66CCCC6699CC33\
4C4C4C
190000666633999966CCCC66CCCC66CCCC99CCFF66CCCC99FFFF66CCCC99CCFF99CCCC66808080\
003300
00190033333399999999CC9999CCCCCCFF99CCCCCCCCFF99CCCC99CCFF99CCCC9999CC994C4C4C\
190000
00000019000033663380808099CC6699CC99CCCC99CCFF9999CC99CCCC9999CC99669966191919\
001900
0000000019001900001919196666338080806699666699669999666699664C4C4C001900001900\
000000
000000000000000000001900000000190000333300191919191919001900001900000000000000\
000000
pop
P
% End of image
% Start of colorimage (RGB)
p
1.39636 .48727 translate
.02546 .02546 scale
42 string
14 14 8 [14 0 0 14 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000
190000333333999966999999999966333333191919190000000000000000000000000000000000\
000000
4C4C4CCCCC99808080333300191919999966CCCC669999336666334C4C4C190000000000000000\
000000
336633CCCC994C4C4C000000669933FFFF99CCFF99FFFF99FFFF9999996699CC99666633000000\
000000
190000808080CCCC99191919CC9966CCFF99FFCC99FFFF99CCFF99CCCC99190000CCCC99808080\
001900
0000000019004C4C4CB3B3B399CC99CCCC99FFFF99FFFF99FFFF999999660019004C4C4CCCCC99\
4C4C4C
000000000000000000190000666633B3B3B3CCCC99CCCC99B3B3B36666004C4C4CCCCC9999CC99\
4C4C4C
0000000000000000000000000000000000001919194C4C4C666633808080999966666666333300\
000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/1P00`40o`000?l0003ooooook7oool0
0?oooonaoooo003ooooo/Oooo`00oooook7oool00?oooonaoooo003ooooo/Oooo`00oooook7oool0
0<coool500000oooo`<00006oooo0`000004oooo000000000000c?ooo`00c_ooo`030000oooooooo
00;oool01@000?ooooooooooo`000006oooo00D0003oooooooooool00000cOooo`00c_ooo`030000
oooooooo00;oool01@000?ooooooooooo`000006oooo00D0003oooooooooool00000cOooo`00c_oo
o`030000oooooooo00;oool01@000?ooooooooooo`000006oooo00D0003oooooooooool000007_oo
o`030000oooo00000:coool00:Woool200008oooo`030000oooooooo00?oool300001oooo`800002
oooo00<0003oooooool07?ooo`8000000oooo`000?ooo`06oooo0P000:;oool00:Soool010000?oo
ooooo`0002;oool00`000?ooooooo`02oooo00D0003oooooooooool000001_ooo`040000oooo0000
00007_ooo`030000oooooooo00;oool00`000?ooooooo`06oooo00<0003oooooool0Woooo`00X?oo
o`@00003oooo00<0003oooooool00_ooo`030000oooooooo01ooool00`000?ooooooo`02oooo00D0
003oooooooooool000001_ooo`030000oooooooo02Goool00`000?ooooooo`06oooo00<0003ooooo
ool0W_ooo`00Woooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool06Ooo
o`X000000oooo`000?ooo`02oooo00<0003oooooool01?ooo`030000oooooooo02Coool00`000?oo
ooooo`02oooo0`0000;oool00`000?ooooooo`2Noooo002Foooo0`0000Goool00`000?ooooooo`05
oooo00<0003oooooool00oooo`030000oooooooo01Soool3000000LI6AVc/k>0P820P800001<C4`c
<c<01P0000Koool200008Oooo`D00004oooo00L0003oooooooooool0003oool000000oooo`80002K
oooo002Doooo0P0000?oool00`000?ooooooo`02oooo00<0003oooooool01_ooo`030000oooooooo
00;oool00`000?ooooooo`0Hoooo0`000004P820IVIVC4a<IVIV0da<C0036ATI0000000002coool0
0`000?ooooooo`06oooo00<0003oooooool00_ooo`030000oooooooo00Coool30000V?ooo`00UOoo
o`030000oooooooo00;oool01@000?ooooooooooo`000004oooo00<0003oooooool00_ooo`@0000J
oooo0P000003C4a<P820P82000=<C4`013<c<da<C3<c<c<c<`8I6AT/oooo00<0003oooooool01_oo
o`030000oooooooo00;oool00`000?ooooooo`03oooo00<0003oooooool0VOooo`00U?ooo`030000
oooooooo00?oool01@000?ooooooooooo`000004oooo0P00027oool200001H20P003IVIVC4a<C4a<
00<c<c<00aTI6@000?ooo`0Zoooo0P000003oooo0000000000Coool00`000?ooooooo`02oooo00<0
003oooooool00oooo`030000oooooooo09Woool009Soool200001Oooo`@0000Roooo0`000006P820
IVIVP820VIVIP820IVIV0X20P005VIVIC4a<<c<c<c<c000002goool00`000?ooo`000005oooo1000
00Koool00`000?ooooooo`2Ioooo002Goooo00<0003oooooool0:oooo`<000001K>c/h20P6IVIX20
P6IVIP04P82000A<C4`c<c<c<c<0000hoooo0P0000Goool00`000?ooooooo`2Ioooo002Foooo00<0
003oooooool00_ooo`030000oooooooo02Ooool3000000JIVIVc/k>0P81VIVJ0P81<C4`2P82000AV
IVI<C4a<C4`I6ATB0000;?ooo`8000000oooo`000?ooo`2Ioooo002Foooo00<0003oooooool00_oo
o`030000oooooooo027oool:00000[>c/`F0P8000fIVIS<c<aTI6@0L00009oooo`80002Hoooo002G
oooo100001cooolB000000<I6AVc/k>0P8001820P003IVIV<c<c000002@00003oooo00?o003ooooo
ool0/oooo`00/?oooa/000001ATI6FIVIX20P820P4a<C00Z000000?o003oooooool0/oooo`00Zooo
odl000000ol00000000000060000[Oooo`00ZOoooe0000000ol00000000000090000Zoooo`00Y?oo
oeD000000ol000000000000>0000Y_ooo`00X?oooeT000000ol000000000000B0000X_ooo`00Mooo
o`80000TooooG0000003o`000000000001D0000Toooo0P0007Woool007Koool00`000?ooo`00000R
ooooGP000003o`000000000001L0000Roooo00<0003oool00000N?ooo`00M?ooo`030000oooooooo
00;oool00`000?ooooooo`0JooooH`000003o`000000000001`0000Moooo00<0003oooooool00P00
07Koool007?oool200001?ooo`030000oooooooo01SooomT000000?o0000000000007`0001_oool0
1@000?ooooooooooo`00001foooo001_oooo00<0003oooooool00_ooo`030000oooooooo00?oool0
0`000?ooooooo`0EooooIP000003o`00000000000240000Ioooo00<0003oooooool0N?ooo`00K_oo
o`030000oooo000000Coool00`000?ooooooo`02oooo00<0003oooooool04_ooofT000000ol00000
0000000T00005oooo`030000oooooooo07Ooool006goool01@000?ooooooooooo`000003oooo00D0
003oool0003oool000004oooof/000000ol000000000000V00004?ooo`030000oooooooo00;oool0
0`000?ooooooo`04oooo0`00073oool006goool00`000?ooooooo`02oooo00L0003oooooooooool0
003oool000004?ooofl000000ol000000000000Z00003?ooo`030000oooooooo00;oool00`000?oo
ooooo`03oooo00D0003oooooooooool00000Koooo`00KOooo`030000oooooooo00;oool00`000?oo
ooooo`02oooo00<0003oooooool03?ooog4000000ol000000000000^00002_ooo`050000oooooooo
oooo000000Coool00`000?ooooooo`02oooo00D0003oooooooooool00000Joooo`00Ioooo`800004
oooo1@0000Goool00`000?ooooooo`0:ooooL`000003o`000000000003000009oooo0`0000Coool0
0`000?ooooooo`03oooo00<0003oooooool00_ooo`80001Yoooo001Voooo00<0003oooooool01Ooo
o`030000oooooooo00Ooool00`000?ooooooo`07ooooM@000003o`00000000000340000?oooo00<0
003oooooool00oooo`050000oooooooooooo000006_oool006Coool300001oooo`800004oooo00@0
003oooooool00009ooooMP000003o`00000000000380000>oooo00<0003oooooool00_ooo`030000
oooooooo00;oool00`000?ooooooo`02oooo00<0003oooooool0I?ooo`00I?ooo`030000oooo0000
00Woool500002oooogL000000ol000000000000d00003?ooo`030000oooooooo00;oool01@000?oo
ooooooooo`000005oooo0P0006Goool006Ooool00`000?ooooooo`0DooooN@000003o`0000000000
03H0000:oooo00D0003oooooooooool000001?ooo`030000oooooooo00;oool00`000?ooooooo`1U
oooo001Xoooo00<0003oooooool04?ooog/000000ol000000000000j00002?ooo`<00004oooo0P00
00Coool00`000?ooooooo`1Uoooo001Xoooo00<0003oooooool03_ooogd000000ol000000000000l
00003?ooo`040000oooooooo00000_ooo`030000oooooooo06Koool006Woool00`000?ooooooo`0;
ooooO`000003o`000000000003h00009oooo0P0000?oool20000JOooo`00J_ooo`030000oooooooo
00Sooon1000000?o000000000000@00007Ooool006Soool300002Ooooh8000000ol0000000000011
0000M_ooo`00Looooh8000000ol00000000000130000MOooo`00LOoooh@000000ol0000000000015
0000Loooo`00KoooohH000000ol00000000000170000LOooo`00KOooohP000000ol0000000000019
0000Koooo`00K?ooohT000000ol000000000001:0000K_ooo`00JoooohX000000ol000000000001;
0000KOooo`00JOoooh/000000ol000000000001>0000Joooo`00Ioooohd000000ol000000000001?
0000J_ooo`00I_ooohh000000ol000000000001@0000JOooo`00IOooohl000000ol000000000001B
0000Ioooo`00Hooooi4000000ol000000000001D0000IOooo`00H_oooi4000000ol000000000001F
0000I?ooo`00BOooo`<0000EooooTP000003o`000000000005L0001Soooo0018oooo00D0003ooooo
ooooool000004_oooi@000000ol000000000001I00004_ooo`@0001;oooo0017oooo00<0003ooooo
ool00oooo`030000oooooooo00kooonE000000?o000000000000FP00013oool00`000?ooooooo`02
oooo00<0003oooooool0B?ooo`00A_ooo`800005oooo00<0003oooooool03OoooiH000000ol00000
0000001K00003_ooo`030000oooooooo00Coool00`000?ooooooo`17oooo0015oooo00<0003oool0
00001Oooo`030000oooooooo00_ooonH000000?o000000000000G@0000_oool00`000?ooooooo`05
oooo00<0003oooooool0Aoooo`00A?ooo`050000oooooooooooo000000Coool00`000?ooooooo`0:
ooooV0000003o`000000000005l0000:oooo00<0003oooooool01Oooo`030000oooooooo04Ooool0
04?oool00`000?ooooooo`03oooo00@0003oool00000000<ooooV@000003o`000000000006000009
oooo00<0003oooooool02?ooo`800015oooo0012oooo00<0003oooooool01Oooo`030000oooooooo
00[ooonK000000?o000000000000H@0000Soool00`000?ooooooo`07oooo00@0003oooooool00014
oooo0011oooo00<0003oool000001oooo`030000oooooooo00SooonL000000?o000000000000HP00
00Soool00`000?ooooooo`06oooo00D0003oooooooooool00000@oooo`00@?ooo`050000oooooooo
oooo000000Ooool00`000?ooooooo`06ooooW@000003o`000000000006@00007oooo0`0000Goool0
1@000?ooooooooooo`000004oooo00<0003oooooool0??ooo`00AOooo`030000oooooooo00Coool0
0`000?ooooooo`06ooooW0000003o`000000000006H00007oooo00<0003oooooool00_ooo`040000
oooooooo00000_ooo`<00003oooo00<0003oooooool0>oooo`00A_ooo`030000oooooooo00_ooonM
000000?o000000000000IP0000coool01`000?ooooooooooo`000?ooo`000004oooo00<0003oool0
0000??ooo`00?_ooo`030000oooooooo00Goool00`000?ooooooo`09ooooW`000003o`0000000000
06P0000;oooo00D0003oooooooooool000001?ooo`030000oooooooo03goool003goool00`000?oo
o`000005oooo00<0003oooooool00P0000OooonP000000?o000000000000J@0000_oool300001?oo
o`80000ooooo000loooo00D0003oooooooooool000001oooo`030000oooooooo00GooonQ000000?o
000000000000JP00013oool010000?ooooooo`0003koool003_oool00`000?ooooooo`0AooooXP00
0003o`000000000006/0000>oooo00<0003oooooool00_ooo`030000oooooooo03_oool003[oool0
0`000?ooo`00000AooooXP000003o`000000000006d0000;oooo0P0000Goool00`000?ooooooo`0k
oooo000joooo00@0003oooooool0000>ooooY0000003o`000000000006h0000;oooo00<0003ooooo
ool00oooo`030000oooooooo03_oool003koool00`000?ooooooo`0;ooooY0000003o`0000000000
06l0000;oooo00<0003oooooool00_ooo`030000oooooooo03_oool003ooool00`000?ooooooo`09
ooooY@000003o`00000000000700000;oooo100003koool0043oool00`000?ooo`000007ooooYP00
0003o`00000000000740001<oooo0011oooo00<0003oooooool01OooojH000000ol000000000001c
0000Boooo`00@?ooo`030000oooooooo00GooonW000000?o000000000000M00004[oool004OooonX
000000?o000000000000M@0004Woool004OooonX000000?o000000000000MP0004Soool004KooonY
000000?o000000000000MP0004Soool004Cooon[000000?o000000000000N00004Koool004CooonZ
000000?o000000000000NP0004Goool004?ooon[000000?o000000000000N`0004Coool004;ooon/
000000?o000000000000O00004?oool0047ooon]000000?o000000000000O00004?oool0043ooon^
000000?o000000000000O@0004;oool003oooon^000000?o000000000000O`00047oool003oooon^
000000?o000000000000P000043oool003kooon_000000?o000000000000P000043oool003gooon`
000000?o000000000000P@0003ooool003cooona000000?o000000000000PP0003koool003cooona
000000?o000000000000P`0003goool003_ooona000000?o000000000000Q00003goool003[ooonb
000000?o000000000000Q@0003coool003Wooonc000000?o000000000000QP0003_oool002Ooool0
0`000?ooooooo`0?oooo/`000003o`000000000008L0000@oooo00<0003oooooool09oooo`009_oo
o`80000@oooo]0000003o`000000000008L0000?oooo00<0003oool00000:?ooo`00:?ooo`80000>
oooo/`000003o`000000000008T0000>oooo00<0003oool00000:?ooo`00:_ooo`030000oooooooo
00[ooond000000?o000000000000RP0000goool010000?ooooooo`0002Ooool002Coool00`000?oo
ooooo`04oooo00<0003oooooool02?oookD000000ol000000000002;00001oooo`030000oooooooo
00;oool00`000?ooooooo`0200009_ooo`009?ooo`800005oooo00<0003oooooool01ooookH00000
0ol000000000002;00001oooo`050000oooooooooooo000000?oool00`000?ooooooo`0Uoooo000S
oooo00@0003oooooool00003oooo00<0003oooooool02?oookH000000ol000000000002<00001_oo
o`050000oooooooooooo000002_oool002Ooool300002_oookL000000ol000000000002<00001_oo
o`050000oooooooooooo000002_oool002Woool200002?oookL000000ol000000000002>00001_oo
o`<00007oooo00<0003oooooool08_ooo`008_ooo`030000oooooooo00Koool00`000?ooooooo`04
oooo^0000003o`000000000008l0000>oooo00<0003oool000008oooo`008_ooo`<00006oooo00<0
003oooooool01?oookP000000ol000000000002@00003Oooo`030000oooo000002?oool0027oool0
0`000?ooooooo`0200002ooookT000000ol000000000000G00001_l007<0000=oooo00@0003ooooo
ool0000Roooo000Soooo00<0003oooooool00P0000Woooni000000?o0000000000005P0000So001c
00001oooo`030000oooooooo00;oool00`000?ooooooo`0200008Oooo`008oooo`030000oooooooo
00;oool00`000?ooooooo`05oooo^@000003o`000000000001L00003o`000`0000?o001b00001ooo
o`050000oooooooooooo000000?oool00`000?ooooooo`0Poooo000Roooo1@0000;oool00`000?oo
ooooo`04oooo^@000003o`000000000001d00003o`00L`0000Koool01@000?ooooooooooo`00000V
oooo000Woooo0`0000GooonG00002_l000D00003o`001`0000Go000400000ol000<00003o`000P00
00?o000200000ol000<00003o`00100000?o000010000?l00?l00?l007<00006oooo00D0003ooooo
ooooool000009_ooo`00;_oooiP0000:o`001@0000?o000600001ol000<00003o`000`0000?o0002
00000ol000800003o`000`0000?o000300002?l007@00006oooo0`0000Koool00`000?ooooooo`0N
oooo000Moooo00<0003oooooool03OoooiT0000:o`00100000Go000400000ol000<00003o`000P00
00?o000300000ol000800003o`000P0000?o000300000ol000800004o`0000<0003o003o00000_l0
07D0000=oooo0`0001ooool001coool00`000?ooooooo`0>ooooV@0000?o000;00001Ol000@00003
o`00200000?o000300000ol000800003o`000P0000?o000300000ol000800003o`000`0000?o001f
00002_ooo`80000Roooo000Loooo0P0000kooonJ00000ol000/00002o`0000<0003o003o00001000
00Wo000200000ol000<00003o`000P0000?o000200000ol000<00003o`000P0000?o000300000ol0
07H00009oooo00<0003oooooool08_ooo`006oooo`030000oooooooo0080000<ooooVP0000[o0003
00000ol000040000o`00o`00o`000`0000Wo000200000ol000<00003o`000P0000?o000200000ol0
00<00003o`000P0000?o000300000ol007L00004oooo00<0003oool000000P0000Goool00`000?oo
ooooo`0Loooo000Koooo00<0003oooooool00_ooo`030000oooooooo00SooonK00002_l000<00003
o`0000@0003o003o003o000300000ol000<00003o`000P0000?o000300000ol000800003o`000P00
00?o000300000ol000800003o`000`0000?o001g00001Oooo`040000oooooooo00001Oooo`80000M
oooo000Qoooo0P0000SooonK00002_l000800003o`000`0000?o000200000ol000<00003o`000P00
00Co000200000ol000800003o`000P0000Co000200000ol000800004o`0000<0003o003o00000_l0
07P00008oooo00<0003oooooool00P0001ooool002?oool200001Ooooi`00003o`002@0000?o0003
00000ol000<00007o`000`0000Wo000200000ol000800009o`000`0000So001h00002Oooo`80000Q
oooo000Soooo00<0003oooooool01?oooi`00003o`002@0000?o000300000ol000@00005o`001000
00?o00000`000?l00?l00002o`000`0000?o000200000ol000030000o`00o`0000;o000500000ol0
00040000o`00o`00o`00N00002coool002;oool00`000?ooooooo`04ooooW@0000[o000G000000?o
000000000000V`0002_oool002WooonM00002_l001L000000ol000000000000900000ol008l0000[
oooo000YooooW@0000[o000G000000?o0000000000002@0000?o002@0000:_ooo`00:?oookl00000
0ol000000000002L0000:_ooo`00:?oookl000000ol000000000002M0000:Oooo`009ooookl00000
0ol000000000002O0000:?ooo`009_oool0000000ol000000000002P00009oooo`009Ooool400000
0ol000000000002P00009oooo`009Ooool4000000ol000000000002Q00009_ooo`009?oool800000
0ol000000000002Q00009_ooo`009?oool8000000ol000000000002Q00009_ooo`008ooool800000
0ol000000000002S00009Oooo`008ooool8000000ol000000000002S00009Oooo`008ooool800000
0ol000000000002T00009?ooo`008_oool<000000ol000000000002T00009?ooo`008_oool<00000
0ol000000000002T00009?ooo`008_oool8000000ol000000000002U00009?ooo`008_oool800000
0ol000000000002V00008oooo`008Ooool<000000ol000000000002V00008oooo`008Ooool<00000
0ol000000000002V00008oooo`008?oool@000000ol000000000002W00008_ooo`008?oool@00000
0ol000000000002W00008_ooo`008?oool<000000ol000000000002Y00008Oooo`007ooool@00000
0ol000000000002Y00008Oooo`007ooool@000000ol000000000002Z00003_ooo`030000oooooooo
00ooool001koooo5000000?o000000000000ZP0000koool00`000?ooooooo`0?oooo000>oooo00<0
003oooooool00oooo`030000oooooooo00Ooooo5000000?o000000000000ZP0000goool00`000?oo
o`00000@oooo000>oooo00<0003oooooool00oooo`030000oooooooo00Koooo5000000?o00000000
0000[00000[oool200004oooo`003_ooo`030000oooooooo00;oool00`000?ooooooo`07ooooa@00
0003o`00000000000:`00006oooo00H0003oooooool0003oool0000Coooo000=oooo00<0003oool0
00000`0000[oooo5000000?o000000000000[00000Ooool200000oooo`030000oooo0000013oool0
00goool00`000?ooooooo`03oooo00<0003oooooool01oooolD000000ol000000000002/00001ooo
o`L000000oooo`000?ooo`0>oooo000Coooo00<0003oooooool01oooolD000000ol000000000002]
00003Oooo`80000?oooo000LooooaP000003o`00000000000:d0000Noooo000Looooa@000003o`00
000000000:h0000<oooo0P00013oool000coool200003OooolH000000ol000000000002_00002_oo
o`040000oooooooo00003oooo`003?ooo`030000oooooooo00coooo6000000?o000000000000[`00
00Woool00`000?ooooooo`02oooo00<0003oooooool03?ooo`003?ooo`80000=ooooaP000003o`00
000000000;000008oooo00<0003oooooool00_ooo`040000oooooooo00002oooo`003?ooo`030000
oooo000000800009ooooa`000003o`00000000000;000008oooo00<0003oooooool00_ooo`040000
oooooooo00002oooo`002oooo`030000oooooooo00?oool00`000?ooo`000006ooooaP000003o`00
000000000;400008oooo00<0003oooooool00_ooo`D0000:oooo000;oooo00<0003oooooool00ooo
o`040000oooooooo00001OooolH000000ol000000000002a00002Oooo`@00004oooo00<0003ooooo
ool02?ooo`004Oooo`030000oooooooo00Koooo6000000?o000000000000/@0000Woool00`000?oo
ooooo`0@oooo000Iooooa`000003o`00000000000;800008oooo00<0003oooooool04?ooo`006Ooo
olL000000ol000000000002b00003Oooo`030000oooooooo00_oool001Woooo7000000?o00000000
0000/P0000koool00`000?ooooooo`0:oooo000?oooo0`0000Ooooo6000000?o000000000000/`00
00Woool00`000?ooooooo`0300003?ooo`002Oooo`H00002oooo00<0003oooooool01OooolH00000
0ol000000000002d00002?ooo`<00002oooo00<0003oooooool02_ooo`002Oooo`800006oooo00<0
003oooooool01?ooolL000000ol000000000002d00002Oooo`030000oooooooo00;oool00`000?oo
ooooo`09oooo000;oooo00<0003oooooool02_ooolL000000ol000000000002d00002?ooo`030000
oooooooo00?oool00`000?ooooooo`09oooo000<oooo00<0003oooooool02?ooolP000000ol00000
0000002e00001oooo`030000oooooooo00ooool000goool2000000?oool0003oool01OooolL00000
0ol000000000002f00002?ooo`030000oooooooo00koool000ooool200001_ooolL000000ol00000
0000002f00006Oooo`003oooo`030000oooooooo00Goooo7000000?o000000000000]P0001Woool0
01Ooooo7000000?o000000000000]P0001Woool001Ooooo7000000?o000000000000]`0001Soool0
01Ooooo7000000?o000000000000]`0001Soool001Koool3ool0a0000003o`00000000000;P0000H
oooo000Foooo0`0000Koo`2n000000?o000000000000^00001Soool001Koool900001Ooo0;T00000
0ol000000000002h00006?ooo`005_ooo`h00006ool0/`000003o`00000000000;P0000Hoooo000F
oooo500000Goo`2^000000?o000000000000^00001Soool001GooolJ00001_oo0:L000000ol00000
0000002j00005oooo`005Oooob000005ool0XP000003o`00000000000;X0000Goooo000Eoooo9@00
00Koo`2L000000?o000000000000^P0001Ooool001Goool[00001Ooo09L000000ol000000000002j
00005oooo`005Ooooc000006ool0T@000003o`00000000000;X0000Goooo000Eoooo=P0000Goo`2<
000000?o000000000000^P0001Ooool001Gooolk00001_oo08D000000ol000000000002k00005ooo
o`005Ooood400005ool0P0000003o`00000000000;`0000Foooo000DooooA`0000Koo`1j000000?o
000000000000_00001Koool001Cooom=00001Ooo07D000000ol000000000002l00005_ooo`005?oo
oe800006ool0200000Goo`1R000000?o000000000000_00001Koool001CooomH00001Ooo00800007
ool0H0000003o`00000000000;d0000Foooo000DooooG@0000Woo`1P000000?o000000000000_@00
01Koool001CooomO00002_oo05d000000ol000000000002m00005_ooo`005?oooel00007ool00`00
00Goo`1H000000?o000000000000_@0001Koool001CooomP00001Ooo00T00006ool0DP000003o`00
000000000;d0000Foooo000DooooH@0000?oo`0@00001Ooo04d000000ol000000000002m00005_oo
o`001Oooo`030000oooooooo00_ooomj00001_oo04H000000ol000000000002o00005Oooo`001Ooo
o`D00009ooooP00000Goo`11000000?o000000000000_`0001Goool000Goool00`000?ooooooo`02
oooo00<0003oooooool01_ooohD00006ool0>`000003o`00000000000;l0000Eoooo000:oooo00<0
003oooooool01_oooh/00005ool0=P000003o`00000000000;l0000Eoooo000:oooo00<0003ooooo
ool01_oooi000006ool0<0000003o`00000000000;l0000Eoooo0005oooo00D0003oooooooooool0
00002OoooiH00005ool0:P000003o`00000000000<00000Eoooo0005oooo2@0000GooonK00001_oo
02@000000ol000000000003000001_ooo`L00008oooo0005oooo00<0003oooooool01Oooo`030000
oooooooo00?ooonQ00001Ooo01l000000ol000000000003000001Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo000CooooYP0000Koo`0I000000?o000000000000`00000Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`004ooooj`00005ool050000003o`00000000000<000005
oooo00<0003oooooool01Oooo`030000oooooooo00Goool001?ooona00001_oo00h000000ol00000
0000003000001Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo0005oooo0P0000?oool3
00001_oookL00005ool01P0000Do_oo100001_ooo`L00008oooo0005oooo00D0003oooooooooool0
00000oooo`030000oooooooo00?ooonl00001_oo00Do_oo100005Oooo`001Oooo`040000oooooooo
00001?ooo`030000oooooooo00?oooo200001Cnool40000Eoooo0005oooo00<0003oool000001Ooo
o`030000oooooooo00?oooo200001Cnool40000Eoooo0005oooo0P0000Koool00`000?ooooooo`03
oooo``0000<o_oo200001Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo0005oooo00<0
003oooooool00oooo`800006oooo``0000030?oo000000000<800005oooo2@0000Ooool001?oooo3
000000<0ool000000000`P0000Woool01@000?ooooooooooo`000007oooo000Coooo``0000030?oo
000000000<800008oooo00<0003oooooool02_ooo`001Oooo`030000oooooooo00_oooo3000000<0
ool000000000`P0000Soool00`000?ooooooo`0:oooo0005oooo00<0003oooooool02ooool<00000
0`3oo`000000003200002?ooo`030000oooooooo00;oool00`000?ooooooo`05oooo0005oooo00<0
003oooooool02oooodh000000k?V/`000000001b000000<0ool000000000`P0000Woool500001ooo
o`001Oooo`T00005oooo`P0000030?oo000000000<<0000=oooo00<0003oooooool01Oooo`001Ooo
o`030000oooooooo00Coool00`000?ooooooo`04oooo`P0000030?oo000000000<<0000Eoooo0005
oooo00<0003oooooool01?ooo`030000oooooooo00Coooo2000000<0ool000000000``0001Goool0
00Goool00`000?ooooooo`0;oooo`P0000030?oo000000000<<0000Eoooo000Coooo`P0000030?oo
000000000<<0000Eoooo000Doooo`00000030?oo000000000<<0000Foooo000Doooo`00000030?oo
000000000<<0000Foooo000Doooo`00000030?oo000000000<<0000Foooo000Doooo`00000030?oo
000000000<<0000Foooo000Doooo`00000030?oo000000000<<0000Foooo000Doooo`00000030?oo
000000000<<0000Foooo000Doooo_`0000030?oo000000000<@0000Foooo000Doooo_`0000030?oo
000000000<@0000Foooo000Doooo_`0000030?oo000000000<@0000Foooo000Eoooo_P0000030?oo
000000000<@0000Foooo000Eoooo_P0000030?oo000000000<<0000Goooo000Eoooo_@0000030?oo
000000000<@0000Goooo000Eoooo_@0000030?oo000000000<@0000Goooo000Eoooo_@0000030?oo
000000000<@0000Goooo000Eoooo_@0000030?oo000000000<@0000Goooo000Eoooo_@0000030?oo
000000000<@0000Goooo000Eoooo_@0000030?oo000000000<@0000Goooo000Foooo^`0000030?oo
000000000<@0000Hoooo000Foooo^`0000030?oo000000000<@0000Hoooo000Foooo^`0000030?oo
000000000<@0000Hoooo000Foooo^`0000030?oo000000000<@0000Hoooo000Goooo^P0000030?oo
000000000<@0000Hoooo000Goooo^@0000030?oo000000000<@0000Ioooo000Goooo^@0000030?oo
000000000<@0000Ioooo000Goooo^@0000030?oo000000000<@0000Ioooo000Goooo^@0000030?oo
000000000<@0000Ioooo000Goooo^@0000030?oo000000000<@0000Ioooo000Goooo^@0000030?oo
000000000<@00006oooo00<0003oooooool04?ooo`003?ooo`800009oooo^00000030?oo00000000
0<D00006oooo0`00013oool000[oool200000_ooo`030000oooooooo00Oooong000000<0ool00000
0000a00000Ooool00`000?ooooooo`04000000?oool0003oool02Oooo`002Oooo`030000oooooooo
00?oool00`000?ooooooo`06oooo]`0000030?oo000000000<@00006oooo00<0003oooooool00_oo
o`040000oooooooo00002oooo`002Oooo`030000oooooooo00?oool00`000?ooooooo`07oooo]P00
00030?oo000000000<@00006oooo00D0003oooooooooool000000oooo`030000oooooooo00Woool0
00Woool00`000?ooooooo`03oooo00<0003oooooool01ooookH000000`3oo`000000003300001ooo
o`050000oooooooooooo000000?oool00`000?ooooooo`09oooo000:oooo00<0003oooooool00_oo
o`030000oooooooo00Oooone000000<0ool000000000a00000Soool300004?ooo`002oooo`@0000:
oooo]@0000030?oo000000000<@0000Koooo000Ioooo]@0000030?oo000000000<@0000Koooo000J
oooo]00000030?oo000000000<<0000Loooo000?oooo00<0003oooooool02?oooe000005ooo<G`00
00030?oo000000000<<00009oooo00<0003oooooool04?ooo`002oooo`060000oooooooo0000oooo
00002Ooooe000005ooo<G`0000030?oo000000000<<00008oooo00<0003oool000000_ooo`80000=
oooo000;oooo00@0003oooooool00002oooo00<0003oooooool01_oooe000005ooo<GP0000030?oo
000000000<@00007oooo00@0003oooooool00002oooo00<0003oooooool03?ooo`002oooo`040000
oooooooo00000_ooo`030000oooooooo00Oooom?00001Oooc5h000000`3oo`000000003400001ooo
o`040000oooooooo00000_ooo`030000oooooooo00coool000_oool010000?ooooooo`0000;oool0
0`000?ooooooo`07ooooD00000?oolaO000000<0ool000000000``0000Soool2000000Goool0003o
ooooool000003_ooo`003?ooo`060000oooooooo0000oooo00002Ooook8000000`3oo`0000000033
00002oooo`030000oooo000000ooool000goool400002ooook4000000`3oo`000000003200003Ooo
o`030000oooooooo00koool001cooon`000000<0ool000000000``0001koool001gooon_000000<0
ool000000000``0001koool001gooon_000000<0ool000000000`P0000[oool400004Oooo`003Ooo
o`<0000=oooo[`0000030?oo000000000<800009oooo00<0003oooooool00_ooo`030000oooooooo
00koool000goool00`000?ooooooo`05oooo00<0003oooooool01Oooojl000000`3oo`0000000032
00002?ooo`030000oooooooo00?oool00`000?ooooooo`0>oooo000=oooo00<0003oooooool01Ooo
o`030000oooooooo00Gooon_000000<0ool000000000`P0000Soool00`000?ooooooo`03oooo00<0
003oooooool03_ooo`003Oooo`040000oooooooooooo1@0000Sooon]000000<0ool000000000`P00
00Woool00`000?ooooooo`03oooo00<0003oooooool03_ooo`003_ooo`<00005oooo00<0003ooooo
ool01Oooojd000000`3oo`000000003200002Oooo`800004oooo00<0003oooooool03_ooo`003_oo
o`030000oooooooo00kooon/000000<0ool000000000`P0000goool200004Oooo`003_ooo`030000
oooooooo00kooon/000000<0ool000000000`@00027oool0023ooon[000000<0ool000000000`@00
027oool0023ooonZ000000<0ool000000000`@0002;oool0023ooonZ000000<0ool000000000`@00
02;oool0027ooonY000000<0ool000000000`00002?oool0027ooonY000000<0ool000000000`000
02?oool002;ooonX000000<0ool000000000`00002?oool002;ooonX000000<0ool000000000_`00
02Coool002;ooonW000000<0ool000000000`00002Coool002;ooonW000000<0ool000000000`000
02Coool002?ooonV000000<0ool000000000`00002Coool002?ooonV000000<0ool000000000_`00
02Goool002?ooonV000000<0ool000000000_`0002Goool002CooonT000000<0ool000000000_`00
02Koool002CooonT000000<0ool000000000_`0002Koool002GooonS000000<0ool000000000_`00
02Koool002GooonS000000<0ool000000000_P0002Ooool002KooonR000000<0ool000000000_P00
02Ooool002KooonR000000<0ool000000000_@0002Soool002OooonP000000<0ool000000000_@00
02Woool002SooonO000000<0ool000000000_00002[oool002WooonN000000<0ool000000000_000
02[oool002WooonN000000<0ool0000000005P0000H0oonO0000:oooo`00:Ooooih000000`3oo`00
0000000E0000203ooih0000[oooo000ZooooW00000030?oo0000000001H000030?oo0`0000<0oonL
0000;?ooo`00:_oooi`000000`3oo`000000000L00000`3ooi`0000/oooo000Noooo0`0000[ooomh
00000`3oo`<00000103oo`000000000000<0ool400001@3oo`@000030?oo100000<0ool300000`3o
o`8000030?oo0P0000<0ool300000`3oo`@000030?oo00@00000ool0ool0oonL0000;?ooo`007Ooo
o`050000oooooooooooo000000Wooomh00000`3oo`8000030?oo0P0000<0ool300001`3oo`<00003
0?oo100000<0ool300000`3oo`8000030?oo0P0000<0ool300000`3oo`<000080?ooV`0002goool0
01_oool200001Oooo`040000oooo000000001_ooogL000030?oo0P0000<0ool200000`3oo`800004
0?oo00<00000ool0ool00P3oo`8000030?oo100000<0ool300000`3oo`8000030?oo0P0000<0ool3
00000`3oo`8000040?oo00<00000ool0ool00P3ooi/00006oooo0P0002Goool001_oool200001?oo
o`030000oooo000000;oool00`000?ooooooo`03ooooM`0000<0ool200000`3oo`8000030?oo0P00
00<0ool300000`3oo`8000030?oo100000<0ool300000`3oo`8000030?oo0P0000<0ool300000`3o
o`8000030?oo0`0000<0oonJ00001_ooo`030000oooooooo02Goool0027oool200002_ooogH00003
0?oo00@00000ool0ool000020?oo00@00000ool0ool0ool200000`3oo`<000030?oo0P0000<0ool4
00000`3oo`<000030?oo0P0000<0ool200000`3oo`<000030?oo0P0000<0ool300000`3ooiX00005
oooo00<0003oooooool09_ooo`007oooo`80000<ooooMP0000<0ool01000003oo`3oo`000080ool0
1000003oo`3oo`3oo`8000030?oo0`0000<0ool200000`3oo`@000030?oo0`0000<0ool200000`3o
o`8000030?oo0`0000<0ool200000`3oo`<000030?ooV@0000Koool00`000?ooooooo`0Voooo000M
oooo0P0000oooome00000`3oo`0400000?oo0?oo00000P3oo`0400000?oo0?oo0?oo0P0000<0ool3
00000`3oo`8000030?oo100000<0ool300000`3oo`8000030?oo0P0000<0ool300000`3oo`800003
0?oo0`0000<0oonH00001oooo`030000oooooooo00;oool500007oooo`007_ooo`030000oooooooo
00?oool400001oooog@000030?oo00@00000ool0ool000020?oo00@00000ool0ool0ool20000103o
o`0300000?oo0?oo0080ool20000103oo`<000040?oo0P0000<0ool200000`3oo`8000040?oo0P00
00<0ool20000103oo`0300000?oo0?oo0080oonG00002Oooo`@00003oooo00<0003oooooool07_oo
o`008_ooo`800004oooo00<0003oooooool01Oooog<000050?oo0`0000D0ool300001`3oo`<00006
0?oo00<00000ool0ool01`3oo`8000030?oo0P0000T0ool30000203ooiL0000@oooo00<0003ooooo
ool07_ooo`008Oooo`030000oooooooo00Coool00`000?ooooooo`05ooooL`0000D0ool300001@3o
o`@000050?oo100000<0ool01000003oo`3oo`0000<0ool00`00003oo`3oo`020?oo0`0000<0ool2
00000`3oo`0300000?oo0?oo0080ool500000`3oo`0400000?oo0?oo0?ooUP0000Koool00`000?oo
ooooo`07oooo00<0003oooooool07oooo`008?ooo`030000oooooooo00Goool00`000?ooooooo`06
ooooLP0000D0ool300001@3ooa@000000`3oo`000000002g00001_ooo`800007oooo0P00027oool0
023oool00`000?ooooooo`04oooo00<0003oooooool01oooog8000040?oo1@0000@0oolD000000<0
ool000000000200000<0oon[00002Oooo`030000oooooooo02Ooool0023oool00`000?ooooooo`02
oooo0P0000_oooma0000103oo`D000040?oo500000030?oo0000000000P000030?ooZ`0000Woool3
00009oooo`008Oooo`@0000=ooooo`0004/00009oooo00@0003oooooooooool300009?ooo`00<ooo
oh/000026@0000<c<c=<C4a<C4`0^00000Woool00`000?ooooooo`04oooo00<0003oooooool08_oo
o`00=?ooohX000001fJIVH20P?o<I/coVLc<IX20P00c<`2e00002_ooo`030000oooooooo00?oool0
0`000?ooooooo`0Soooo000/oooo0P0000Oooon9000000Nc/k?oc6J0P83<c6JIIVHcIVIVIVH0]@00
00_oool00`000?ooooooo`0Xoooo000Zoooo0P000003oooo0000oooo00Kooon8000000PI6AWoc6Ko
oiW<c6I<C4aVIVIVVC>0P82d00003Oooo`80000Xoooo000Toooo00<0003oooooool00_ooo`050000
oooooooooooo000000Sooon7000000TI6AW<c6Koc6Koc6JIVFIVVFJ0P81VIVH001T0/P00013oool2
00009_ooo`009?ooo`030000oooooooo0080000>ooooQ`000007P820/k>cC4a<IVHcP820IVIVC4a<
0;80000Aoooo00<0003oooooool09Oooo`009Oooo`80000AooooQP00000301T0C4a<C4a<009<C4`0
0aTI6@000000002a0000>Oooo`009_ooo`030000oooooooo00oooooo0000?`0003[oool002Koool2
00004OooohT000000`3oo`000000002a0000>_ooo`00>OooohT000000`3oo`000000002`0000>ooo
o`00>_ooohP000000`3oo`000000002_0000??ooo`00>oooohL000000`3oo`000000002^0000?Ooo
o`00??ooohD000000`3oo`000000002_0000?Oooo`00??ooohD000000`3oo`000000002^0000?_oo
o`00?Ooooh@000000`3oo`000000002]0000?oooo`00?_oooh<000000`3oo`000000002/0000@?oo
o`00?ooooh8000000`3oo`000000002/0000@?ooo`00?ooooh8000000`3oo`000000002[0000@Ooo
o`00@?oooh0000000`3oo`000000002[0000@_ooo`00@Oooogl000000`3oo`000000002Z0000@ooo
o`00@_ooogh000000`3oo`000000002Y0000A?ooo`00@_ooogh000000`3oo`000000002X0000AOoo
o`00@oooogd000000`3oo`000000002X0000AOooo`00A?ooog/000000`3oo`000000002X0000A_oo
o`00A_ooogT000000`3oo`000000002V0000B?ooo`00AoooogP000000`3oo`000000002V0000B?oo
o`00AoooogP000000`3oo`000000002U0000BOooo`00B?ooogL000000`3oo`000000002T0000B_oo
o`00BOooogH000000`3oo`000000002S00002?ooo`030000oooooooo043oool004[ooomd000000<0
ool000000000X`0000Soool00`000?ooooooo`11oooo000moooo0P0000cooomc000000<0ool00000
0000XP0000Soool30000@_ooo`00??ooo`040000oooooooo00003?ooog8000000`3oo`000000002R
00002?ooo`030000oooooooo00800010oooo0010oooo00<0003oooooool02Oooog8000000`3oo`00
0000002Q00002_ooo`040000oooooooooooo0`0003goool003[oool00`000?ooooooo`03oooo00<0
003oooooool02oooog0000000`3oo`000000002O00003?ooo`040000oooooooo00000oooo`80000k
oooo000joooo00<0003oooooool00oooo`030000oooooooo00cooom^000000<0ool000000000W`00
00koool200000oooo`80000loooo000joooo00<0003oooooool00oooo`030000oooooooo00gooom]
000000<0ool000000000WP0000ooool00`000?ooooooo`10oooo000koooo00@0003oooooooooool2
00004?ooof`000000`3oo`000000002M00004Oooo`030000oooooooo03ooool003coool300001?oo
o`<0000<ooooJ`0000030?oo0000000009`0000<oooo0P0000Coool00`000?ooo`00000ooooo0012
oooo00D0003oooooooooool000003OooofT000000`3oo`000000002J00003_ooo`030000oooooooo
00?oool20000@?ooo`00?oooo`030000oooo000000Coool200003OooofP000000`3oo`000000002J
00003?ooo`@00016oooo0010oooo00<0003oooooool00oooo`<00003oooo00<0003oooooool01_oo
ofL000000`3oo`000000002J00003?ooo`030000oooooooo00;oool00`000?ooooooo`13oooo0010
oooo00<0003oooooool00oooo`030000oooooooo00;oool300002OooofD000000`3oo`000000002H
00003_ooo`030000oooooooo00?oool00`000?ooo`000012oooo0015oooo00<0003oooooool01_oo
o`030000oooooooo00OooomT000000<0ool000000000U`0000Woool00`000?ooooooo`0:oooo00<0
003oooooool0@Oooo`00@_ooo`030000oooo000000[oool00`000?ooooooo`07ooooH`0000030?oo
0000000009H0000:oooo00@0003oooooool00008oooo00<0003oooooool0@_ooo`00@oooo`80000:
oooo00<0003oooooool02?ooof8000000`3oo`000000002E00003Oooo`030000oooooooo00Koool0
0`000?ooooooo`13oooo0017oooo00<0003oooooool01Oooo`030000oooooooo00WooomP000000<0
ool000000000U@0000koool00`000?ooooooo`1<oooo0017oooo00<0003oooooool01Oooo`030000
oooooooo00_ooomN000000<0ool000000000T`00017oool00`000?ooooooo`1;oooo0017oooo00<0
003oooooool01?ooo`030000oooooooo00gooomM000000<0ool000000000TP0001?oool01@000?oo
ooooooooo`000018oooo0018oooo0P0000?oool00`000?ooooooo`0?ooooG00000030?oo00000000
0940000Eoooo00<0003oool00000BOooo`00B_ooo`<0000DooooFP0000030?oo0000000008l0000H
oooo00<0003oooooool0B?ooo`00H_oooeT000000`3oo`000000002>00005oooo`80001;oooo001S
ooooE`0000030?oo0000000008h0000Goooo00<0003oooooool0Boooo`00IOooodP000000oooo`00
0000000300001?ooo`<000000`3oooooooooo`02oooo0`0000Koool?00001?ooo`H00004oooo0`00
00?oool;00001?ooo`L000000oooo`00000000150000Ioooo`00IoooodH000000oooo`0000000002
000000Goool000000000003oool00`000003oooo00000000008000001Oooo`00000000000?ooo`0A
00000_ooo`@00002oooo0`000003oooo00000000008000001?ooo`0000000?ooo``000000oooo`00
00000002000000?oool00000000010000003oooo0000000004<0001Yoooo001XooooA@000003oooo
00000000008000000oooo`0000000002000000Coool00000003oool4000000?oool0000000000P00
0003oooo0000000000h000000oooo`0000000004000000Goool000000000003oool01`000003oooo
0000000000X000000oooo`0000000002000000?oool00000000010000003oooo000000000480001Z
oooo001YooooA0000003oooo0000000000L000001?ooo`0000000?ooo`@000000oooo`0000000003
000000?oool0000000000`0000Soool00`000?ooo`000007000000Coool00000003oool7000000?o
ool0000000002?ooo`8000000oooo`0000000002000000?oool0003oool01_oood80001[oooo001[
oooo@P000003oooo0000000000L000001?ooo`00003oooooo`@000000oooo`0000000004000000?o
ool0000000002`000003oooo0000000000H000001?ooo`0000000?ooo`L000000oooo`000000000:
000000?oool0000000000P000003oooo0000oooo00@000000oooo`000000000o0000KOooo`00K?oo
od4000000oooo`0000000002000000?oool0000000000P000004oooo00000?oo00001?ooo`L00000
0oooo`000000000;000000?oool0000000001P000004oooo00000000oooo1`000003oooo00000000
00X000000oooo`0000000002000000Coool00000003oool3000000?oool000000000?P0006koool0
06gooom0000000?oool0000000000P0000Goool2000000<0ooooool000000`000003oooo00000000
00D000000oooo`000000000:000000?oool0000000001P000004oooo00000000oooo10000004oooo
00000000oooo30000003oooo00000000008000001Oooo`00000000000?ooo`02000000?oool00000
0000?@0006ooool006ooooln000000?oool0000000000P000003oooo0000000000@000000`3ooooo
o`000003000000?oool0000000001@000003oooo0000000000X000000oooo`0000000006000000Co
ool0000000000004oooo0P0000Coool:000000?oool0000000000P000005oooo000000000000oooo
008000000oooo`000000000k0000LOooo`00LOooocX000000oooo`000?ooo`05000000?oool00000
00000`0000030?oooooo000000<000001?ooo`0000000?ooo`@000000oooo`000000000;000000?o
ool00000000010000003oooo0000000000T000000oooo`000000000:000000?oool0000000000P00
0003oooo00000000008000000oooo`000?ooo`0k0000Loooo`00LoooocT00002oooo1@000003oooo
0000000000<000000`3oooooo`000003000000Coool00000003oool4000000?oool0000000002`00
00;oool400000_ooo`/000000oooo`000000000:000000?oool0000000000P000003oooo00000000
00<00002oooo>@0007Goool007Coooli000000?oool0000000000`0000Goool00`3oo`0000000004
oooo100000Coool@00001?oooa/00004oooo1`000003oooo0000000003H0001foooo001eoooo@`00
00030?oo0000000007h0001goooo001goooo@@0000030?oo0000000007`0001ioooo001ioooo?`00
00030?oo0000000007X0001koooo001koooo?@0000030?oo0000000007P0001moooo001[oooo0P00
00?oool200003?ooocT000000`3oo`000000001f00003_ooo`<0001_oooo001Zoooo00H0003ooooo
ool0003oool0000@oooo=`0000030?oo0000000007@0000<oooo00D0003oooooooooool000000_oo
o`80001]oooo001Yoooo00<0003oooooool00_ooo`80000Boooo=@0000030?oo0000000007<0000<
oooo00<0003oooooool00oooo`050000oooooooooooo000006coool006Woool00`000?ooooooo`02
oooo00<0003oooooool00oooo`<0000<oooo=00000030?oo000000000780000=oooo00<0003ooooo
ool00oooo`030000oooooooo00;oool00`000?ooooooo`1Yoooo001Woooo0P0000Goool00`000?oo
ooooo`02oooo00D0003oooooooooool000003?oooc<000000`3oo`000000001`00004?ooo`030000
oooooooo00?oool010000?ooo`00000006coool006Soool00`000?ooooooo`02oooo00<0003ooooo
ool00oooo`050000oooooooooooo000000kooola000000<0ool000000000KP00017oool300001?oo
o`80001^oooo001[oooo0P0000Goool200000oooo`030000oooooooo00ooool]000000<0ool00000
0000K00001?oool010000?ooooooo`0000Goool00`000?ooooooo`1/oooo001/oooo0P0000?oool0
0`000?ooooooo`0400004oooob/000000`3oo`000000001Z00005?ooo`030000oooooooo00;oool0
0`000?ooooooo`03oooo0P0006coool0073oool00`000?ooooooo`02oooo00<0003oooooool05ooo
obL000000`3oo`000000001V00006?ooo`030000oooooooo00;oool00`000?ooooooo`02oooo00<0
003oooooool0K?ooo`00L?ooo`030000oooooooo00;oool00`000?ooooooo`0Joooo900000030?oo
0000000006<0000Koooo00<0003oooooool00oooo`80001aoooo001aoooo00D0003oooooooooool0
00007_ooob8000000`3oo`000000001Q00007_ooo`030000oooooooo00;oool00`000?ooooooo`1`
oooo001boooo0`00027ooolO000000<0ool000000000H000027oool20000MOooo`00VOoooa`00000
0`3oo`000000001M00009?ooo`030000oooooooo07Coool009gooolH000000<0ool000000000F@00
09ooool00:3ooolE000000<0ool000000000EP000:;oool00:;ooolC000000<0ool000000000E000
0:Coool00:Ooool>000000<0ool000000000C`000:Woool00:_oool9000000<0ool000000000C000
0:goool00:koool6000000<0ool000000000B@000;3oool00;Coool00`3oo`000000001200007?oo
o`80002Ioooo002joooo>P0001goool4000000?oool0003oool0V?ooo`00U_ooo`80000Yoooo;000
02?oool010000?ooooooo`0000;oool20000V?ooo`00UOooo`030000oooooooo00<0000`oooo6000
02goool010000?ooooooo`0009coool009Goool010000?ooooooo`0000;oool200000oooo`<0001^
oooo00@0003oooooool0002Koooo002Eoooo00@0003oooooool00002oooo00D0003oooooooooool0
00000oooo`030000oooooooo00;oool50000G_ooo`@00005oooo00<0003oooooool0VOooo`00UOoo
o`040000oooooooo00000_ooo`030000oooooooo00800004oooo00D0003oooooooooool000001?oo
o`030000oooooooo05Koool01@000?ooooooooooo`000009oooo00<0003oooooool0VOooo`00U?oo
o`040000oooooooo00000oooo`030000oooooooo00;oool3000000?oool0003oool01oooo`030000
oooooooo05;oool010000?ooooooo`0000Coool00`000?ooo`00000200001_ooo`030000oooooooo
09Soool009Ooool010000?ooooooo`0000Soool200002Oooo`030000oooooooo053oool01@000?oo
ooooooooo`000005oooo00D0003oooooooooool000001Oooo`<0002Hoooo002Joooo0P0000;oool0
0`000?ooooooo`03oooo00<0003oooooool00P0000Goool00`000?ooooooo`0Soooo0P0000;oool3
00009_ooo`050000oooooooooooo000000Goool00`000?ooooooo`02oooo00D0003oooooooooool0
0000Voooo`00Woooo`D00003oooo00@0003oool000000002oooo00<0003oooooool09?ooo`030000
oooooooo00Coool00`000?ooooooo`0Soooo00<0003oooooool00_ooo`030000oooooooo00;oool5
0000X?ooo`00Yoooo`030000oooooooo00?oool00`000?ooooooo`0Toooo00<0003oooooool01Ooo
o`030000oooooooo02;oool00`000?ooooooo`02oooo00@0003oooooooooool20000Y?ooo`00Yooo
o`030000oooooooo00?oool00`000?ooooooo`0Poooo0`000003oooo0000oooo00Ooool00`000?oo
ooooo`0Roooo1@000:Woool00:Soool500008_ooo`040000oooooooooooo0P0000Coool3000000?o
ool0003oool08_ooo`80002]oooo003?oooo00<0003oooooool00_ooo`050000oooooooooooo0000
00?oool20000d_ooo`00coooo`030000oooooooo00;oool01@000?ooooooooooo`000004oooo00<0
003oooooool0d?ooo`00coooo`030000oooooooo00;oool01@000?ooooooooooo`000004oooo00<0
003oooooool0d?ooo`00c_ooo`<00002oooo0`0000?oool40000doooo`00oooook7oool00?oooona
oooo003ooooo/Oooo`00oooook7oool00?oooonaoooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {431, 0}} -> {-2.20002, -2.20002, 0.0153134, 
  0.0153134}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.227273 0.5 0.227273 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 .5 m
.5 .5 .45455 0 365.73 arc
F
.69835 .90899 m
.69835 .90899 .01818 0 365.73 arc
F
% Start of gray image
p
.68562 .89626 translate
.02545 .02545 scale
16 string
16 16 8 [16 0 0 16 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00000000193366664C33331900000000
0000001980B3808066664C3319000000
00000080B3664C66804C4C4C33190000
00006699664C4C666633334C4C331900
004C8080664C4C4C80334C3333331919
00808080668080664C4C4C3333333319
008080808099994C6666804C4C4C3319
1980668099998066668080994C4C3333
33996666808080668080808080333333
19B380666680668066808080664C3333
0099B3809966804C4C808066804C4C19
0080B3B380668080808080804C4C3319
0000B3B3B3808080808080664C331900
000019B399808080808080664C330000
00000000808080808080804C33000000
000000000019668080804C0000000000
pop
P
% End of image
gsave
.97727 .5 -69 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
69 11.5 translate
90 rotate
-69 -11.5 translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
69.000000 14.625000 moveto
(h) show
75.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.96101 .62353 -72 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
72 11.5 translate
105 rotate
-72 -11.5 translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Psc) show
81.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.91333 .73864 -69 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
69 11.5 translate
120 rotate
-69 -11.5 translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
69.000000 14.625000 moveto
(h) show
75.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.83748 .83748 -72 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
72 11.5 translate
135 rotate
-72 -11.5 translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Ari) show
81.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.73864 .91333 -69 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
69 11.5 translate
150 rotate
-69 -11.5 translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
69.000000 14.625000 moveto
(h) show
75.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.62353 .96101 -72 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
72 11.5 translate
165 rotate
-72 -11.5 translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Tau) show
81.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.5 .97727 -69 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
69 11.5 translate
180 rotate
-69 -11.5 translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
69.000000 14.625000 moveto
(h) show
75.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.37647 .96101 -72 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
72 11.5 translate
195 rotate
-72 -11.5 translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Gem) show
81.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.26136 .91333 -69 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
69 11.5 translate
210 rotate
-69 -11.5 translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(8) show
69.000000 14.625000 moveto
(h) show
75.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.16252 .83748 -72 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
72 11.5 translate
225 rotate
-72 -11.5 translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Cnc) show
81.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.08667 .73864 -72 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
72 11.5 translate
240 rotate
-72 -11.5 translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
75.000000 14.625000 moveto
(h) show
81.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.03899 .62353 -72 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
72 11.5 translate
255 rotate
-72 -11.5 translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Leo) show
81.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.02273 .5 -72 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
72 11.5 translate
270 rotate
-72 -11.5 translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(12) show
75.000000 14.625000 moveto
(h) show
81.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.03899 .37647 -72 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
72 11.5 translate
285 rotate
-72 -11.5 translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Vir) show
81.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.08667 .26136 -72 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
72 11.5 translate
300 rotate
-72 -11.5 translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(14) show
75.000000 14.625000 moveto
(h) show
81.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.16252 .16252 -72 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
72 11.5 translate
315 rotate
-72 -11.5 translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Lib) show
81.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.26136 .08667 -72 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
72 11.5 translate
330 rotate
-72 -11.5 translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(16) show
75.000000 14.625000 moveto
(h) show
81.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.37647 .03899 -72 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
72 11.5 translate
345 rotate
-72 -11.5 translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Sco) show
81.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.5 .02273 -72 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
72 11.5 translate
360 rotate
-72 -11.5 translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(18) show
75.000000 14.625000 moveto
(h) show
81.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.62353 .03899 -72 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
72 11.5 translate
15 rotate
-72 -11.5 translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Sgr) show
81.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.73864 .08667 -72 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
72 11.5 translate
30 rotate
-72 -11.5 translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
75.000000 14.625000 moveto
(h) show
81.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.83748 .16252 -72 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
72 11.5 translate
45 rotate
-72 -11.5 translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Cap) show
81.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.91333 .26136 -72 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
72 11.5 translate
60 rotate
-72 -11.5 translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(22) show
75.000000 14.625000 moveto
(h) show
81.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.96101 .37647 -72 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
72 11.5 translate
75 rotate
-72 -11.5 translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Aqr) show
81.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
1 1 0 r
1 Mabswid
.5 .5 m
.07606 .33602 L
s
0 1 1 r
.5 .5 m
.33602 .92394 L
s
gsave
.41801 .71197 -87 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 1.000000 1.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 1.000000 1.000000 setrgbcolor
(Morning) show
110.187500 14.625000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 1.000000 1.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Helvetica-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Helvetica-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Helvetica-Bold
grestore
1 0 0 r
.66398 .07606 m
.5 .5 L
s
gsave
.58199 .28803 -86.5 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(Evening) show
109.375000 14.625000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Helvetica-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Helvetica-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Helvetica-Bold
grestore
1 g
gsave
.5 .87727 -94 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 1.000000 1.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 1.000000 1.000000 setrgbcolor
(1582) show
85.000000 14.625000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 1.000000 1.000000 setrgbcolor
(-) show
91.375000 14.625000 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 1.000000 1.000000 setrgbcolor
(Oct) show
106.937500 14.625000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 1.000000 1.000000 setrgbcolor
(-) show
113.312500 14.625000 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 1.000000 1.000000 setrgbcolor
(15) show
124.312500 14.625000 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 1.000000 1.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Helvetica
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Helvetica
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Helvetica
grestore
% Start of colorimage (RGB)
p
.42095 .72419 translate
.02182 .02182 scale
48 string
16 16 8 [16 0 0 16 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
000000000000000000000000000000000000190000001900190000000000000000000000000000\
000000000000000000
0000000000000000001900001900001919193333333366664C4C4C4C4C4C191919000000000000\
000000000000000000
00000000000000001919000033996680808099CC99CCCC66CCCC66CCCC996699664C4C4C000000\
000000000000000000
000000000000000000669999808080CCFF66FFCC66CCCC99CCFF99CCCC66999966808080003333\
000000000000000000
0000000000004C4C4CB3B3B3FFCC66CCCC66808080CCCC66CCCC66996666669966336666666666\
003333000000000000
00000000000066CC99CCCC99CCCC66CCCC99666666666666999966336666666666666666669966\
4C4C4C000000000000
000000191919999999FFCC66FFFF99FFCC66CCCC666699664C4C4C666666666666669933808080\
666666000000000000
000000003333999999CCCC66FFCC99FFFF66FFCC66B3B3B3669933808080808080808080669933\
4C4C4C191919000000
000000191919808080CCCC66FFCC66FFCC99FFCC66CCCC66999966669966CC9933808080666666\
4C4C4C000019000000
000000190000808080CC9966CCCC66CCCC66CC99668080808080809999339999666699334C4C4C\
333333000000000000
000000000000333300808080B3B3B3CC99664C4C4C9999666666338080808080806666664C4C4C\
003333000000000000
0000000000000000194C4C4C6666333366668080806699336666668080804C4C4C4C4C4C191919\
000000000000000000
0000000000000000000019004C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C191919000000\
000000000000000000
000000000000000000000000000000191919191919333333003333191919000019000000000000\
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000
pop
P
% End of image
1 1 0 r
.02 w
.28904 .4184 Mdot
1 1 .8 r
.014 w
.21758 .56504 Mdot
.7 .9 .7 r
.005 w
.19893 .41753 Mdot
.25 .75 1 r
.014 w
.5 .5 Mdot
% Start of colorimage (RGB)
p
1.39636 .48727 translate
.02546 .02546 scale
42 string
14 14 8 [14 0 0 14 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000
000000000000000000000000000000000000190000190000190000001900000000000000000000\
000000
0000000000000000001900001919196666336666336699336666334C4C4C191919000000000000\
000000
000000000000191919996633999966999966B3B3B3999966CCCC669999338080804C4C4C000000\
000000
19000019191966663399996699996699CC99CCCC66CCCC6699CC66CCCC9999CC669999664C4C4C\
000000
000000666666999966B3B3B3CCCC99CCCC99CCFFCCCCCCCCCCFF99CCCC99CCCC9999CC99996666\
001900
191919663300996666999933999933CCCC66CC9966CCCC66CC9933CC996699CC66CC6666669933\
333333
191919996633999966CCCC66CCCC99CCCC66CCFF66CCCC66CCFF99CCCC66CCCC66CCCC66999933\
4C4C4C
330000666633CC9933CCCC66CCCC66CCCC66CCCC66CCCC66CCCC66CCFF66CCCC66CCCC6699CC33\
4C4C4C
190000666633999966CCCC66CCCC66CCCC99CCFF66CCCC99FFFF66CCCC99CCFF99CCCC66808080\
003300
00190033333399999999CC9999CCCCCCFF99CCCCCCCCFF99CCCC99CCFF99CCCC9999CC994C4C4C\
190000
00000019000033663380808099CC6699CC99CCCC99CCFF9999CC99CCCC9999CC99669966191919\
001900
0000000019001900001919196666338080806699666699669999666699664C4C4C001900001900\
000000
000000000000000000001900000000190000333300191919191919001900001900000000000000\
000000
pop
P
% End of image
% Start of colorimage (RGB)
p
1.39636 .48727 translate
.02546 .02546 scale
42 string
14 14 8 [14 0 0 14 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000
190000333333999966999999999966333333191919190000000000000000000000000000000000\
000000
4C4C4CCCCC99808080333300191919999966CCCC669999336666334C4C4C190000000000000000\
000000
336633CCCC994C4C4C000000669933FFFF99CCFF99FFFF99FFFF9999996699CC99666633000000\
000000
190000808080CCCC99191919CC9966CCFF99FFCC99FFFF99CCFF99CCCC99190000CCCC99808080\
001900
0000000019004C4C4CB3B3B399CC99CCCC99FFFF99FFFF99FFFF999999660019004C4C4CCCCC99\
4C4C4C
000000000000000000190000666633B3B3B3CCCC99CCCC99B3B3B36666004C4C4CCCCC9999CC99\
4C4C4C
0000000000000000000000000000000000001919194C4C4C666633808080999966666666333300\
000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/1P00`40o`000?l0003ooooook7oool0
0?oooonaoooo003ooooo/Oooo`00oooook7oool00?oooonaoooo003ooooo/Oooo`00oooook7oool0
0<coool500000oooo`<00006oooo0`000004oooo000000000000c?ooo`00c_ooo`030000oooooooo
00;oool01@000?ooooooooooo`000006oooo00D0003oooooooooool00000cOooo`00c_ooo`030000
oooooooo00;oool01@000?ooooooooooo`000006oooo00D0003oooooooooool00000cOooo`00c_oo
o`030000oooooooo00;oool01@000?ooooooooooo`000006oooo00D0003oooooooooool000007_oo
o`030000oooo00000:coool00:Woool200008oooo`030000oooooooo00?oool300001oooo`800002
oooo00<0003oooooool07?ooo`8000000oooo`000?ooo`06oooo0P000:;oool00:Soool010000?oo
ooooo`0002;oool00`000?ooooooo`02oooo00D0003oooooooooool000001_ooo`040000oooo0000
00007_ooo`030000oooooooo00;oool00`000?ooooooo`06oooo00<0003oooooool0Woooo`00X?oo
o`@00003oooo00<0003oooooool00_ooo`030000oooooooo01ooool00`000?ooooooo`02oooo00D0
003oooooooooool000001_ooo`030000oooooooo02Goool00`000?ooooooo`06oooo00<0003ooooo
ool0W_ooo`00Woooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool07Ooo
o`<00004oooo00D0003oooooooooool000001_ooo`030000oooooooo02Coool00`000?ooooooo`02
oooo0`0000;oool00`000?ooooooo`2Noooo002Foooo0`0000Goool00`000?ooooooo`05oooo00<0
003oooooool00oooo`030000oooooooo01ooool00`000?ooooooo`03oooo0`0000Koool200008Ooo
o`D00004oooo00L0003oooooooooool0003oool000000oooo`80002Koooo002Doooo0P0000?oool0
0`000?ooooooo`02oooo00<0003oooooool01_ooo`030000oooooooo00;oool00`000?ooooooo`1A
oooo00<0003oooooool01_ooo`030000oooooooo00;oool00`000?ooooooo`04oooo0`0009Soool0
09Goool00`000?ooooooo`02oooo00D0003oooooooooool000001?ooo`030000oooooooo00;oool4
0000E?ooo`030000oooooooo00Koool00`000?ooooooo`02oooo00<0003oooooool00oooo`030000
oooooooo09Woool009Coool00`000?ooooooo`03oooo00D0003oooooooooool000001?ooo`80001K
oooo0P000003oooo0000000000Coool00`000?ooooooo`02oooo00<0003oooooool00oooo`030000
oooooooo09Woool009Soool200001Oooo`@0001Ooooo00<0003oool000001Oooo`@00006oooo00<0
003oooooool0VOooo`00Uoooo`030000oooooooo07?oool200001Oooo`030000oooooooo09Woool0
09Koool00`000?ooooooo`02oooo00<0003oooooool0:_oooah0000/oooo0P000003oooo0000oooo
09Woool009Koool00`000?ooooooo`02oooo00<0003oooooool08Ooooc00000Woooo0P0009Soool0
09Ooool400007?oood00002ioooo002`ooooB`000;Goool00:_ooomH0000[Oooo`00ZOoooe`0002[
oooo002TooooIP000:Koool00:3ooom^0000X_ooo`00Moooo`80000TooooM00002Coool20000NOoo
o`00M_ooo`030000oooo000002;ooomh00008_ooo`030000oooo000007Soool007Coool00`000?oo
ooooo`02oooo00<0003oooooool06_oooh80000Moooo00<0003oooooool00P0007Koool007?oool2
00001?ooo`030000oooooooo01Sooon600006oooo`050000oooooooooooo000007Koool006ooool0
0`000?ooooooo`02oooo00<0003oooooool00oooo`030000oooooooo01Gooon:00000_ooo`03o`00
oooooooo01Coool00`000?ooooooo`1hoooo001^oooo00<0003oool000001?ooo`030000oooooooo
00;oool00`000?ooooooo`0BooooS`000003o`00oooooooo01Goool00`000?ooooooo`1goooo001]
oooo00D0003oooooooooool000000oooo`050000oooo0000oooo000001?ooon@000000Co00000000
0000000@oooo00<0003oooooool00_ooo`030000oooooooo00Coool30000L?ooo`00KOooo`030000
oooooooo00;oool01`000?ooooooooooo`000?ooo`00000@ooooU0000003o`000000000000D0000<
oooo00<0003oooooool00_ooo`030000oooooooo00?oool01@000?ooooooooooo`00001_oooo001]
oooo00<0003oooooool00_ooo`030000oooooooo00;oool00`000?ooooooo`0<ooooUP000003o`00
0000000000T0000:oooo00D0003oooooooooool000001?ooo`030000oooooooo00;oool01@000?oo
ooooooooo`00001[oooo001Woooo0P0000Coool500001Oooo`030000oooooooo00[ooonH000000?o
0000000000002`0000Woool300001?ooo`030000oooooooo00?oool00`000?ooooooo`02oooo0P00
06Woool006Koool00`000?ooooooo`05oooo00<0003oooooool01oooo`030000oooooooo00OooonJ
000000?o000000000000300000ooool00`000?ooooooo`03oooo00D0003oooooooooool00000Jooo
o`00I?ooo`<00007oooo0P0000Coool010000?ooooooo`0000WooonJ000000?o0000000000003P00
00koool00`000?ooooooo`02oooo00<0003oooooool00_ooo`030000oooooooo00;oool00`000?oo
ooooo`1Toooo001Toooo00<0003oool000002Oooo`D0000;ooooV`000003o`00000000000100000<
oooo00<0003oooooool00_ooo`050000oooooooooooo000000Goool20000IOooo`00Ioooo`030000
oooooooo01CooonM000000?o0000000000004P0000[oool01@000?ooooooooooo`000004oooo00<0
003oooooool00_ooo`030000oooooooo06Goool006Soool00`000?ooooooo`0@ooooW`000003o`00
0000000001H00008oooo0`0000Coool200001?ooo`030000oooooooo06Goool006Soool00`000?oo
ooooo`0>ooooX@000003o`000000000001P0000<oooo00@0003oooooool00002oooo00<0003ooooo
ool0I_ooo`00JOooo`030000oooooooo00_ooonR000000?o0000000000006`0000Woool200000ooo
o`80001Yoooo001Zoooo00<0003oooooool02?oooj@000000ol000000000000M0000Moooo`00J?oo
o`<00009ooooY@000003o`000000000001h0001foooo001cooooY@000003o`00000000000200001e
oooo001aooooY`000003o`00000000000280001coooo001_ooooZ0000003o`000000000002D0001a
oooo001]ooooZP000003o`000000000002L0001_oooo001/ooooZ`000003o`000000000002P0001^
oooo001[ooooZ`000003o`000000000002X0001]oooo001Yoooo[@000003o`000000000002`0001[
oooo001Woooo[P000003o`000000000002h0001Zoooo001Voooo[`000003o`000000000002l0001Y
oooo001Uoooo/0000003o`00000000000340001Woooo001Soooo/@000003o`000000000003@0001U
oooo001Roooo/P000003o`000000000003D0001Toooo0019oooo0`0001Gooonc000000?o00000000
0000=P0006?oool004Soool01@000?ooooooooooo`00000Boooo]0000003o`000000000003T0000B
oooo100004_oool004Ooool00`000?ooooooo`03oooo00<0003oooooool03_oookD000000ol00000
0000000j00004?ooo`030000oooooooo00;oool00`000?ooooooo`18oooo0016oooo0P0000Goool0
0`000?ooooooo`0=oooo]@000003o`000000000003`0000>oooo00<0003oooooool01?ooo`030000
oooooooo04Ooool004Goool00`000?ooo`000005oooo00<0003oooooool02ooookL000000ol00000
0000000n00002oooo`030000oooooooo00Goool00`000?ooooooo`17oooo0014oooo00D0003ooooo
ooooool000001?ooo`030000oooooooo00[ooonh000000?o000000000000?`0000[oool00`000?oo
ooooo`05oooo00<0003oooooool0Aoooo`00@oooo`030000oooooooo00?oool010000?ooo`000000
00cooonh000000?o000000000000@@0000Woool00`000?ooooooo`08oooo0P0004Goool004;oool0
0`000?ooooooo`05oooo00<0003oooooool02_oookX000000ol000000000001200002?ooo`030000
oooooooo00Ooool010000?ooooooo`0004Coool0047oool00`000?ooo`000007oooo00<0003ooooo
ool02?oookX000000ol000000000001400002?ooo`030000oooooooo00Koool01@000?oooooooooo
o`000013oooo0010oooo00D0003oooooooooool000001oooo`030000oooooooo00Kooonk000000?o
000000000000AP0000Ooool300001Oooo`050000oooooooooooo000000Coool00`000?ooooooo`0l
oooo0015oooo00<0003oooooool01?ooo`030000oooooooo00Kooonk000000?o000000000000A`00
00Ooool00`000?ooooooo`02oooo00@0003oooooool00002oooo0`0000?oool00`000?ooooooo`0k
oooo0016oooo00<0003oooooool02ooook/000000ol000000000001800003?ooo`070000oooooooo
oooo0000oooo000000Coool00`000?ooo`00000loooo000noooo00<0003oooooool01Oooo`030000
oooooooo00Wooonm000000?o000000000000BP0000_oool01@000?ooooooooooo`000004oooo00<0
003oooooool0?Oooo`00?Oooo`030000oooo000000Goool00`000?ooooooo`0200001ooookd00000
0ol000000000001<00002oooo`<00004oooo0P0003ooool003coool01@000?ooooooooooo`000007
oooo00<0003oooooool01Ooookh000000ol000000000001=00004?ooo`040000oooooooo0000?_oo
o`00>oooo`030000oooooooo017ooono000000?o000000000000CP0000koool00`000?ooooooo`02
oooo00<0003oooooool0>oooo`00>_ooo`030000oooo0000017ooono000000?o000000000000D000
00_oool200001Oooo`030000oooooooo03_oool003[oool010000?ooooooo`0000koooo1000000?o
000000000000D@0000_oool00`000?ooooooo`03oooo00<0003oooooool0>oooo`00?_ooo`030000
oooooooo00_oooo1000000?o000000000000DP0000_oool00`000?ooooooo`02oooo00<0003ooooo
ool0>oooo`00?oooo`030000oooooooo00Woooo1000000?o000000000000E00000_oool40000?_oo
o`00@?ooo`030000oooo000000Ooooo2000000?o000000000000E@0004coool0047oool00`000?oo
ooooo`05oooo`P000003o`000000000005L0001;oooo0010oooo00<0003oooooool01Ooool<00000
0ol000000000001H0000B_ooo`00Aooool@000000ol000000000001I0000BOooo`00Aooool<00000
0ol000000000001K0000B?ooo`00A_oool@000000ol000000000001K0000B?ooo`00A?ooolD00000
0ol000000000001N0000A_ooo`00A?ooolD000000ol000000000001O0000AOooo`00@oooolH00000
0ol000000000001P0000A?ooo`00@_ooolH000000ol000000000001R0000@oooo`00@OooolL00000
0ol000000000001R0000@oooo`00@?ooolL000000ol000000000001T0000@_ooo`00?oooolP00000
0ol000000000001U0000@Oooo`00?oooolP000000ol000000000001V0000@?ooo`00?_ooolP00000
0ol000000000001W0000@?ooo`00?OooolT000000ol000000000001X0000?oooo`00??ooolX00000
0ol000000000001Y0000?_ooo`00??ooolT000000ol000000000001[0000?Oooo`00>oooolX00000
0ol000000000001[0000?Oooo`00>_ooolX000000ol000000000001]0000??ooo`00>Ooool/00000
0ol000000000001^0000>oooo`009oooo`030000oooooooo00ooooo;000000?o000000000000K`00
013oool00`000?ooooooo`0Woooo000Voooo0P00013oooo;000000?o000000000000L00000ooool0
0`000?ooo`00000Xoooo000Xoooo0P0000koooo;000000?o000000000000L@0000koool00`000?oo
o`00000Xoooo000Zoooo00<0003oooooool02_oool/000000ol000000000001c00003Oooo`040000
oooooooo00009oooo`009?ooo`030000oooooooo00Coool00`000?ooooooo`08ooooc0000003o`00
0000000007@00007oooo00<0003oooooool00_ooo`030000oooooooo0080000Voooo000Toooo0P00
00Goool00`000?ooooooo`07ooooc@000003o`000000000007@00007oooo00D0003oooooooooool0
00000oooo`030000oooooooo02Goool002?oool010000?ooooooo`0000?oool00`000?ooooooo`08
ooooc0000003o`000000000007H00006oooo00D0003oooooooooool00000:oooo`009oooo`<0000:
ooooc@000003o`000000000007H00006oooo00D0003oooooooooool00000:oooo`00:Oooo`800008
oooocP000003o`000000000007L00006oooo0`0000Ooool00`000?ooooooo`0Roooo000Roooo00<0
003oooooool01_ooo`030000oooooooo00Coooo>000000?o000000000000N@0000koool00`000?oo
o`00000Soooo000Roooo0`0000Koool00`000?ooooooo`04oooocP000003o`000000000007X0000=
oooo00<0003oool000008oooo`008Oooo`030000oooooooo0080000;oooocP000003o`0000000000
07/0000=oooo00@0003oooooool0000Roooo000Soooo00<0003oooooool00P0000Woooo>000000?o
000000000000O00000Ooool00`000?ooooooo`02oooo00<0003oooooool00P00027oool002?oool0
0`000?ooooooo`02oooo00<0003oooooool01Ooooll000000ol000000000001l00001oooo`050000
oooooooooooo000000?oool00`000?ooooooo`0Poooo000Roooo1@0000;oool00`000?ooooooo`04
oooocP000003o`000000000007h00006oooo00D0003oooooooooool000009_ooo`009oooo`<00005
ooooc`000003o`000000000007h00006oooo00D0003oooooooooool000009_ooo`00;_oooll00000
0ol000000000000F00001_l006@00006oooo0`0000Koool00`000?ooooooo`0Noooo000Moooo00<0
003oooooool03Oooom0000000ol000000000000E00002?l006@0000=oooo0`0001ooool001coool0
0`000?ooooooo`0>ooood0000003o`000000000001D00003o`000`0000?o001T00002_ooo`80000R
oooo000Loooo0P0000koooo@000000?o000000000000700000?o001T00002Oooo`030000oooooooo
02;oool001_oool00`000?ooooooo`0200003?oooj`0000:o`001@0000?o000700001Ol000@00003
o`000`0000?o000200000ol000800003o`000`0000?o000400000ol000040000o`00o`00o`00I@00
00Coool00`000?ooo`00000200001Oooo`030000oooooooo01coool001_oool00`000?ooooooo`02
oooo00<0003oooooool02?ooojd0000:o`001@0000?o000600001ol000<00003o`000`0000?o0002
00000ol000800003o`000`0000?o000300002?l006D00005oooo00@0003oooooool00005oooo0P00
01goool0027oool200002?ooojd0000:o`00100000Go000400000ol000<00003o`000P0000?o0003
00000ol000800003o`000P0000?o000300000ol000800004o`0000<0003o003o00000_l006H00008
oooo00<0003oooooool00P0001ooool002?oool200001Oooojh00003o`002`0000Go000400000ol0
00P00003o`000`0000?o000200000ol000800003o`000`0000?o000200000ol000<00003o`00IP00
00Woool200008Oooo`008oooo`030000oooooooo00Cooon^00000ol000/00002o`0000<0003o003o
0000100000Wo000200000ol000<00003o`000P0000?o000200000ol000<00003o`000P0000?o0003
00000ol006H0000/oooo000Roooo00<0003oooooool01?ooojl0000:o`000`0000?o000010000?l0
0?l00?l000<00009o`000P0000?o000300000ol000800003o`000P0000?o000300000ol000800003
o`000`0000?o001W0000:oooo`00:Oooojl0000:o`000`0000?o000010000?l00?l00?l000<00003
o`000`0000?o000200000ol000<00003o`000P0000?o000200000ol000<00003o`000P0000?o0003
00000ol006L0000[oooo000Yoooo[`0000[o000200000ol000<00003o`000P0000?o000300000ol0
00030000o`00o`0000?o000200000ol000800003o`000P0000Co000200000ol000800004o`0000<0
003o003o00000_l006P0000Zoooo000Xoooo/00000?o000900000ol000<00003o`000`0000Oo0002
00002_l000800003o`000P0000Wo000300002?l006P0000Zoooo000Xoooo/00000?o000900000ol0
00<00003o`00100000Go0002000000?o0000003o00000_l000030000o`00o`0000;o000300000ol0
00800003o`0000<0003o003o00000_l000D00003o`0000@0003o003o003o001Y0000:Oooo`009ooo
ok40000:o`005P000003o`000000000008d0000Xoooo000Voooo/P0000[o000F000000?o00000000
00002P0000?o002100009oooo`009Ooook<0000:o`005@000003o`000000000000/00003o`00P@00
02Ooool002GooooB000000?o000000000000T00002Koool002CooooB000000?o000000000000T@00
02Koool002CooooB000000?o000000000000T@0002Koool002?ooooC000000?o000000000000TP00
02Goool002?ooooB000000?o000000000000T`0002Goool002?ooooB000000?o000000000000U000
02Coool002;ooooB000000?o000000000000U@0002Coool002;ooooB000000?o000000000000U@00
02Coool002;ooooB000000?o000000000000U@0002Coool002;ooooA000000?o000000000000U`00
02?oool0027ooooB000000?o000000000000U`0002?oool0023oool2ool0d@000003o`0000000000
09L0000Soooo000Poooo0P0000;oo`3>000000?o000000000000V@0002;oool0023oool400000ooo
0</000000ol000000000002I00008_ooo`008?ooo`L00003ool0a`000003o`000000000009/0000Q
oooo000Ooooo2`0000;oo`35000000?o000000000000V`00027oool001ooool=00000ooo0<800000
0ol000000000002L00003_ooo`030000oooooooo00ooool001kooolA00000_oo0;l000000ol00000
0000002M00003_ooo`030000oooooooo00ooool000koool00`000?ooooooo`03oooo00<0003ooooo
ool01ooooa<00003ool0_0000003o`000000000009d0000=oooo00<0003oool000004?ooo`003_oo
o`030000oooooooo00?oool00`000?ooooooo`06oooo5`0000;oo`2i000000?o000000000000W`00
00[oool200004oooo`003_ooo`030000oooooooo00;oool00`000?ooooooo`07oooo6@0000?oo`2f
000000?o000000000000W`0000Koool01P000?ooooooo`000?ooo`0001?oool000goool00`000?oo
o`00000300002_oooa`00003ool0/`000003o`000000000009l00007oooo0P0000?oool00`000?oo
o`00000@oooo000=oooo00<0003oooooool00oooo`030000oooooooo00OooolO00000_oo0;000000
0ol000000000002P00001oooo`L000000oooo`000?ooo`0>oooo000Coooo00<0003oooooool01ooo
ob400003ool0[@000003o`00000000000:40000=oooo0P0000ooool001cooolU00000_oo0:/00000
0ol000000000002Q00007_ooo`007?ooobL00003ool0Y`000003o`00000000000:80000<oooo0P00
013oool000coool200003Oooob/00002ool0Y@000003o`00000000000:<0000:oooo00@0003ooooo
ool0000?oooo000<oooo00<0003oooooool03?ooobd00003ool0X@000003o`00000000000:@00009
oooo00<0003oooooool00_ooo`030000oooooooo00coool000coool200003Ooooc000003ool0WP00
0003o`00000000000:D00008oooo00<0003oooooool00_ooo`040000oooooooo00002oooo`003?oo
o`030000oooo000000800009oooo=00000;oo`2L000000?o000000000000Y@0000Soool00`000?oo
ooooo`02oooo00@0003oooooool0000;oooo000;oooo00<0003oooooool00oooo`030000oooo0000
00Kooolf00000ooo09P000000ol000000000002V00002?ooo`030000oooooooo00;oool500002_oo
o`002oooo`030000oooooooo00?oool010000?ooooooo`0000Goooli00000_oo09H000000ol00000
0000002V00002Oooo`@00004oooo00<0003oooooool02?ooo`004Oooo`030000oooooooo00Kooolk
00000ooo098000000ol000000000002W00002Oooo`030000oooooooo013oool001Wooolo00000_oo
090000000ol000000000002X00002?ooo`030000oooooooo013oool001Wooom100000ooo08d00000
0ol000000000002X00003Oooo`030000oooooooo00_oool001Wooom400000ooo08T000000ol00000
0000002Y00003_ooo`030000oooooooo00[oool000ooool300001oooodL00002ool0Q`000003o`00
000000000:T00009oooo00<0003oooooool00`0000coool000Woool600000_ooo`030000oooooooo
00Gooom900000ooo08<000000ol000000000002[00002?ooo`<00002oooo00<0003oooooool02_oo
o`002Oooo`800006oooo00<0003oooooool01?ooodd00002ool0P@000003o`00000000000:/00009
oooo00<0003oooooool00_ooo`030000oooooooo00Woool000_oool00`000?ooooooo`0:ooooC`00
00?oo`1n000000?o000000000000Z`0000Soool00`000?ooooooo`03oooo00<0003oooooool02Ooo
o`003?ooo`030000oooooooo00SooomC00000ooo07X000000ol000000000002]00001oooo`030000
oooooooo00ooool000goool2000000?oool0003oool01OoooeH00002ool0N0000003o`0000000000
0:d00008oooo00<0003oooooool03_ooo`003oooo`800006ooooF00000?oo`1e000000?o00000000
0000[@0001Woool000ooool00`000?ooooooo`05ooooF`0000;oo`1b000000?o000000000000[P00
01Woool001OooomM00000ooo06l000000ol000000000002^00006Oooo`005oooof000007ool0I`00
0003o`00000000000;00000Hoooo000GooooH@0000Ooo`1V000000?o000000000000/00001Soool0
01Ooooln000000>ci[<000000000800000Ooo`1V000000?o000000000000/00001Soool001KooomR
00002Ooo06<000000ol000000000002a00006?ooo`005_ooof800007ool00P0000?oo`1P000000?o
000000000000/@0001Soool001KooomS00001Ooo00H00002ool0G@000003o`00000000000;80000H
oooo000FooooI00000?oo`0900000ooo05X000000ol000000000002b00006?ooo`005Oooog@00002
ool0F0000003o`00000000000;<0000Goooo000EooooMP0000?oo`1D000000?o000000000000]000
01Ooool001Gooomi00000ooo054000000ol000000000002d00005oooo`005Oooog`00002ool0CP00
0003o`00000000000;D0000Goooo000EooooOP0000?oo`1;000000?o000000000000]@0001Ooool0
01Gooon100000_oo04T000000ol000000000002e00005oooo`005Ooooh<00003ool0A@000003o`00
000000000;H0000Goooo000EooooQP0000?oo`12000000?o000000000000]`0001Koool001Cooon:
00000_oo040000000ol000000000002g00005_ooo`005?oooh`00003ool0?0000003o`0000000000
0;P0000Foooo000DooooS`0000;oo`0j000000?o000000000000^00001Koool001CooonA00000ooo
03H000000ol000000000002i00005_ooo`005?oooi@00002ool0=0000003o`00000000000;T0000F
oooo000DooooUP0000?oo`0a000000?o000000000000^@0001Koool001CooonI00000ooo02d00000
0ol000000000002j00005_ooo`005?oooi`00002ool0:`000003o`00000000000;X0000Foooo000D
ooooWP0000?oo`0W000000?o000000000000^`0001Koool000Goool00`000?ooooooo`0;ooooXP00
00;oo`0U000000?o000000000000_00001Goool000Goool500002Ooooj@00003ool08P000003o`00
000000000;`0000Eoooo0005oooo00<0003oooooool00_ooo`030000oooooooo00KooonW00000_oo
01l000000ol000000000002m00005Oooo`002_ooo`030000oooooooo00KooonY00000ooo01`00000
0ol000000000002m00005Oooo`002_ooo`030000oooooooo00Kooon/00000ooo01P000000ol00000
0000002n00005Oooo`001Oooo`050000oooooooooooo000000Wooon_00000_oo01H000000ol00000
0000002n00005Oooo`001Oooo`T00005oooo/@0000?oo`0C000000?o000000000000_P0000Koool7
00002?ooo`001Oooo`030000oooooooo00Goool00`000?ooooooo`03oooo]00000;oo`0@000000?o
000000000000_`0000Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`004ooookH00003
ool03@000003o`00000000000;l00005oooo00<0003oooooool01Oooo`030000oooooooo00Goool0
01?oooni00000_oo00/000000ol000000000002o00001Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo000Coooo^`0000?oo`07000000?o000000000000`00000Goool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`001Oooo`800003oooo0`0000Kooonn00000ooo00030000?koo?koo
00<o_oo100001_ooo`L00008oooo0005oooo00D0003oooooooooool000000oooo`030000oooooooo
00?oooo1000000?oo`0o_olo_ol00cnool40000Eoooo0005oooo00@0003oooooool00004oooo00<0
003oooooool00ooool800005?koo`@0001Goool000Goool00`000?ooo`000005oooo00<0003ooooo
ool00ooool800005?koo`@0001Goool000Goool200001_ooo`030000oooooooo00?oooo300000cno
ol800005oooo00<0003oooooool01Oooo`030000oooooooo00Goool000Goool00`000?ooooooo`03
oooo0P0000Koooo3000000<0ool000000000`P0000Goool900001oooo`004ooool8000000`3oo`00
0000003300002Oooo`050000oooooooooooo000000Ooool001?oooo2000000<0ool000000000``00
00Soool00`000?ooooooo`0:oooo0005oooo00<0003oooooool02ooool8000000`3oo`0000000033
00002?ooo`030000oooooooo00[oool000Goool00`000?ooooooo`0;oooo`@0000030?oo00000000
0<@00008oooo00<0003oooooool00_ooo`030000oooooooo00Goool000Goool00`000?ooooooo`0;
oooo`@0000030?oo000000000<@00009oooo1@0000Ooool000Goool900001Ooool4000000`3oo`00
0000003400003Oooo`030000oooooooo00Goool000Goool00`000?ooooooo`04oooo00<0003ooooo
ool01?oool0000000`3oo`000000003500005Oooo`001Oooo`030000oooooooo00Coool00`000?oo
ooooo`04oooo`00000030?oo000000000<D0000Eoooo0005oooo00<0003oooooool02ooookl00000
0`3oo`000000003600005Oooo`004ooookl000000`3oo`000000003600005Oooo`005?oookh00000
0`3oo`000000003500005_ooo`005?oookd000000`3oo`000000003600005_ooo`005?oookd00000
0`3oo`000000003600005_ooo`005?oook`000000`3oo`000000003700005_ooo`005?oook`00000
0`3oo`000000003700005_ooo`005?oook`000000`3oo`000000003700005_ooo`005?oook/00000
0`3oo`000000003800005_ooo`005?oook/000000`3oo`000000003800005_ooo`005?oookX00000
0`3oo`000000003900005_ooo`005OoookT000000`3oo`000000003900005_ooo`005OoookT00000
0`3oo`000000003800005oooo`005OoookP000000`3oo`000000003900005oooo`005OoookP00000
0`3oo`000000003900005oooo`005OooodH00005ooo<K@0000030?oo000000000<T0000Goooo000E
ooooAP0000Goola/000000<0ool000000000bP0001Ooool001Gooom600001Oooc6`000000`3oo`00
0000003:00005oooo`005OooodH00005ooo<J`0000030?oo000000000</0000Goooo000FooooAP00
00?oola/000000<0ool000000000bP0001Soool001Kooone000000<0ool000000000bP0001Soool0
01Kooond000000<0ool000000000b`0001Soool001Kooond000000<0ool000000000b`0001Soool0
01Oooonb000000<0ool000000000c00001Soool001Oooonb000000<0ool000000000b`0001Woool0
01Oooonb000000<0ool000000000b`0001Woool001Oooona000000<0ool000000000c00001Woool0
01Oooona000000<0ool000000000c00001Woool001Oooon`000000<0ool000000000c@0001Woool0
01Oooon`000000<0ool000000000c@0000Koool00`000?ooooooo`0@oooo000<oooo0P0000Wooon`
000000<0ool000000000c@0000Koool300004?ooo`002_ooo`800002oooo00<0003oooooool01ooo
ojh000000`3oo`000000003=00001oooo`030000oooooooo00@000000oooo`000?ooo`09oooo0009
oooo00<0003oooooool00oooo`030000oooooooo00Kooon^000000<0ool000000000c@0000Koool0
0`000?ooooooo`02oooo00@0003oooooool0000;oooo0009oooo00<0003oooooool00oooo`030000
oooooooo00Oooon]000000<0ool000000000c@0000Koool01@000?ooooooooooo`000003oooo00<0
003oooooool02Oooo`002Oooo`030000oooooooo00?oool00`000?ooooooo`07oooo[00000030?oo
000000000<d00007oooo00D0003oooooooooool000000oooo`030000oooooooo00Woool000[oool0
0`000?ooooooo`02oooo00<0003oooooool01ooooj`000000`3oo`000000003=00002?ooo`<0000@
oooo000;oooo100000[ooon[000000<0ool000000000cP0001_oool001Wooon[000000<0ool00000
0000cP0001_oool001[ooonZ000000<0ool000000000c@0001coool000ooool00`000?ooooooo`08
ooooZ@0000030?oo000000000<h00009oooo00<0003oooooool04?ooo`002oooo`060000oooooooo
0000oooo00002OooojT000000`3oo`000000003>00002?ooo`030000oooo000000;oool200003Ooo
o`002oooo`040000oooooooo00000_ooo`030000oooooooo00KooonX000000<0ool000000000c`00
00Ooool010000?ooooooo`0000;oool00`000?ooooooo`0<oooo000;oooo00@0003oooooool00002
oooo00<0003oooooool01oooojL000000`3oo`000000003?00001oooo`040000oooooooo00000_oo
o`030000oooooooo00coool000_oool010000?ooooooo`0000;oool00`000?ooooooo`07ooooY`00
00030?oo000000000<h00008oooo0P000005oooo0000oooooooo000000koool000coool01P000?oo
ooooo`000?ooo`0000WooonV000000<0ool000000000c`0000_oool00`000?ooo`00000?oooo000=
oooo100000_ooonU000000<0ool000000000cP0000goool00`000?ooooooo`0>oooo000LooooY000
00030?oo000000000<l0000Noooo000MooooX`0000030?oo000000000<l0000Noooo000MooooX`00
00030?oo000000000<h0000:oooo1000017oool000goool300003Ooooj8000000`3oo`000000003?
00002Oooo`030000oooooooo00;oool00`000?ooooooo`0>oooo000=oooo00<0003oooooool01Ooo
o`030000oooooooo00GooonR000000<0ool000000000c`0000Soool00`000?ooooooo`03oooo00<0
003oooooool03_ooo`003Oooo`030000oooooooo00Goool00`000?ooooooo`05ooooXP0000030?oo
000000000<l00008oooo00<0003oooooool00oooo`030000oooooooo00koool000goool010000?oo
ooooooooo`D00008ooooX00000030?oo000000000<l00009oooo00<0003oooooool00oooo`030000
oooooooo00koool000koool300001Oooo`030000oooooooo00GooonP000000<0ool000000000c`00
00Woool200001?ooo`030000oooooooo00koool000koool00`000?ooooooo`0>ooooWP0000030?oo
000000000=00000=oooo0P00017oool000koool00`000?ooooooo`0>ooooWP0000030?oo00000000
0<l0000Qoooo000PooooW@0000030?oo000000000<l0000Qoooo000PooooW00000030?oo00000000
0<l0000Roooo000PooooW00000030?oo000000000<l0000Roooo000QooooVP0000030?oo00000000
0<l0000Soooo000QooooVP0000030?oo000000000<l0000Soooo000RooooV@0000030?oo00000000
0<l0000Soooo000RooooV00000030?oo000000000<l0000Toooo000RooooV00000030?oo00000000
0<l0000Toooo000RooooV00000030?oo000000000<l0000Toooo000SooooUP0000030?oo00000000
0=00000Toooo000SooooUP0000030?oo000000000<l0000Uoooo000SooooU@0000030?oo00000000
0=00000Uoooo000TooooU00000030?oo000000000<l0000Voooo000TooooU00000030?oo00000000
0<l0000Voooo000UooooTP0000030?oo000000000=00000Voooo000UooooTP0000030?oo00000000
0<l0000Woooo000VooooT00000030?oo0000000001D000060?oo]@0002Ooool002Kooon@000000<0
ool000000000500000P0oonc0000:?ooo`009oooohl000000`3oo`000000000D00000`3oo`<00003
0?oo/@0002Woool002Sooon=000000<0ool0000000006`0000<0oon`0000:_ooo`00:OooofP00003
0?oo0`0000040?oo0000000000000`3oo`@000050?oo100000<0ool40000103oo`8000030?oo0P00
00<0ool200000`3oo`<000030?oo100000<0ool01000003oo`3oo`3ook00000Zoooo000YooooJ000
00<0ool200000`3oo`8000030?oo0`0000L0ool300000`3oo`@000030?oo0`0000<0ool200000`3o
o`8000030?oo0`0000<0ool30000203oojl0000[oooo000YooooJ00000<0ool200000`3oo`800003
0?oo0P0000@0ool00`00003oo`3oo`020?oo0P0000<0ool400000`3oo`<000030?oo0P0000<0ool2
00000`3oo`<000030?oo0P0000@0ool00`00003oo`3oo`020?oo[`0002_oool002[ooomW00000`3o
o`8000030?oo0P0000<0ool200000`3oo`<000030?oo0P0000<0ool400000`3oo`<000030?oo0P00
00<0ool200000`3oo`<000030?oo0P0000<0ool300000`3oojh0000/oooo000ZooooI`0000<0ool0
1000003oo`3oo`000080ool01000003oo`3oo`3oo`8000030?oo0`0000<0ool200000`3oo`@00003
0?oo0`0000<0ool200000`3oo`8000030?oo0`0000<0ool200000`3oo`<000030?oo[P0002coool0
01koool300002_ooofH000030?oo00@00000ool0ool000020?oo00@00000ool0ool0ool200000`3o
o`<000030?oo0P0000<0ool400000`3oo`<000030?oo0P0000<0ool200000`3oo`<000030?oo0P00
00<0ool300000`3oojh0000/oooo000Moooo00D0003oooooooooool000002OooofH000030?oo00@0
0000ool0ool000020?oo00@00000ool0ool0ool200000`3oo`<000030?oo0P0000<0ool400000`3o
o`<000030?oo0P0000<0ool200000`3oo`<000030?oo0P0000<0ool300000`3oojd0000]oooo000K
oooo0P0000Goool010000?ooo`00000000KooomU00000`3oo`0400000?oo0?oo00000P3oo`040000
0?oo0?oo0?oo0P0000@0ool00`00003oo`3oo`020?oo0P0000@0ool30000103oo`8000030?oo0P00
00<0ool20000103oo`8000030?oo0P0000@0ool00`00003oo`3oo`020?oo[@0000Koool200009Ooo
o`006oooo`800004oooo00<0003oool000000_ooo`030000oooooooo00?ooomU00001@3oo`<00005
0?oo0`0000L0ool300001P3oo`0300000?oo0?oo00L0ool200000`3oo`8000090?oo0`0000P0oon/
00001_ooo`030000oooooooo02Goool0027oool200002_ooof@000050?oo0`0000D0ool400001@3o
o`@000030?oo00<00000ool0ool0103oo`@000000`0I01T00000000600000`3oo`0300000?oo0?oo
0080ool500000`3oo`0400000?oo0?oo0?oo[00000Goool00`000?ooooooo`0Voooo000Ooooo0P00
00cooomT00001@3oo`<000050?oo4`0000030?oo00000000008000000`006C>IIX20P002c<aV00=V
VFI<C4`00000``0000Koool00`000?ooooooo`0Voooo000Moooo0P0000oooomS0000103oo`D00004
0?oo4`0000030?oo00000000008000000da<C?o<I/c<IP02c<aV00=VVFHcIVH0<c<0`P0000Ooool0
0`000?ooooooo`02oooo1@0001ooool001koool00`000?ooooooo`03oooo100000OooomR0000103o
o`D000040?oo4P0000030?oo0000000000<0000029VIVOooVOo<IVJIITa<C6IVIVJI<fIVI/400009
oooo100000?oool00`000?ooooooo`0Noooo000Roooo0P0000Coool00`000?ooooooo`05ooooP000
00030?oo0000000000<000002H20P?o<I_o<VLc<IYVII/bI<h20P4a<C0006@3000004?ooo`030000
oooooooo01koool0027oool00`000?ooooooo`04oooo00<0003oooooool01Oooogl000000`3oo`00
00000004000000Pc<`2c/k?<VFJIVFIVIS>0P81VIVH0<c?000001_ooo`030000oooooooo00Ooool0
0`000?ooooooo`0Ooooo000Poooo00<0003oooooool01Oooo`030000oooooooo00Kooomn000000<0
ool0000000001@0000E<C4`00aTI6@000000002o00001_ooo`800007oooo0P00027oool0023oool0
0`000?ooooooo`04oooo00<0003oooooool01oooogh000000`3oo`0000000006000000@I6ATc<c<0
<c<001W100002Oooo`030000oooooooo02Ooool0023oool00`000?ooooooo`02oooo0P0000_oooml
000000<0ool000000000c00000Woool300009oooo`008Oooo`@0000=ooooO00000030?oo00000000
0</00009oooo00@0003oooooooooool300009?ooo`00<oooogX000000`3oo`000000003;00002Ooo
o`030000oooooooo00Coool00`000?ooooooo`0Roooo000dooooN@0000030?oo000000000<X0000:
oooo00<0003oooooool00oooo`030000oooooooo02?oool002coool200001oooogP000000`3oo`00
0000003:00002oooo`030000oooooooo02Soool002[oool2000000?oool0003oool01_ooogL00000
0`3oo`000000003:00003Oooo`80000Xoooo000Toooo00<0003oooooool00_ooo`050000oooooooo
oooo000000Sooomf000000<0ool000000000b@00013oool200009_ooo`009?ooo`030000oooooooo
0080000>ooooM@0000030?oo000000000<P0000Aoooo00<0003oooooool09Oooo`009Oooo`80000A
ooooL`0000030?oo000000000<T0000ioooo000Voooo00<0003oooooool03oooog<000000`3oo`00
000000380000>_ooo`009_ooo`80000AooooL@0000030?oo000000000<T0000joooo000iooooL@00
00030?oo000000000<P0000koooo000jooooL00000030?oo000000000<L0000loooo000kooooKP00
00030?oo000000000<L0000moooo000looooK@0000030?oo000000000<L0000moooo000looooK000
00030?oo000000000<L0000noooo000mooooJ`0000030?oo000000000<H0000ooooo000nooooJP00
00030?oo000000000<D00010oooo000oooooJ00000030?oo000000000<H00010oooo000oooooJ000
00030?oo000000000<D00011oooo0010ooooI`0000030?oo000000000<@00012oooo0011ooooI@00
00030?oo000000000<@00013oooo0012ooooI00000030?oo000000000<<00014oooo0012ooooH`00
00030?oo000000000<<00015oooo0013ooooHP0000030?oo000000000<<00015oooo0014ooooH@00
00030?oo000000000<800016oooo0016ooooGP0000030?oo000000000<400018oooo0017ooooG@00
00030?oo000000000<400018oooo0017ooooG00000030?oo000000000<400019oooo0018ooooF`00
00030?oo000000000<00001:oooo0019ooooFP0000030?oo000000000;l00008oooo00<0003ooooo
ool0@?ooo`00B_oooeP000000`3oo`000000002o00002?ooo`030000oooooooo047oool003goool2
00003?oooeL000000`3oo`000000002n00002?ooo`<00012oooo000loooo00@0003oooooool0000<
ooooE@0000030?oo000000000;l00008oooo00<0003oooooool00P00043oool0043oool00`000?oo
ooooo`09ooooE@0000030?oo000000000;h0000:oooo00@0003oooooooooool30000?Oooo`00>_oo
o`030000oooooooo00?oool00`000?ooooooo`0;ooooD`0000030?oo000000000;`0000<oooo00@0
003oooooool00003oooo0P0003_oool003[oool00`000?ooooooo`03oooo00<0003oooooool03?oo
oe4000000`3oo`000000002l00003_ooo`800003oooo0P0003coool003[oool00`000?ooooooo`03
oooo00<0003oooooool03Ooooe0000000`3oo`000000002k00003oooo`030000oooooooo043oool0
03_oool010000?ooooooooooo`80000@ooooC`0000030?oo000000000;X0000Aoooo00<0003ooooo
ool0?oooo`00??ooo`<00004oooo0`0000cooom=000000<0ool000000000^P0000coool200001?oo
o`030000oooo000003ooool004;oool01@000?ooooooooooo`00000=ooooB`0000030?oo00000000
0;P0000>oooo00<0003oooooool00oooo`800010oooo000ooooo00<0003oool000001?ooo`80000=
ooooB@0000030?oo000000000;T0000<oooo100004Koool0043oool00`000?ooooooo`03oooo0`00
00?oool00`000?ooooooo`06ooooB@0000030?oo000000000;P0000<oooo00<0003oooooool00_oo
o`030000oooooooo04?oool0043oool00`000?ooooooo`03oooo00<0003oooooool00_ooo`<00009
ooooA`0000030?oo000000000;H0000>oooo00<0003oooooool00oooo`030000oooo000004;oool0
04Goool00`000?ooooooo`06oooo00<0003oooooool01oooodD000000`3oo`000000002f00002Ooo
o`030000oooooooo00[oool00`000?ooooooo`11oooo0012oooo00<0003oool000002_ooo`030000
oooooooo00Oooom4000000<0ool000000000]@0000[oool010000?ooooooo`0000Soool00`000?oo
ooooo`12oooo0013oooo0P0000[oool00`000?ooooooo`08oooo@P0000030?oo000000000;D0000=
oooo00<0003oooooool01_ooo`030000oooooooo04?oool004Ooool00`000?ooooooo`05oooo00<0
003oooooool02Ooood4000000`3oo`000000002d00003_ooo`030000oooooooo04coool004Ooool0
0`000?ooooooo`05oooo00<0003oooooool02oooocl000000`3oo`000000002b00004Oooo`030000
oooooooo04_oool004Ooool00`000?ooooooo`04oooo00<0003oooooool03Oooocd000000`3oo`00
0000002b00004oooo`050000oooooooooooo000004Soool004Soool200000oooo`030000oooooooo
00ooooll000000<0ool000000000/@0001Goool00`000?ooo`000019oooo001:oooo0`0001Coooli
000000<0ool000000000/00001Soool00`000?ooooooo`18oooo001Roooo>00000030?oo00000000
0:l0000Goooo0P0004_oool006?ooolg000000<0ool000000000[P0001Ooool00`000?ooooooo`1;
oooo001Uoooo=00000030?oo00000000014000000oooo`000000000300001?ooo`@00004oooo0`00
00Koool?00001?ooo`H00004oooo0`0000?oool=000000?oool0000000000`0000Cooom70000Iooo
o`00Iooooc8000000`3oo`000000000A000000?oool0000000000P000005oooo000000000000oooo
00<000000oooo`0000000002000000Goool000000000003oool04@0000;oool400000_ooo`<00000
0oooo`0000000002000000Coool00000003oool?000000?oool0000000000P000005oooo00000000
0000oooo04D0001Yoooo001Xoooo<@0000030?oo00000000014000000oooo`0000000002000000?o
ool0000000000P000004oooo00000000oooo10000003oooo00000000008000000oooo`000000000>
000000?oool00000000010000005oooo000000000000oooo00L000000oooo`000000000=000000?o
ool0000000000P000003oooo00000000008000000oooo`00000000110000J_ooo`00JOooobl00000
0`3oo`000000000B000000?oool0000000001`000004oooo00000000oooo10000003oooo00000000
00<000000oooo`000000000300002?ooo`030000oooo000000L000001?ooo`0000000?ooo`L00000
0oooo`0000000008oooo1@000003oooo0000000000L000000oooo`00000000100000Joooo`00Jooo
obd000000`3oo`000000000B000000?oool0000000001`000004oooo00000000oooo10000003oooo
0000000000@000000oooo`000000000;000000?oool0000000001P000004oooo00000000oooo1`00
0003oooo0000000000d000000oooo`0000000007000000?oool000000000?P0006goool006coool[
000000<0ool0000000004`000003oooo00000000008000000oooo`0000000002000000Coool00000
00000004oooo1`000003oooo0000000000/000000oooo`0000000006000000Coool00000003oool7
000000?oool0000000003@000003oooo00000000008000000oooo`0000000002000000?oool00000
0000?@0006koool006gooolZ000000<0ool0000000004`000003oooo0000000000800005oooo0`00
0003oooo00000000008000000oooo`0000000005000000?oool0000000002P000003oooo00000000
00H000001?ooo`0000000?ooo`@000001?ooo`0000000?ooo`l000000oooo`000000000200001Ooo
ocl0001_oooo001_oooo:00000030?oo0000000001<000000oooo`0000000002000000?oool00000
00001@000003oooo00000000008000000oooo`0000000005000000?oool0000000002P000003oooo
0000000000H000001?ooo`000000000000Coool200001?ooo`d000000oooo`0000000002000000?o
ool000000000?`00077oool0077ooolU000000<0ool0000000004P000003oooo0000oooo00D00000
0oooo`0000000004000000?oool0000000000P000004oooo00000000oooo10000003oooo00000000
00/000000oooo`0000000004000000?oool0000000002@000003oooo0000000000/000000oooo`00
0?ooo`05000000?oool000000000?00007?oool007?ooolS000000<0ool0000000004`0000;oool5
000000?oool00000000010000003oooo00000000008000001?ooo`0000000?ooo`@000000oooo`00
0000000;00000_ooo`@00002oooo2`000003oooo0000000000`00002oooo1@000003oooo00000000
03X0001eoooo001doooo8@0000030?oo0000000001D000000oooo`000000000300001Oooo`<00004
oooo100000Coool@00001?oooad000000oooo`000000000300001OooocL0001foooo001eoooo8000
00030?oo000000000:40001goooo001goooo7P0000030?oo000000000940000021TI6H20P820P820
P6IVITa<C3<c<aTI6@H0001ioooo001ioooo6`0000030?oo00000000098000001H20P;>c/da<C6IV
IX20P002C4a<00<c<c<0000000000P0007_oool007_ooolI000000<0ool000000000T@0000:0P800
1FIVITa<C4a<C820P4a<C002<c<c0QTI6Ggoool006_oool200000oooo`80000<oooo5@0000030?oo
0000000009800002P82000=VIVJ0P81VIVH00Ta<C0<c<c<00aTI6@000?ooo`09oooo0`0006ooool0
06[oool01P000?ooooooo`000?ooo`00013ooolC000000<0ool000000000T@0000056ATIIVIVP820
VIVIP820009VIVH00h20P9VIVDa<C002<c<c00<0003oooooool01?ooo`050000oooooooooooo0000
00;oool20000KOooo`00JOooo`030000oooooooo00;oool200004_oooa4000000`3oo`000000002A
000000<I6AV0P81VIVH00VIVIP05P820IVIVP820P820IVIV008c<c<00`000?ooooooo`03oooo00<0
003oooooool00oooo`050000oooooooooooo000006coool006Woool00`000?ooooooo`02oooo00<0
003oooooool00oooo`<0000<oooo3`0000030?oo0000000009<000001;>c/h20P9VIVH20P09<C4`0
1X20P6IVIX20P4a<C1TI6@0000Goool00`000?ooooooo`03oooo00<0003oooooool00_ooo`030000
oooooooo06Woool006Ooool200001Oooo`030000oooooooo00;oool01@000?ooooooooooo`00000<
oooo3P0000030?oo0000000009<00003/k>c1820P003IVIVC4a<6ATI00800006oooo00<0003ooooo
ool00oooo`040000oooo00000000K?ooo`00J?ooo`030000oooooooo00;oool00`000?ooooooo`03
oooo00D0003oooooooooool000003_ooo``000000`3oo`000000002C000000<I6AVc/k>IVIT01820
P003IVIVC4a<000000800005oooo0`0000Coool20000K_ooo`00Joooo`800005oooo0P0000?oool0
0`000?ooooooo`0?oooo200000030?oo00000000094000000oooo`0000000003000000AVIVJ0P820
P81<C4`400001Oooo`040000oooooooo00001Oooo`030000oooooooo06coool006coool200000ooo
o`030000oooooooo00@0000Coooo1P0000030?oo0000000008l00003oooo3@0000Coool00`000?oo
ooooo`02oooo00<0003oooooool00oooo`80001/oooo001`oooo00<0003oooooool00_ooo`030000
oooooooo01Ooool00`00003oo`00002=00002?ooo`/00005oooo00<0003oooooool00_ooo`030000
oooooooo00;oool00`000?ooooooo`1/oooo001`oooo00<0003oooooool00_ooo`030000oooooooo
01Soool00`3oooooo`00002900003Oooo`P00006oooo00<0003oooooool00oooo`80001aoooo001a
oooo00D0003oooooooooool000007_ooohH0000Boooo0`0000Woool00`000?ooooooo`02oooo00<0
003oooooool0L?ooo`00L_ooo`<0000QooooPP00027oool20000MOooo`00VOooog`0000Toooo00<0
003oooooool0M?ooo`00WOooog@0002Ooooo002PooooKP000:;oool00:;ooomZ0000Y?ooo`00Yooo
of00002Yoooo002[ooooF0000:goool00:kooomB0000/?ooo`00]Ooood@0000Loooo0P0009Woool0
0;[ooolj00007Oooo`@000000oooo`000?ooo`2Hoooo002Foooo0P0002Woool/00008oooo`040000
oooooooo00000_ooo`80002Hoooo002Eoooo00<0003oooooool00`00033ooolH0000;Oooo`040000
oooooooo0000W?ooo`00UOooo`040000oooooooo00000_ooo`800003oooo0`0006koool010000?oo
ooooo`0009_oool009Goool010000?ooooooo`0000;oool01@000?ooooooooooo`000003oooo00<0
003oooooool00_ooo`D0001Noooo100000Goool00`000?ooooooo`2Ioooo002Eoooo00@0003ooooo
ool00002oooo00<0003oooooool00P0000Coool01@000?ooooooooooo`000004oooo00<0003ooooo
ool0E_ooo`050000oooooooooooo000000Woool00`000?ooooooo`2Ioooo002Doooo00@0003ooooo
ool00003oooo00<0003oooooool00_ooo`<000000oooo`000?ooo`07oooo00<0003oooooool0D_oo
o`040000oooooooo00001?ooo`030000oooo000000800006oooo00<0003oooooool0V?ooo`00Uooo
o`040000oooooooo00002?ooo`800009oooo00<0003oooooool0D?ooo`050000oooooooooooo0000
00Goool01@000?ooooooooooo`000005oooo0`0009Soool009[oool200000_ooo`030000oooooooo
00?oool00`000?ooooooo`0200001Oooo`030000oooooooo02?oool200000_ooo`<0000Voooo00D0
003oooooooooool000001Oooo`030000oooooooo00;oool01@000?ooooooooooo`00002Koooo002O
oooo1@0000?oool010000?ooo`00000000;oool00`000?ooooooo`0Toooo00<0003oooooool01?oo
o`030000oooooooo02?oool00`000?ooooooo`02oooo00<0003oooooool00_ooo`D0002Poooo002W
oooo00<0003oooooool00oooo`030000oooooooo02Coool00`000?ooooooo`05oooo00<0003ooooo
ool08_ooo`030000oooooooo00;oool010000?ooooooooooo`80002Toooo002Woooo00<0003ooooo
ool00oooo`030000oooooooo023oool3000000?oool0003oool01oooo`030000oooooooo02;oool5
0000ZOooo`00Z?ooo`D0000Roooo00@0003oooooooooool200001?ooo`<000000oooo`000?ooo`0R
oooo0P000:goool00<ooool00`000?ooooooo`02oooo00D0003oooooooooool000000oooo`80003B
oooo003?oooo00<0003oooooool00_ooo`050000oooooooooooo000000Coool00`000?ooooooo`3@
oooo003?oooo00<0003oooooool00_ooo`050000oooooooooooo000000Coool00`000?ooooooo`3@
oooo003>oooo0`0000;oool300000oooo`@0003Coooo003ooooo/Oooo`00oooook7oool00?oooona
oooo003ooooo/Oooo`00oooook7oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {431, 0}} -> {-2.20002, -2.20002, 0.0153134, 
  0.0153134}}]
}, Open  ]]
}, Open  ]],

Cell["\<\
Mit den jetzt vorliegenden Werkzeugen kann dem festgestellten Mangel \
entgegengewirkt werden. Abhilfe ergibt sich allerdings erst, wenn mehrere \
historisch vorgekommene Kalendersysteme in ihrer jeweiligen Datierung auf den \
resultierenden Abbildungen erscheinen.\
\>", "Text"],

Cell["\<\
Das nun programmierte Kalendersystem besitzt zwischen 714 v.Chr. und dem Ende \
der G\[UDoubleDot]ltigkeit des Gregorianischen Kalenders einen verbindlichen \
Charakter auch bez\[UDoubleDot]glich der Wochentagsdiskussion und dem zugeh\
\[ODoubleDot]rigen Sternlauf.\
\>", "Text"],

Cell["\<\
Weitere Kalendersysteme sind vorhanden und k\[ODoubleDot]nnen analog zu den \
bereits implementierten Kalendern erg\[ADoubleDot]nzt werden. Dazu ist eine \
konkrete Zusammenarbeit mit der Firma Stellar Software notwendige \
Voraussetzung.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ". Protokoll"
}], "Section"],

Cell[TextData[{
  "Die Version von ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " lautet:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({$Version, $ReleaseNumber, $LicenseID}\)], "Input"],

Cell[BoxData[
    \({"Microsoft Windows 3.0 (October 6, 1996)", 0, "L4526-3546"}\)], 
  "Output"]
}, Open  ]],

Cell["Die Berechnungszeit betrug (in Sekunden):", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TimeUsed[]\)], "Input"],

Cell[BoxData[
    \(52.7200000000000024`\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Literatur", "Subtitle"],

Cell[TextData[{
  "[Kie1983]\nKietz E., ",
  StyleBox["Der Tag, an dem ER starb",
    FontSlant->"Italic"],
  ", \[UDoubleDot]bersetzt durch Erhard Kietz 1977, herausgegeben 1983 durch \
Esther Kietz, Bl\[UDoubleDot]thlingen (1983)"
}], "Text",
  CellTags->"[Kie1983]"],

Cell[TextData[{
  "[Knau1951]\nKnaurs ",
  StyleBox["Lexikon A-Z",
    FontSlant->"Italic"],
  ", Droemesche Verlagsanstalt M\[UDoubleDot]nchen, (1951/52)"
}], "Text",
  CellTags->"[Knau1951]"],

Cell[TextData[{
  "[M\[UDoubleDot]l1985]\nM\[UDoubleDot]ller M., ",
  StyleBox["Johannes Hus in Konstanz",
    FontSlant->"Italic"],
  ", Stadt Konstanz und Verlag Friedr. Stadler Konstanz, (1985)"
}], "Text",
  CellTags->"[Muel1985]"],

Cell[TextData[{
  "[Ple1982]\nPleticha H., ",
  StyleBox["Deutsche Geschichte in 12 B\[ADoubleDot]nden",
    FontSlant->"Italic"],
  ", Band ",
  StyleBox["1",
    FontWeight->"Bold"],
  ", Verlagsgruppe Bertelsmann GmbH G\[UDoubleDot]tersloh, (1982)"
}], "Text",
  CellTags->"[Ple1982]"],

Cell[TextData[{
  "[Pub1989]\nPubal V. ",
  StyleBox["Das Hus-Haus in Konstanz",
    FontSlant->"Italic"],
  ", Faltblatt, herausgegeben von dem Kulturministerium der CSR im Verlag \
Nakladatelstv\[IAcute] Svoboda, (1989)"
}], "Text",
  CellTags->"[Pub1989]"],

Cell[TextData[{
  "[Rie1983]\nRiemer U., ",
  StyleBox["Gro\[SZ]e Deutsche",
    FontSlant->"Italic"],
  ", Kindler Verlag GmbH M\[UDoubleDot]nchen, (1983)"
}], "Text",
  CellTags->"[Rie1983]"],

Cell[TextData[{
  "[Rusk1974]\nRusk R. ",
  StyleBox["The Day when He Died",
    FontSlant->"Italic"],
  ", Christianity Today, Band ",
  StyleBox["XIII",
    FontWeight->"Bold"],
  ", Nr. 13, 29.M\[ADoubleDot]rz 1974, 4(720)-6(722), (1974), zitiert nach ",
  ButtonBox["[Kie1983]",
    ButtonData:>"[Kie1983]",
    ButtonStyle->"Hyperlink"],
  ", Seite 56-61"
}], "Text",
  CellTags->"[Rusk1974]"],

Cell[TextData[{
  "[SW2003]\nS\[UDoubleDot]dland N., Walter E. ",
  StyleBox["Historik",
    FontSlant->"Italic"],
  ", Computerprogramm in QBASIC, Computermission Sinsheim\n\
(http://www.computermission.org) oder \
http://Norbert.Suedland.bei.t-online.de, (2003)"
}], "Text",
  CellTags->"[SW2003]"],

Cell[TextData[{
  "[Zem1987]\nZemanek H., ",
  StyleBox["Kalender und Chronologie",
    FontSlant->"Italic"],
  ", R. Oldenbourg Verlag M\[UDoubleDot]nchen Wien, 4. verbesserte Auflage, \
(1987)"
}], "Text",
  CellTags->"[Zem1987]"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 800}, {0, 544}},
WindowSize->{768, 521},
WindowMargins->{{-4, Automatic}, {Automatic, 5}},
Magnification->1.5,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style.  Make modifications to any definition using commands in the \
Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Times",
    FontSize->36,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 0.996109],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44,
    FontColor->RGBColor[0, 0, 0.996109]],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20,
    FontColor->RGBColor[0, 0, 0.996109]],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->24,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Times",
    FontSize->24,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->RGBColor[0.996109, 0, 0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36,
    FontColor->RGBColor[0.996109, 0, 0]],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14,
    FontColor->RGBColor[0.996109, 0, 0]],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->18,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0.8, 0.300008],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24,
    FontColor->RGBColor[0, 0.8, 0.300008]],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontSize->12,
    FontColor->RGBColor[0, 0.8, 0.300008]],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->14,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    CounterIncrements->"Section",
    CounterAssignments->{{"Equation", 0}, {"Figure", 0}, {"Table", 0}, {
        "Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->16,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0.500008, 0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24,
    FontColor->RGBColor[0, 0.500008, 0]],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12,
    FontColor->RGBColor[0, 0.500008, 0]],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 0.500008],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22,
    FontColor->RGBColor[0, 0, 0.500008]],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12,
    FontColor->RGBColor[0, 0, 0.500008]],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0.500008, 0, 0.500008],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18,
    FontColor->RGBColor[0.500008, 0, 0.500008]],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10,
    FontColor->RGBColor[0.500008, 0, 0.500008]],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Open  ]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section",
    TextJustification->1,
    FontFamily->"Arial"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    TextJustification->1,
    LineSpacing->{1, 3},
    CounterIncrements->"Text",
    FontFamily->"Times"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    TextJustification->1,
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    TextJustification->1,
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->1,
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    TextJustification->1,
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Times",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    TextJustification->1,
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    TextJustification->1,
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    TextJustification->1,
    FontSize->7]
  }, Open  ]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    FontSize->16,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}},
    FontSize->11,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->OutputForm,
    CounterIncrements->"Output",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0},
    FontSize->16,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}},
    FontSize->11,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->OutputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->GrayLevel[0],
    Background->RGBColor[1, 1, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16,
    FontColor->GrayLevel[0],
    Background->RGBColor[1, 1, 0]],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11,
    FontColor->GrayLevel[0],
    Background->RGBColor[1, 1, 0]],
  
  Cell[StyleData["Message", "Printout"],
    CellFrame->True,
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->10,
    FontColor->GrayLevel[0],
    Background->GrayLevel[0.8]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->OutputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16,
    FontColor->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11,
    FontColor->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}},
    FontSize->16],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}},
    FontSize->11],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Times",
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Open  ]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\
The following styles are useful for numbered equations, figures, etc.  They \
automatically give the cell a FrameLabel containing a reference to a \
particular counter, and also increment that counter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{Inherited, 5}, {Inherited, Inherited}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "Title"], ".", 
              CounterBox[ "NumberedEquation"], ")"}], FormatType -> TextForm, 
            FontWeight -> "Plain"]}, {None, None}},
    DefaultFormatType->DefaultOutputFormatType,
    TextAlignment->Center,
    FormatType->InputForm,
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["NumberedEquation", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["NumberedEquation", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation1"],
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")  "}], FormatType -> 
            TextForm, FontWeight -> "Plain"]}, {None, None}},
    DefaultFormatType->DefaultOutputFormatType,
    TextAlignment->Center,
    FormatType->InputForm,
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["NumberedEquation1", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["NumberedEquation1", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["NumberedEquation1", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Abbildung ", 
              CounterBox[ "Title"], ".", 
              CounterBox[ "NumberedFigure"]}]], None}},
    CounterIncrements->"NumberedFigure",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["NumberedFigure", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["NumberedFigure", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure1"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Abbildung ", 
              CounterBox[ "NumberedFigure"]}]], None}},
    CounterIncrements->"NumberedFigure",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure1", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["NumberedFigure1", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["NumberedFigure1", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{44, Inherited}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Tabelle ", 
              CounterBox[ "Title"], ".", 
              CounterBox[ "NumberedTable"]}]], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["NumberedTable", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["NumberedTable", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable1"],
    CellMargins->{{44, Inherited}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Tabelle ", 
              CounterBox[ "NumberedTable"]}]], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable1", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["NumberedTable1", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["NumberedTable1", "Printout"],
    FontSize->10]
  }, Open  ]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    ShowCellBracket->False,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    FormatType->InputForm,
    ScriptLevel->1,
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0],
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{0, 0}, {6, 6}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    ShowCellBracket->False,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    ZeroWidthTimes->True,
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["ChemicalFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["ChemicalFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{0, 0}, {6, 6}}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    ShowCellBracket->False,
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    TextAlignment->Center,
    FormatType->InputForm,
    ScriptLevel->0,
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0],
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    ShowCellBracket->False,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->15],
  
  Cell[StyleData["Program", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->10.5],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{0, 0}, {6, 6}},
    FontSize->9.5]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Equation"],
    DefaultFormatType->DefaultOutputFormatType,
    TextAlignment->Center,
    FormatType->InputForm,
    CounterIncrements->"Equation",
    FormatTypeAutoConvert->False,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Equation", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Equation", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["Equation", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10,
    FontWeight->"Bold",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard ButtonFunctions, for use \
in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Open  ]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Open  ]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder objects in \
palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->Primary,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Open  ]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles of most \
cells.  If a cell's FormatType matches the name of one of the styles defined \
below, then that style is applied between the cell's style and its own \
options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    TextAlignment->Left,
    LineSpacing->{1.1, 0},
    StyleMenuListing->None,
    FontFamily->"Times New Roman"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1.1, 0},
    StyleMenuListing->None,
    FontFamily->"Times New Roman"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times New Roman"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an inline cell \
within another.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None,
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["InlineCell", "Presentation"],
    FontSize->16,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["InlineCell", "Condensed"],
    FontSize->11,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["InlineCell", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    FontFamily->"Times New Roman",
    Background->RGBColor[0, 0.8, 0.2]],
  
  Cell[StyleData["InlineCellEditing", "Presentation"],
    FontSize->16,
    Background->RGBColor[0, 0.8, 0.2]],
  
  Cell[StyleData["InlineCellEditing", "Condensed"],
    FontSize->11,
    Background->RGBColor[0, 0.8, 0.2]],
  
  Cell[StyleData["InlineCellEditing", "Printout"],
    FontSize->10,
    Background->GrayLevel[0.8]]
  }, Open  ]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Centered Headings", "Section",
    CellFrame->{{0, 0}, {0, 2}}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CenteredTitle"],
    CellMargins->{{12, 12}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Times",
    FontSize->36,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["CenteredTitle", "Presentation"],
    CellMargins->{{24, 24}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["CenteredTitle", "Condensed"],
    CellMargins->{{8, 8}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["CenteredTitle", "Printout"],
    CellMargins->{{2, 2}, {15, 30}},
    FontSize->24]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CenteredSubtitle"],
    CellMargins->{{12, 12}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Times",
    FontSize->24,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["CenteredSubtitle", "Presentation"],
    CellMargins->{{24, 24}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["CenteredSubtitle", "Condensed"],
    CellMargins->{{8, 8}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["CenteredSubtitle", "Printout"],
    CellMargins->{{2, 2}, {10, 15}},
    FontSize->18]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CenteredSubsubtitle"],
    CellMargins->{{12, 12}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["CenteredSubsubtitle", "Presentation"],
    CellMargins->{{24, 24}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["CenteredSubsubtitle", "Condensed"],
    CellMargins->{{8, 8}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["CenteredSubsubtitle", "Printout"],
    CellMargins->{{2, 2}, {8, 10}},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CenteredSection"],
    CellMargins->{{12, 12}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    TextAlignment->Center,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->16,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["CenteredSection", "Presentation"],
    CellMargins->{{24, 24}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["CenteredSection", "Condensed"],
    CellMargins->{{8, 8}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["CenteredSection", "Printout"],
    CellMargins->{{2, 2}, {7, 22}},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CenteredSubsection"],
    CellMargins->{{12, 12}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    TextAlignment->Center,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["CenteredSubsection", "Presentation"],
    CellMargins->{{24, 24}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["CenteredSubsection", "Condensed"],
    CellMargins->{{8, 8}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["CenteredSubsection", "Printout"],
    CellMargins->{{2, 2}, {7, 22}},
    FontSize->12]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CenteredSubsubsection"],
    CellMargins->{{12, 12}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    TextAlignment->Center,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["CenteredSubsubsection", "Presentation"],
    CellMargins->{{24, 24}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["CenteredSubsubsection", "Condensed"],
    CellMargins->{{8, 8}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["CenteredSubsubsection", "Printout"],
    CellMargins->{{2, 2}, {7, 14}},
    FontSize->11]
  }, Open  ]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation package. These \
styles serve to make visible otherwise invisible tagboxes.\
\>", "Text",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    CellTags->"NotationPackage"]
  }, Closed]]
  }, Open  ]]
  }]
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "[Kie1983]"->{
    Cell[192643, 4973, 269, 7, 93, "Text",
      CellTags->"[Kie1983]"]},
  "[Knau1951]"->{
    Cell[192915, 4982, 193, 6, 69, "Text",
      CellTags->"[Knau1951]"]},
  "[Muel1985]"->{
    Cell[193111, 4990, 235, 6, 69, "Text",
      CellTags->"[Muel1985]"]},
  "[Ple1982]"->{
    Cell[193349, 4998, 288, 9, 93, "Text",
      CellTags->"[Ple1982]"]},
  "[Pub1989]"->{
    Cell[193640, 5009, 259, 7, 93, "Text",
      CellTags->"[Pub1989]"]},
  "[Rie1983]"->{
    Cell[193902, 5018, 193, 6, 69, "Text",
      CellTags->"[Rie1983]"]},
  "[Rusk1974]"->{
    Cell[194098, 5026, 398, 13, 93, "Text",
      CellTags->"[Rusk1974]"]},
  "[SW2003]"->{
    Cell[194499, 5041, 300, 8, 93, "Text",
      CellTags->"[SW2003]"]},
  "[Zem1987]"->{
    Cell[194802, 5051, 232, 7, 93, "Text",
      CellTags->"[Zem1987]"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"[Kie1983]", 235441, 6506},
  {"[Knau1951]", 235533, 6509},
  {"[Muel1985]", 235626, 6512},
  {"[Ple1982]", 235718, 6515},
  {"[Pub1989]", 235809, 6518},
  {"[Rie1983]", 235900, 6521},
  {"[Rusk1974]", 235992, 6524},
  {"[SW2003]", 236084, 6527},
  {"[Zem1987]", 236174, 6530}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 261, 3, 154, "Title",
  CounterAssignments->{{"Title", 0}, {"SubTitle", 0}, {"SubSubTitle", 0}, {
      "Section", 0}, {"SubSection", 0}, {"SubSubSection", 0}, {
      "NumberedEquation", 0}, {"NumberedFigure", 0}, {"NumberedTable", 0}}],
Cell[1995, 56, 229, 5, 120, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2249, 65, 97, 5, 76, "Section"],
Cell[2349, 72, 360, 6, 117, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2746, 83, 99, 5, 76, "Section"],

Cell[CellGroupData[{
Cell[2870, 92, 140, 7, 68, "Subsection"],
Cell[3013, 101, 416, 10, 93, "Text"],
Cell[3432, 113, 247, 6, 69, "Text"],
Cell[3682, 121, 379, 8, 93, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4098, 134, 174, 7, 68, "Subsection"],

Cell[CellGroupData[{
Cell[4297, 145, 196, 9, 61, "Subsubsection"],
Cell[4496, 156, 158, 3, 69, "Text"],
Cell[4657, 161, 234, 4, 93, "Text"],
Cell[4894, 167, 415, 7, 117, "Text"],
Cell[5312, 176, 258, 6, 69, "Text"],
Cell[5573, 184, 590, 15, 117, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6200, 204, 219, 9, 61, "Subsubsection"],
Cell[6422, 215, 326, 8, 93, "Text"],

Cell[CellGroupData[{
Cell[6773, 227, 814, 15, 441, "Input"],
Cell[7590, 244, 51, 1, 41, "Output"]
}, Open  ]],
Cell[7656, 248, 116, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[7797, 255, 79, 1, 41, "Input"],
Cell[7879, 258, 1739, 40, 333, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[9667, 304, 212, 9, 61, "Subsubsection"],
Cell[9882, 315, 420, 11, 93, "Text"],
Cell[10305, 328, 558, 15, 117, "Text"],
Cell[10866, 345, 197, 6, 69, "Text"],
Cell[11066, 353, 199, 4, 69, "Text"],

Cell[CellGroupData[{
Cell[11290, 361, 1878, 32, 916, "Input"],
Cell[13171, 395, 58, 1, 41, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[13278, 402, 194, 9, 61, "Subsubsection"],
Cell[13475, 413, 48, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[13548, 417, 53, 1, 66, "Input"],
Cell[13604, 420, 120, 3, 41, "Output"]
}, Open  ]],
Cell[13739, 426, 467, 12, 93, "Text"],
Cell[14209, 440, 458, 13, 117, "Text"],
Cell[14670, 455, 197, 6, 69, "Text"],
Cell[14870, 463, 133, 3, 69, "Text"],

Cell[CellGroupData[{
Cell[15028, 470, 2470, 43, 1091, "Input"],
Cell[17501, 515, 56, 1, 41, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[17606, 522, 200, 9, 61, "Subsubsection"],
Cell[17809, 533, 50, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[17884, 537, 57, 1, 66, "Input"],
Cell[17944, 540, 120, 3, 41, "Output"]
}, Open  ]],
Cell[18079, 546, 428, 12, 93, "Text"],
Cell[18510, 560, 433, 11, 117, "Text"],
Cell[18946, 573, 197, 6, 69, "Text"],
Cell[19146, 581, 136, 3, 69, "Text"],

Cell[CellGroupData[{
Cell[19307, 588, 2797, 49, 1191, "Input"],
Cell[22107, 639, 59, 1, 41, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[22215, 646, 194, 9, 61, "Subsubsection"],
Cell[22412, 657, 108, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[22545, 664, 4036, 72, 1566, "Input"],
Cell[26584, 738, 60, 1, 41, "Output"]
}, Open  ]],
Cell[26659, 742, 240, 7, 69, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26936, 754, 180, 9, 61, "Subsubsection"],
Cell[27119, 765, 139, 3, 69, "Text"],

Cell[CellGroupData[{
Cell[27283, 772, 542, 8, 191, "Input"],
Cell[27828, 782, 1216, 22, 483, "Output"]
}, Open  ]],
Cell[29059, 807, 114, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[29198, 814, 102, 2, 41, "Input"],
Cell[29303, 818, 641, 16, 133, "Output"]
}, Open  ]],
Cell[29959, 837, 320, 6, 93, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[30328, 849, 175, 7, 68, "Subsection"],

Cell[CellGroupData[{
Cell[30528, 860, 185, 9, 61, "Subsubsection"],
Cell[30716, 871, 233, 4, 69, "Text"],
Cell[30952, 877, 252, 7, 69, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[31241, 889, 189, 9, 61, "Subsubsection"],
Cell[31433, 900, 196, 4, 69, "Text"],

Cell[CellGroupData[{
Cell[31654, 908, 49, 1, 41, "Input"],
Cell[31706, 911, 89, 1, 41, "Output"]
}, Open  ]],
Cell[31810, 915, 45, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[31880, 919, 1592, 27, 816, "Input"],
Cell[33475, 948, 48, 1, 41, "Output"]
}, Open  ]],
Cell[33538, 952, 91, 2, 45, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[33666, 959, 212, 9, 61, "Subsubsection"],
Cell[33881, 970, 50, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[33956, 974, 730, 12, 416, "Input"],
Cell[34689, 988, 59, 1, 41, "Output"]
}, Open  ]],
Cell[34763, 992, 41, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[34829, 996, 57, 1, 41, "Input"],
Cell[34889, 999, 47, 1, 41, "Output"]
}, Open  ]],
Cell[34951, 1003, 38, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[35014, 1007, 131, 2, 66, "Input"],
Cell[35148, 1011, 40, 1, 41, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[35237, 1018, 194, 9, 61, "Subsubsection"],
Cell[35434, 1029, 50, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[35509, 1033, 1219, 21, 791, "Input"],
Cell[36731, 1056, 57, 1, 41, "Output"]
}, Open  ]],
Cell[36803, 1060, 41, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[36869, 1064, 55, 1, 41, "Input"],
Cell[36927, 1067, 46, 1, 41, "Output"]
}, Open  ]],
Cell[36988, 1071, 38, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[37051, 1075, 127, 2, 66, "Input"],
Cell[37181, 1079, 40, 1, 41, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[37270, 1086, 197, 9, 61, "Subsubsection"],
Cell[37470, 1097, 50, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[37545, 1101, 2099, 33, 1316, "Input"],
Cell[39647, 1136, 60, 1, 41, "Output"]
}, Open  ]],
Cell[39722, 1140, 41, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[39788, 1144, 58, 1, 41, "Input"],
Cell[39849, 1147, 47, 1, 41, "Output"]
}, Open  ]],
Cell[39911, 1151, 38, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[39974, 1155, 133, 2, 91, "Input"],
Cell[40110, 1159, 40, 1, 41, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[40199, 1166, 194, 9, 61, "Subsubsection"],
Cell[40396, 1177, 50, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[40471, 1181, 1032, 16, 566, "Input"],
Cell[41506, 1199, 61, 1, 41, "Output"]
}, Open  ]],
Cell[41582, 1203, 41, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[41648, 1207, 174, 3, 66, "Input"],
Cell[41825, 1212, 86, 1, 41, "Output"],
Cell[41914, 1215, 104, 2, 41, "Output"]
}, Open  ]],
Cell[42033, 1220, 38, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[42096, 1224, 144, 2, 91, "Input"],
Cell[42243, 1228, 40, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[42320, 1234, 144, 2, 91, "Input"],
Cell[42467, 1238, 40, 1, 41, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[42556, 1245, 180, 9, 61, "Subsubsection"],
Cell[42739, 1256, 478, 8, 141, "Text"],
Cell[43220, 1266, 366, 12, 45, "Text"],

Cell[CellGroupData[{
Cell[43611, 1282, 142, 3, 66, "Input"],
Cell[43756, 1287, 58, 1, 41, "Output"],
Cell[43817, 1290, 40, 1, 41, "Output"]
}, Open  ]],
Cell[43872, 1294, 267, 7, 69, "Text"],

Cell[CellGroupData[{
Cell[44164, 1305, 138, 2, 66, "Input"],
Cell[44305, 1309, 60, 1, 41, "Output"],
Cell[44368, 1312, 40, 1, 41, "Output"]
}, Open  ]],
Cell[44423, 1316, 720, 19, 117, "Text"],

Cell[CellGroupData[{
Cell[45168, 1339, 127, 2, 66, "Input"],
Cell[45298, 1343, 65, 1, 41, "Output"]
}, Open  ]],
Cell[45378, 1347, 383, 12, 45, "Text"],

Cell[CellGroupData[{
Cell[45786, 1363, 101, 2, 41, "Input"],
Cell[45890, 1367, 50, 1, 41, "Output"]
}, Open  ]],
Cell[45955, 1371, 312, 7, 69, "Text"],

Cell[CellGroupData[{
Cell[46292, 1382, 128, 2, 66, "Input"],
Cell[46423, 1386, 64, 1, 41, "Output"]
}, Open  ]],
Cell[46502, 1390, 480, 9, 117, "Text"],

Cell[CellGroupData[{
Cell[47007, 1403, 150, 3, 66, "Input"],
Cell[47160, 1408, 60, 1, 41, "Output"],
Cell[47223, 1411, 40, 1, 41, "Output"]
}, Open  ]],
Cell[47278, 1415, 214, 7, 45, "Text"],

Cell[CellGroupData[{
Cell[47517, 1426, 137, 2, 66, "Input"],
Cell[47657, 1430, 60, 1, 41, "Output"],
Cell[47720, 1433, 40, 1, 41, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[47833, 1442, 101, 5, 76, "Section"],
Cell[47937, 1449, 206, 4, 69, "Text"],

Cell[CellGroupData[{
Cell[48168, 1457, 62, 1, 41, "Input"],
Cell[48233, 1460, 84, 1, 35, "Print"]
}, Open  ]],
Cell[48332, 1464, 49, 0, 45, "Text"],
Cell[48384, 1466, 280, 4, 116, "Input"],
Cell[48667, 1472, 252, 6, 69, "Text"],

Cell[CellGroupData[{
Cell[48944, 1482, 112, 2, 41, "Input"],

Cell[CellGroupData[{
Cell[49081, 1488, 70863, 1706, 444, 33887, 1245, "GraphicsData", 
"PostScript", "Graphics"],
Cell[119947, 3196, 71094, 1709, 444, 33887, 1245, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[191068, 4909, 289, 5, 93, "Text"],
Cell[191360, 4916, 289, 5, 93, "Text"],
Cell[191652, 4923, 262, 5, 93, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[191951, 4933, 101, 5, 76, "Section"],
Cell[192055, 4940, 114, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[192194, 4949, 71, 1, 41, "Input"],
Cell[192268, 4952, 97, 2, 41, "Output"]
}, Open  ]],
Cell[192380, 4957, 57, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[192462, 4961, 43, 1, 41, "Input"],
Cell[192508, 4964, 54, 1, 41, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[192611, 4971, 29, 0, 80, "Subtitle"],
Cell[192643, 4973, 269, 7, 93, "Text",
  CellTags->"[Kie1983]"],
Cell[192915, 4982, 193, 6, 69, "Text",
  CellTags->"[Knau1951]"],
Cell[193111, 4990, 235, 6, 69, "Text",
  CellTags->"[Muel1985]"],
Cell[193349, 4998, 288, 9, 93, "Text",
  CellTags->"[Ple1982]"],
Cell[193640, 5009, 259, 7, 93, "Text",
  CellTags->"[Pub1989]"],
Cell[193902, 5018, 193, 6, 69, "Text",
  CellTags->"[Rie1983]"],
Cell[194098, 5026, 398, 13, 93, "Text",
  CellTags->"[Rusk1974]"],
Cell[194499, 5041, 300, 8, 93, "Text",
  CellTags->"[SW2003]"],
Cell[194802, 5051, 232, 7, 93, "Text",
  CellTags->"[Zem1987]"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

